# Magyar nevek listái

vezeteknev = ['Kovács', 'Nagy', 'Kiss', 'Tóth', 'Varga', 'Farkas', 'Horváth', 'Szabó', 'Molnár', 'Balázs',
              'Lakatos', 'Takács', 'Papp', 'Katona', 'Szilágyi', 'Balogh', 'Gulyás', 'Szőke', 'Simon', 'Fehér',
              'Barta', 'Császár', 'Sándor', 'Fodor', 'Bakos', 'László', 'Kerekes', 'Fekete', 'Török', 'Pintér',
              'Juhász', 'Gáspár', 'Kis', 'Bognár', 'Hajdu', 'Kónya', 'Kozma', 'Borbély', 'Budai', 'Hegedűs',
              'Ács', 'Bálint', 'Rácz', 'Virág', 'Sipos', 'Kelemen', 'Gál', 'Szőllősi', 'Lengyel', 'Füredi',
              'Magyar', 'Fazekas', 'Antal', 'Bérczes', 'Temesvári', 'Oláh', 'Pál', 'Barna', 'Bajnai', 'Balog',
              'Kocsis', 'Halász', 'Kertész', 'Boros', 'Fekete', 'Bérczi', 'Vincze', 'Dudás', 'Mészáros',
              'Gombos', 'Árkosi', 'Pánczél', 'Karádi', 'Kulcsár', 'Ágoston', 'Pap', 'Pálinkás', 'Csák', 'Bódi',
              'Kerekes', 'Fischer', 'Győri', 'Magyar', 'Péter', 'Fenyő', 'Kocsis', 'Fazekas', 'Kis-Benedek',
              'Bán', 'Bánhidi', 'Kovácsik', 'Kincses', 'Iványi', 'Bertalan', 'Molnár', 'Papp', 'Benedek',
              'Huszár', 'Kis-Gál', 'Németh', 'Somogyi', 'Boda', 'Budai', 'Székely', 'Borsos', 'Czeglédi',
              'Árvai', 'Miklós', 'Füzesi', 'Pap', 'Kisfaludi', 'Pongrácz', 'Tóth', 'Budavári', 'Sajó',
              'Mészáros', 'Lévai', 'Kéri', 'Czakó', 'Csordás', 'Mészáros', 'Bodó', 'Kántor', 'Nagy-Balogh',
              'Szekeres', 'Takács', 'Jakab', 'Herczeg', 'Vajda', 'Gyuris', 'Kincs', 'Végh', 'Lukács', 'Erdélyi',
              'Simon', 'Bárdi', 'Szabó-Balog', 'Szubin']

keresztnev_n = ['Anna', 'Cecília', 'Erika', 'Hanna', 'Katalin', 'Mária', 'Nóra', 'Orsolya', 'Réka', 'Szilvia',
                'Tünde', 'Viktória', 'Dóra', 'Eszter', 'Flóra', 'Hajnalka', 'Izabella', 'Jázmin', 'Kamilla', 'Nikolett',
                'Panna', 'Rita', 'Sarolta', 'Zsófia', 'Ágota', 'Csilla', 'Lilla', 'Orsolya', 'Panna',
                'Szandra', 'Tamara', 'Ágnes', 'Júlia', 'Kincső', 'Babett', 'Barbara', 'Beáta', 'Bianka',
                'Blanka', 'Boglárka', 'Borbála', 'Boróka', 'Brigitta', 'Bernadett', 'Bettina', 'Berta', 'Betti',
                'Bianka', 'Cecília', 'Cintia', 'Csenge', 'Csilla', 'Detti', 'Diana', 'Dóra', 'Dalma', 'Daniella',
                'Debóra', 'Dolli', 'Dominika']

keresztnev_f = ['Ábel', 'Ádám', 'Ákos', 'Aladár', 'Albert', 'Albin', 'Alekszander', 'Alfréd', 'Ambrus', 'Andor',
                'András', 'Áron', 'Árpád', 'Attila', 'Aurél', 'Bálint', 'Barna', 'Barnabás', 'Béla', 'Benedek',
                'Benjámin', 'Bernát', 'Botond', 'Csongor', 'Dénes', 'Dániel', 'Dávid', 'Dezső', 'Dominik', 'Donát',
                'Edgár', 'Edmund', 'Ede', 'Eduárd', 'Endre', 'Erik', 'Ernő', 'Fábián', 'Farkas', 'Ferenc', 'Flórián',
                'Gábor', 'Géza', 'Gergely', 'Gusztáv', 'György', 'Győző', 'Hunor', 'Igor', 'Imre', 'István', 'János',
                'József', 'Kálmán', 'Károly', 'Kázmér', 'Kelemen', 'Kende', 'Kornél', 'Kristóf',
                'Lajos', 'László', 'Levente', 'Lóránt', 'Lóránd', 'Lukács', 'Márió', 'Márk', 'Márton', 'Mátyás',
                'Miklós', 'Milán', 'Mózes', 'Nándor', 'Nikolasz', 'Noé', 'Norbert', 'Olivér', 'Ödön', 'Oszkár',
                'Ottó', 'Pál', 'Patrik', 'Péter', 'Róbert', 'Rudolf', 'Sámuel', 'Sándor', 'Sebestyén', 'Soma',
                'Szabolcs', 'Szilárd', 'Szilveszter', 'Tamás', 'Tihamér', 'Tibor', 'Tivadar', 'Tódor', 'Tóbiás',
                'Vencel', 'Viktor', 'Vilmos', 'Vince', 'Zalán', 'Zétény', 'Zoltán', 'Zsigmond', 'Zsolt']

keresztnev_v =['Ábel', 'Ádám', 'Ákos', 'Aladár', 'Albert', 'Albin', 'Alekszander', 'Alfréd', 'Ambrus', 'Andor',
                'András', 'Áron', 'Árpád', 'Attila', 'Aurél', 'Bálint', 'Barna', 'Barnabás', 'Béla', 'Benedek',
                'Benjámin', 'Bernát', 'Botond', 'Csongor', 'Dénes', 'Dániel', 'Dávid', 'Dezső', 'Dominik', 'Donát',
                'Edgár', 'Edmund', 'Ede', 'Eduárd', 'Endre', 'Erik', 'Ernő', 'Fábián', 'Farkas', 'Ferenc', 'Flórián',
                'Gábor', 'Géza', 'Gergely', 'Gusztáv', 'György', 'Győző', 'Hunor', 'Igor', 'Imre', 'István', 'János',
                'József', 'Kálmán', 'Károly', 'Kázmér', 'Kelemen', 'Kende', 'Kornél', 'Kristóf',
                'Lajos', 'László', 'Levente', 'Lóránt', 'Lóránd', 'Lukács', 'Márió', 'Márk', 'Márton', 'Mátyás',
                'Miklós', 'Milán', 'Mózes', 'Nándor', 'Nikolasz', 'Noé', 'Norbert', 'Olivér', 'Ödön', 'Oszkár',
                'Ottó', 'Pál', 'Patrik', 'Péter', 'Róbert', 'Rudolf', 'Sámuel', 'Sándor', 'Sebestyén', 'Soma',
                'Szabolcs', 'Szilárd', 'Szilveszter', 'Tamás', 'Tihamér', 'Tibor', 'Tivadar', 'Tódor', 'Tóbiás',
                'Vencel', 'Viktor', 'Vilmos', 'Vince', 'Zalán', 'Zétény', 'Zoltán', 'Zsigmond', 'Zsolt',
               'Anna', 'Cecília', 'Erika', 'Hanna', 'Katalin', 'Mária', 'Nóra', 'Orsolya', 'Réka', 'Szilvia',
               'Tünde', 'Viktória', 'Dóra', 'Eszter', 'Flóra', 'Hajnalka', 'Izabella', 'Jázmin', 'Kamilla', 'Nikolett',
               'Panna', 'Rita', 'Sarolta', 'Zsófia', 'Ágota', 'Csilla', 'Lilla', 'Orsolya', 'Panna',
               'Szandra', 'Tamara', 'Ágnes', 'Júlia', 'Kincső', 'Babett', 'Barbara', 'Beáta', 'Bianka',
               'Blanka', 'Boglárka', 'Borbála', 'Boróka', 'Brigitta', 'Bernadett', 'Bettina', 'Berta', 'Betti',
               'Bianka', 'Cecília', 'Cintia', 'Csenge', 'Csilla', 'Detti', 'Diana', 'Dóra', 'Dalma', 'Daniella',
               'Debóra', 'Dolli', 'Dominika'
               ]

utca = ['Ady Endre utca', 'Akácfa utca', 'Alkotmány utca', 'Almássy tér', 'Andrássy út', 'Apáczai Csere János utca',
        'Aradi utca', 'Árpád fejedelem útja', 'Attila utca', 'Bajcsy-Zsilinszky út', 'Balassi Bálint utca',
        'Baross utca', 'Bartók Béla út', 'Batthyány tér', 'Bécsi utca', 'Belgrád rakpart', 'Bethlen Gábor tér',
        'Béke tér', 'Bem rakpart', 'Benczúr utca', 'Bérkocsis utca', 'Berzsenyi utca', 'Bihari utca', 'Bocskai utca',
        'Budaörsi út', 'Csarnok tér', 'Csévi utca', 'Csillaghegyi út', 'Csokonai utca', 'Csömöri utca', 'Dandár utca',
        'Darázs utca', 'Deák Ferenc utca', 'Dózsa György út', 'Egyetem tér', 'Erzsébet körút', 'Erzsébet tér',
        'Fadrusz utca', 'Fehérvári út', 'Kőrösi Csoma Sándor út', 'Ferenciek tere', 'Ferenc körút', 'Ferenc tér',
        'Feszty Árpád utca', 'Fő utca', 'Frankel Leó utca', 'Gát utca', 'Gönczy Pál utca', 'Gyömrői út',
        'Gyulai Pál utca', 'Hajós utca', 'Haller utca', 'Hársfa utca', 'Hattyú utca', 'Hegedűs Gyula utca',
        'Hegyalja út', 'Heltai Jenő utca', 'Hercegprímás utca', 'Hidegkúti út', 'Hűvösvölgyi út', 'Jókai utca',
        'József Attila utca', 'Kálmán Imre utca', 'Kálvin tér', 'Károly körút', 'Kassák Lajos utca',
        'Katona József utca', 'Káva utca', 'Kazinczy utca', 'Király utca',  'Klauzál tér', 'Klauzál utca',
        'Köztársaság tér', 'Kőbányai út', 'Közraktár utca', 'Klapka György út', 'Mártirok útja'
        'Krisztina körút', 'Kun utca', 'Váci út', 'Lajos utca', 'Lánchíd utca', 'Üllői út']

telepules = ['Aba', 'Abaliget', 'Abasár', 'Abaújalpár', 'Abaújkér', 'Abaújlak', 'Abaújszántó', 'Abaújszolnok',
             'Abaújvár', 'Abádszalók', 'Abda', 'Abod', 'Abony', 'Acsa', 'Acsalag', 'Acsád', 'Adács', 'Adásztevel',
             'Adony', 'Adorjánháza', 'Adorjás', 'Aggtelek', 'Agyagosszergény', 'Ajak', 'Ajka', 'Aka', 'Akasztó',
             'Alacska', 'Alap', 'Alattyán', 'Albertirsa', 'Alcsútdoboz', 'Aldebrő', 'Algyő', 'Alibánfa', 'Almamellék',
             'Almásfüzitő', 'Almásháza', 'Almáskamarás', 'Almáskeresztúr', 'Alsóberecki', 'Alsóbogát', 'Alsódobsza',
             'Alsógagy', 'Alsómocsolád', 'Alsónána', 'Alsónemesapáti', 'Alsónémedi', 'Alsónyék', 'Alsóörs', 'Alsópáhok',
             'Alsópetény', 'Alsórajk', 'Alsóregmec', 'Alsószenterzsébet', 'Alsószentiván', 'Alsószentmárton', 'Alsószölnök',
             'Alsószuha', 'Alsótelekes', 'Alsótold', 'Alsóújlak', 'Alsóvadász', 'Alsózsolca', 'Ambrózfalva', 'Anarcs',
             'Andocs', 'Andornaktálya', 'Andrásfa', 'Annavölgy', 'Apagy', 'Apaj', 'Aparhant', 'Apácatorna', 'Apátfalva',
             'Apátistvánfalva', 'Apátvarasd', 'Apc', 'Apostag', 'Aranyosapáti', 'Aranyosgadány', 'Arka', 'Arló',
             'Arnót', 'Aszaló', 'Aszód', 'Aszófő', 'Atkár', 'Attala', 'Ábrahámhegy', 'Ács', 'Ácsteszér', 'Ádánd', 'Ág',
             'Ágasegyháza', 'Ágfalva', 'Álmosd', 'Áporka', 'Ároktő', 'Árpádhalom', 'Árpás', 'Ártánd', 'Ásotthalom',
             'Ásványráró', 'Ászár', 'Áta', 'Átány', 'Babarc', 'Babarcszőlős', 'Babosdöbréte', 'Babócsa', 'Babót',
             'Badacsonytomaj', 'Badacsonytördemic', 'Bag', 'Bagamér', 'Baglad', 'Bagod', 'Baj', 'Baja', 'Bajánsenye',
             'Bajna', 'Bajót', 'Bak', 'Bakháza', 'Bakonszeg', 'Bakonya', 'Bakonybánk', 'Bakonybél', 'Bakonycsernye',
             'Bakonygyirót', 'Bakonyjákó', 'Bakonykoppány', 'Bakonykúti', 'Bakonynána', 'Bakonyoszlop', 'Bakonypéterd',
             'Bakonypölöske', 'Bakonyság', 'Bakonysárkány', 'Bakonyszentiván', 'Bakonyszentkirály', 'Bakonyszentlászló',
             'Bakonyszombathely', 'Bakonyszücs', 'Bakonytamási', 'Bakóca', 'Baks', 'Baksa', 'Baktakék',
             'Baktalórántháza', 'Baktüttös', 'Balajt', 'Balassagyarmat', 'Balaton', 'Balatonakali', 'Balatonalmádi',
             'Balatonberény', 'Balatonboglár', 'Balatoncsicsó', 'Balatonederics', 'Balatonendréd', 'Balatonfenyves',
             'Balatonföldvár', 'Balatonfőkajár', 'Balatonfüred', 'Balatonfűzfő', 'Balatongyörök', 'Balatonhenye',
             'Balatonkenese', 'Balatonkeresztúr', 'Balatonlelle', 'Balatonmagyaród', 'Balatonmáriafürdő',
             'Balatonőszöd', 'Balatonrendes', 'Balatonszabadi', 'Balatonszárszó', 'Balatonszemes',
             'Balatonszentgyörgy', 'Balatonszepezd', 'Balatonszőlős', 'Balatonudvari', 'Balatonújlak', 'Balatonvilágos',
             'Balástya', 'Balinka', 'Balkány', 'Ballószög', 'Balmazújváros', 'Balogunyom', 'Balotaszállás', 'Balsa',
             'Bana', 'Barabás', 'Baracs', 'Baracska', 'Baranyahidvég', 'Baranyajenő', 'Baranyaszentgyörgy', 'Barbacs',
             'Barcs', 'Barlahida', 'Barnag', 'Basal', 'Baskó', 'Baté', 'Battonya', 'Batyk', 'Bazsi', 'Bábolna',
             'Bábonymegyer', 'Bácsalmás', 'Bácsbokod', 'Bácsborsód', 'Bácsszentgyörgy', 'Bácsszőlős', 'Bágyogszovát',
             'Bálványos', 'Bánd', 'Bánfa', 'Bánhorváti', 'Bánk', 'Bánokszentgyörgy', 'Bánréve', 'Bár', 'Báránd',
             'Bárdudvarnok', 'Bárna', 'Bársonyos', 'Báta', 'Bátaapáti', 'Bátaszék', 'Bátmonostor', 'Bátonyterenye',
             'Bátor', 'Bátorliget', 'Bátya', 'Bázakerettye', 'Becsehely', 'Becske', 'Becskeháza', 'Becsvölgye', 'Bedegkér',
             'Bedő', 'Bejcgyertyános', 'Bekecs', 'Bekölce', 'Belecska', 'Beled', 'Beleg', 'Belezna', 'Beloiannisz',
             'Belsősárd', 'Belvárdgyula', 'Benk', 'Bercel', 'Beregdaróc', 'Beregsurány', 'Berekböszörmény', 'Berekfürdő',
             'Beremend', 'Berente', 'Beret', 'Berettyóújfalu', 'Berhida', 'Berkenye', 'Berkesd', 'Berkesz', 'Bernecebaráti',
             'Berzence', 'Berzék', 'Besence', 'Besenyőd', 'Besenyőtelek', 'Besenyszög', 'Besnyő', 'Beszterec',
             'Bezedek', 'Bezenye', 'Bezeréd', 'Bezi', 'Béb', 'Békás', 'Békés', 'Békéscsaba', 'Békéssámson',
             'Békésszentandrás', 'Bélapátfalva', 'Bélavár', 'Bélmegyer', 'Bénye', 'Bér', 'Bérbaltavár', 'Biatorbágy',
             'Bicsérd', 'Bicske', 'Bihardancsháza', 'Biharkeresztes', 'Biharnagybajom', 'Bihartorda', 'Biharugra',
             'Bikal', 'Bikács', 'Biri', 'Birján', 'Bisse', 'Boba', 'Bocfölde', 'Boconád', 'Bocska', 'Bocskaikert',
             'Boda', 'Bodajk', 'Bodmér', 'Bodolyabér', 'Bodonhely', 'Bodony', 'Bodorfa', 'Bodrog', 'Bodroghalom',
             'Bodrogkeresztúr', 'Bodrogkisfalud', 'Bodrogolaszi', 'Bogács', 'Bogád', 'Bogádmindszent', 'Bogdása',
             'Bogyiszló', 'Bogyoszló', 'Bojt', 'Bokod', 'Bokor', 'Boldog', 'Boldogasszonyfa', 'Boldogkőújfalu',
             'Boldogkőváralja', 'Boldva', 'Bolhás', 'Bolhó', 'Boncodfölde', 'Bonnya', 'Bonyhád', 'Bonyhádvarasd',
             'Bordány', 'Borgáta', 'Borjád', 'Borota', 'Borsfa', 'Borsodbóta', 'Borsodgeszt', 'Borsodivánka',
             'Borsodnádasd', 'Borsodszentgyörgy', 'Borsodszirák', 'Borsosberény', 'Borszörcsök', 'Borzavár', 'Bosta',
             'Botpalád', 'Botykapeterd', 'Bozsok', 'Bozzai', 'Bócsa', 'Bódvalenke', 'Bódvarákó', 'Bódvaszilas',
             'Bókaháza', 'Bóly', 'Bózsva', 'Böde', 'Bödeháza', 'Bögöt', 'Bögöte', 'Böhönye', 'Bököny', 'Bölcske',
             'Börcs', 'Börzönce', 'Bő', 'Bőcs', 'Bőny', 'Bősárkány', 'Bőszénfa', 'Bucsa', 'Bucsu', 'Bucsuszentlászló',
             'Bucsuta', 'Budajenő', 'Budakalász', 'Budakeszi', 'Budaörs', 'Budapest', 'Bugac', 'Bugacpusztaháza',
             'Bugyi', 'Buj', 'Buják', 'Buzsák', 'Bük', 'Bükkaranyos', 'Bükkábrány', 'Bükkmogyorósd', 'Bükkösd',
             'Bükkszenterzsébet', 'Bükkszentkereszt', 'Bükkszentmárton', 'Bükkszék', 'Bükkzsérc', 'Bürüs', 'Büssü',
             'Büttös', 'Cakóháza', 'Cák', 'Cece', 'Cegléd', 'Ceglédbercel', 'Celldömölk', 'Cered', 'Cégénydányád',
             'Chernelházadamonya', 'Cibakháza', 'Cigánd', 'Cikó', 'Cirák', 'Csabacsűd', 'Csabaszabadi', 'Csabdi',
             'Csabrendek', 'Csaholc', 'Csajág', 'Csanádalberti', 'Csanádapáca', 'Csanádpalota', 'Csanytelek', 'Csapi',
             'Csapod', 'Csarnóta', 'Csaroda', 'Csataszög', 'Csatár', 'Csatka', 'Csáfordjánosfa', 'Csákány',
             'Csákánydoroszló', 'Csákberény', 'Csákvár', 'Csánig', 'Csány', 'Csányoszró', 'Csárdaszállás', 'Császár',
             'Császártöltés', 'Császló', 'Csátalja', 'Csávoly', 'Csebény', 'Csegöld', 'Csehbánya', 'Csehi',
             'Csehimindszent', 'Csemő', 'Csempeszkopács', 'Csengele', 'Csenger', 'Csengersima', 'Csengerújfalu',
             'Csengőd', 'Csenyéte', 'Csepreg', 'Cserdi', 'Cserénfa', 'Cserépfalu', 'Cserépváralja', 'Cserháthaláp',
             'Cserhátsurány', 'Cserhátszentiván', 'Cserkeszőlő', 'Cserkút', 'Csernely', 'Cserszegtomaj', 'Csertalakos',
             'Csertő', 'Csesznek', 'Csesztreg', 'Csesztve', 'Csetény', 'Csécse', 'Csém', 'Csénye', 'Csép', 'Csépa',
             'Csér', 'Csévharaszt', 'Csibrák', 'Csikéria', 'Csikóstőttős', 'Csikvánd', 'Csincse', 'Csipkerek', 'Csitár',
             'Csobaj', 'Csobád', 'Csobánka', 'Csokonyavisonta', 'Csokvaomány', 'Csolnok', 'Csoma', 'Csomád',
             'Csombárd', 'Csongrád', 'Csonkahegyhát', 'Csonkamindszent', 'Csopak', 'Csorna', 'Csorvás', 'Csókakő',
             'Csólyospálos', 'Csór', 'Csót', 'Csöde', 'Csögle', 'Csökmő', 'Csököly', 'Csömend', 'Csömödér', 'Csömör',
             'Csönge', 'Csörnyeföld', 'Csörög', 'Csörötnek', 'Csősz', 'Csővár', 'Csurgó', 'Csurgónagymarton', 'Cún',
             'Dabas', 'Dabronc', 'Dabrony', 'Dad', 'Dalmand', 'Damak', 'Daraboshegy', 'Darány', 'Darnó', 'Darnózseli',
             'Daruszentmiklós', 'Darvas', 'Dág', 'Dáka', 'Dámóc', 'Dánszentmiklós', 'Dány', 'Dávod', 'Debercsény',
             'Debrecen', 'Debréte', 'Decs', 'Dejtár', 'Demecser', 'Demjén', 'Dencsháza', 'Derecske', 'Derekegyház',
             'Deszk', 'Detek', 'Detk', 'Devecser', 'Dédestapolcsány', 'Dég', 'Délegyháza', 'Dénesfa', 'Dévaványa',
             'Dinnyeberki', 'Diósberény', 'Diósd', 'Diósjenő', 'Dióskál', 'Diósviszló', 'Doba', 'Doboz', 'Dobri',
             'Dobronhegy', 'Domaháza', 'Domaszék', 'Dombegyház', 'Dombiratos', 'Dombóvár', 'Dombrád', 'Domony',
             'Domoszló', 'Dormánd', 'Dorog', 'Dorogháza', 'Dozmat', 'Dóc', 'Döbörhegy', 'Döbröce', 'Döbrököz',
             'Döbrönte', 'Döge', 'Dömös', 'Dömsöd', 'Dör', 'Dörgicse', 'Döröske', 'Dötk', 'Dövény', 'Drágszél',
             'Drávacsehi', 'Drávacsepely', 'Drávafok', 'Drávagárdony', 'Drávaiványi', 'Drávakeresztúr', 'Drávapalkonya',
             'Drávapiski', 'Drávaszabolcs', 'Drávaszerdahely', 'Drávasztára', 'Drávatamási', 'Drégelypalánk', 'Dubicsány',
             'Dudar', 'Duka', 'Dunaalmás', 'Dunabogdány', 'Dunaegyháza', 'Dunafalva', 'Dunaföldvár', 'Dunaharaszti',
             'Dunakeszi', 'Dunakiliti', 'Dunapataj', 'Dunaremete', 'Dunaszeg', 'Dunaszekcső', 'Dunaszentbenedek',
             'Dunaszentgyörgy', 'Dunaszentmiklós', 'Dunaszentpál', 'Dunasziget', 'Dunatetétlen', 'Dunaújváros',
             'Dunavarsány', 'Dunavecse', 'Dusnok', 'Dúzs', 'Ebergőc', 'Ebes', 'Ecseg', 'Ecsegfalva', 'Ecseny', 'Ecser',
             'Ecséd', 'Edde', 'Edelény', 'Edve', 'Eger', 'Egeralja', 'Egeraracsa', 'Egerág', 'Egerbakta', 'Egerbocs',
             'Egercsehi', 'Egerfarmos', 'Egerlövő', 'Egerszalók', 'Egerszólát', 'Egervár', 'Egervölgy', 'Egyed', 'Egyek',
             'Egyházasdengeleg', 'Egyházasfalu', 'Egyházasgerge', 'Egyházasharaszti', 'Egyházashetye', 'Egyházashollós',
             'Egyházaskesző', 'Egyházaskozár', 'Egyházasrádóc', 'Elek', 'Ellend', 'Előszállás', 'Emőd', 'Encs', 'Encsencs',
             'Endrefalva', 'Endrőc', 'Enese', 'Enying', 'Eperjes', 'Eperjeske', 'Eplény', 'Epöl', 'Ercsi', 'Erdőbénye',
             'Erdőhorváti', 'Erdőkertes', 'Erdőkövesd', 'Erdőkürt', 'Erdősmárok', 'Erdősmecske', 'Erdőtarcsa', 'Erdőtelek',
             'Erk', 'Erzsébet', 'Esztár', 'Eszteregnye', 'Esztergályhorváti', 'Esztergom', 'Ete', 'Etes', 'Etyek', 'Écs',
             'Égerszög', 'Érd', 'Érpatak', 'Érsekcsanád', 'Érsekhalma', 'Érsekvadkert', 'Értény', 'Fadd', 'Fajsz',
             'Fancsal', 'Farád', 'Farkasgyepű', 'Farkaslyuk', 'Farmos', 'Fazekasboda', 'Fábiánháza', 'Fábiánsebestyén',
             'Fácánkert', 'Fáj', 'Fedémes', 'Fegyvernek', 'Fehérgyarmat', 'Fehértó', 'Fehérvárcsurgó', 'Feked',
             'Feketeerdő', 'Felcsút', 'Feldebrő', 'Felgyő', 'Felpéc', 'Felsőberecki', 'Felsőcsatár', 'Felsődobsza',
             'Felsőegerszeg', 'Felsőgagy', 'Felsőjánosfa', 'Felsőkelecsény', 'Felsőlajos', 'Felsőmarác', 'Felsőmocsolád',
             'Felsőnána', 'Felsőnyárád', 'Felsőnyék', 'Felsőörs', 'Felsőpakony', 'Felsőpáhok', 'Felsőpetény',
             'Felsőrajk', 'Felsőregmec', 'Felsőszenterzsébet', 'Felsőszentiván', 'Felsőszentmárton', 'Felsőszölnök',
             'Felsőtárkány', 'Felsőtelekes', 'Felsőtold', 'Felsővadász', 'Felsőzsolca', 'Fenyőfő', 'Ferencszállás',
             'Fertőboz', 'Fertőd', 'Fertőendréd', 'Fertőhomok', 'Fertőrákos', 'Fertőszentmiklós', 'Fertőszéplak',
             'Fényeslitke', 'Fiad', 'Filkeháza', 'Fityeház', 'Foktő', 'Folyás', 'Fonó', 'Fony', 'Fonyód', 'Forráskút',
             'Forró', 'Fót', 'Földeák', 'Földes', 'Főnyed', 'Fulókércs', 'Furta', 'Füle', 'Fülesd', 'Fülöp', 'Fülöpháza',
             'Fülöpjakab', 'Fülöpszállás', 'Fülpösdaróc', 'Fürged', 'Füzesabony', 'Füzesgyarmat', 'Füzér',
             'Füzérkajata', 'Füzérkomlós', 'Füzérradvány', 'Füzvölgy', 'Gacsály', 'Gadács', 'Gadány', 'Gadna',
             'Gagyapáti', 'Gagybátor', 'Gagyvendégi', 'Galambok', 'Galgaguta', 'Galgagyörk', 'Galgahévíz', 'Galgamácsa',
             'Galvács', 'Gamás', 'Ganna', 'Gara', 'Garabonc', 'Garadna', 'Garáb', 'Garbolc', 'Garé', 'Gasztony',
             'Gáborján', 'Gáborjánháza', 'Gádoros', 'Gálosfa', 'Gánt', 'Gárdony', 'Gátér', 'Gávavencsellő', 'Gecse',
             'Gelej', 'Gelénes', 'Gellénháza', 'Gelse', 'Gelsesziget', 'Gemzse', 'Gencsapáti', 'Gerde', 'Gerendás',
             'Geresdlak', 'Gerényes', 'Gerjen', 'Gersekarát', 'Geszt', 'Gesztely', 'Geszteréd', 'Géberjén', 'Géderlak',
             'Gégény', 'Gérce', 'Gétye', 'Gic', 'Gige', 'Gilvánfa', 'Girincs', 'Golop', 'Gomba', 'Gombosszeg',
             'Gordisa', 'Gosztola', 'Gógánfa', 'Gór', 'Göd', 'Gödöllő', 'Gödre', 'Gölle', 'Gömörszőlős', 'Gönc',
             'Göncruszka', 'Gönyű', 'Görbeháza', 'Görcsöny', 'Görcsönydoboka', 'Görgeteg', 'Gősfa', 'Grábóc', 'Gulács',
             'Gutorfölde', 'Gyalóka', 'Gyanógeregye', 'Gyarmat', 'Gyál', 'Gyenesdiás', 'Gyepükaján', 'Gyermely',
             'Gyékényes', 'Gyomaendrőd', 'Gyód', 'Gyóró', 'Gyömöre', 'Gyömrő', 'Gyöngyfa', 'Gyöngyös', 'Gyöngyösfalu',
             'Gyöngyöshalász', 'Gyöngyösmellék', 'Gyöngyösoroszi', 'Gyöngyöspata', 'Gyöngyössolymos', 'Gyöngyöstarján',
             'Gyönk', 'Györe', 'Györgytarló', 'Györköny', 'Győr', 'Győrasszonyfa', 'Győrladamér', 'Győröcske',
             'Győrság', 'Győrsövényház', 'Győrszemere', 'Győrtelek', 'Győrújbarát', 'Győrújfalu', 'Győrvár',
             'Győrzámoly', 'Gyugy', 'Gyula', 'Gyulaháza', 'Gyulaj', 'Gyulakeszi', 'Gyúró', 'Gyügye', 'Gyüre',
             'Gyűrűs', 'Hagyárosbörönd', 'Hahót', 'Hajdúbagos', 'Hajdúböszörmény', 'Hajdúdorog', 'Hajdúhadház',
             'Hajdúnánás', 'Hajdúsámson', 'Hajdúszoboszló', 'Hajdúszovát', 'Hajmás', 'Hajmáskér', 'Hajós', 'Halastó',
             'Halászi', 'Halásztelek', 'Halimba', 'Halmaj', 'Halmajugra', 'Halogy', 'Hangács', 'Hangony', 'Hantos',
             'Harasztifalu', 'Harc', 'Harka', 'Harkakötöny', 'Harkány', 'Harsány', 'Harta', 'Hatvan', 'Hács',
             'Háromfa', 'Háromhuta', 'Hárskút', 'Hásságy', 'Hedrehely', 'Hegyesd', 'Hegyeshalom', 'Hegyfalu',
             'Hegyháthodász', 'Hegyhátmaróc', 'Hegyhátsál', 'Hegyhátszentjakab', 'Hegyhátszentmárton',
             'Hegyhátszentpéter', 'Hegykő', 'Hegymagas', 'Hegymeg', 'Hegyszentmárton', 'Hejce', 'Hejőbába',
             'Hejőkeresztúr', 'Hejőkürt', 'Hejőpapi', 'Hejőszalonta', 'Helesfa', 'Helvécia', 'Hencida', 'Hencse',
             'Herceghalom', 'Hercegkút', 'Hercegszántó', 'Herencsény', 'Herend', 'Heresznye', 'Heréd', 'Hermánszeg',
             'Hernád', 'Hernádbűd', 'Hernádcéce', 'Hernádkak', 'Hernádkércs', 'Hernádnémeti', 'Hernádpetri',
             'Hernádszentandrás', 'Hernádszurdok', 'Hernádvécse', 'Hernyék', 'Hetefejércse', 'Hetes', 'Hetvehely',
             'Hetyefő', 'Heves', 'Hevesaranyos', 'Hevesvezekény', 'Hédervár', 'Héhalom', 'Héreg', 'Hét', 'Hévíz',
             'Hévízgyörk', 'Hidas', 'Hidasnémeti', 'Hidegkút', 'Hidegség', 'Hidvégardó', 'Himesháza', 'Himod', 'Hirics',
             'Hobol', 'Hodász', 'Hollád', 'Hollóháza', 'Hollókő', 'Homokbödöge', 'Homokkomárom', 'Homokmégy',
             'Homokszentgyörgy', 'Homorúd', 'Homrogd', 'Hont', 'Horpács', 'Hort', 'Hortobágy', 'Horváthertelend',
             'Horvátlövő', 'Horvátzsidány', 'Hosszúhetény', 'Hosszúpályi', 'Hosszúpereszteg', 'Hosszúvíz',
             'Hosszúvölgy', 'Hosztót', 'Hottó', 'Hódmezővásárhely', 'Hövej', 'Hőgyész', 'Hugyag', 'Hunya',
             'Hunyadfalva', 'Husztót', 'Ibafa', 'Iborfia', 'Ibrány', 'Igal', 'Igar', 'Igrici', 'Iharos', 'Iharosberény',
             'Ikervár', 'Iklad', 'Iklanberény', 'Iklódbördőce', 'Ikrény', 'Iliny', 'Ilk', 'Illocska', 'Imola',
             'Imrehegy', 'Ináncs', 'Inárcs', 'Inke', 'Ipacsfa', 'Ipolydamásd', 'Ipolytarnóc', 'Ipolytölgyes',
             'Ipolyvece', 'Iregszemcse', 'Irota', 'Isaszeg', 'Ispánk', 'Istenmezeje', 'Istvándi', 'Iszkaszentgyörgy',
             'Iszkáz', 'Isztimér', 'Ivád', 'Iván', 'Ivánbattyán', 'Ivánc', 'Iváncsa', 'Ivándárda', 'Izmény', 'Izsák',
             'Izsófalva', 'Jakabszállás', 'Jágónak', 'Ják', 'Jákfa', 'Jákfalva', 'Jákó', 'Jánd', 'Jánkmajtis',
             'Jánoshalma', 'Jánosháza', 'Jánoshida', 'Jánossomorja', 'Járdánháza', 'Jármi', 'Jásd', 'Jászalsószentgyörgy',
             'Jászapáti', 'Jászágó', 'Jászárokszállás', 'Jászberény', 'Jászboldogháza', 'Jászdózsa',
             'Jászfelsőszentgyörgy', 'Jászfényszaru', 'Jászivány', 'Jászjákóhalma', 'Jászkarajenő', 'Jászkisér',
             'Jászladány', 'Jászszentandrás', 'Jászszentlászló', 'Jásztelek', 'Jenő', 'Jéke', 'Jobaháza',
             'Jobbágyi', 'Jósvafő', 'Juta', 'Kaba', 'Kacorlak', 'Kacsóta', 'Kadarkút', 'Kajárpéc', 'Kajászó',
             'Kajdacs', 'Kakasd', 'Kakucs', 'Kalaznó', 'Kallósd', 'Kalocsa', 'Kamond', 'Kamut', 'Kapolcs',
             'Kapoly', 'Kaposfő', 'Kaposgyarmat', 'Kaposhomok', 'Kaposkeresztúr', 'Kaposmérő', 'Kapospula',
             'Kaposszekcső', 'Kaposszerdahely', 'Kaposújlak', 'Kaposvár', 'Kapuvár', 'Karakó', 'Karakószörcsök',
             'Karancsalja', 'Karancsberény', 'Karancskeszi', 'Karancslapujtő', 'Karancsság', 'Karácsond', 'Karád',
             'Karcag', 'Karcsa', 'Kardos', 'Kardoskút', 'Karmacs', 'Karos', 'Kartal', 'Kaskantyú', 'Kastélyosdombó',
             'Kaszaper', 'Kaszó', 'Katafa', 'Katádfa', 'Katymár', 'Kazár', 'Kazincbarcika', 'Kazsok', 'Kács', 'Kákics',
             'Kál', 'Káld', 'Kálló', 'Kállósemjén', 'Kálmáncsa', 'Kálmánháza', 'Káloz', 'Kálócfa', 'Kám', 'Kánó',
             'Kántorjánosi', 'Kány', 'Kánya', 'Kányavár', 'Kápolna', 'Kápolnásnyék', 'Káptalanfa', 'Káptalantóti',
             'Kára', 'Kárász', 'Károlyháza', 'Kásád', 'Kátoly', 'Káva', 'Kávás', 'Kázsmárk', 'Kecel', 'Kecskemét',
             'Kecskéd', 'Kehidakustány', 'Kelebia', 'Kelemér', 'Kelevíz', 'Keléd', 'Kemecse', 'Kemence', 'Kemendollár',
             'Kemeneshőgyész', 'Kemeneskápolna', 'Kemenesmagasi', 'Kemenesmihályfa', 'Kemenespálfa', 'Kemenessömjén',
             'Kemenesszentmárton', 'Kemenesszentpéter', 'Kemestaródfa', 'Keménfa', 'Kemse', 'Kenderes', 'Kenéz',
             'Kenézlő', 'Kengyel', 'Kenyeri', 'Kercaszomor', 'Kercseliget', 'Kerecsend', 'Kerecseny', 'Kerekegyháza',
             'Kereki', 'Kerepes', 'Keresztéte', 'Kerékteleki', 'Kerkabarabás', 'Kerkafalva', 'Kerkakutas',
             'Kerkaszentkirály', 'Kerkateskánd', 'Kerkáskápolna', 'Kerta', 'Kertészsziget', 'Keszeg', 'Kesznyéten',
             'Keszőhidegkút', 'Keszthely', 'Kesztölc', 'Keszü', 'Kevermes', 'Kék', 'Kékcse', 'Kéked', 'Kékesd',
             'Kékkút', 'Kéleshalom', 'Kémes', 'Kérsemjén', 'Kétbodony', 'Kétegyháza', 'Kéthely', 'Kétpó', 'Kétsoprony',
             'Kétújfalu', 'Kétvölgy', 'Kéty', 'Kilimán', 'Kimle', 'Kincsesbánya', 'Királd', 'Királyegyháza',
             'Királyhegyes', 'Királyszentistván', 'Kisapáti', 'Kisapostag', 'Kisar', 'Kisasszond', 'Kisasszonyfa',
             'Kisbabot', 'Kisbajcs', 'Kisbajom', 'Kisbágyon', 'Kisbárapáti', 'Kisbárkány', 'Kisberény', 'Kisberzseny',
             'Kisbeszterce', 'Kisbér', 'Kisbodak', 'Kisbucsa', 'Kisbudmér', 'Kiscsehi', 'Kiscsécs', 'Kiscsősz',
             'Kisdér', 'Kisdobsza', 'Kisdombegyház', 'Kisdorog', 'Kisecset', 'Kisfalud', 'Kisfüzes', 'Kisgörbő',
             'Kisgyalán', 'Kisgyőr', 'Kishajmás', 'Kisharsány', 'Kishartyán', 'Kisherend', 'Kishódos', 'Kishuta',
             'Kisigmánd', 'Kisjakabfalva', 'Kiskassa', 'Kiskinizs', 'Kiskorpád', 'Kisköre', 'Kiskőrös',
             'Kiskunfélegyháza', 'Kiskunhalas', 'Kiskunlacháza', 'Kiskunmajsa', 'Kiskutas', 'Kisláng', 'Kisléta',
             'Kislippó', 'Kislőd', 'Kismarja', 'Kismaros', 'Kismányok', 'Kisnamény', 'Kisnána', 'Kisnémedi', 'Kisnyárád',
             'Kisoroszi', 'Kispalád', 'Kispáli', 'Kispirit', 'Kisrákos', 'Kisrécse', 'Kisrozvágy', 'Kissikátor', 'Kissomlyó',
             'Kisszállás', 'Kisszekeres', 'Kisszentmárton', 'Kisszékely', 'Kissziget', 'Kisszőlős', 'Kistamási',
             'Kistapolca', 'Kistarcsa', 'Kistelek', 'Kistokaj', 'Kistolmács', 'Kistormás', 'Kistótfalu', 'Kisunyom',
             'Kisújszállás', 'Kisvarsány', 'Kisvaszar', 'Kisvárda', 'Kisvásárhely', 'Kisvejke', 'Kiszombor',
             'Kiszsidány', 'Klárafalva', 'Kocs', 'Kocsér', 'Kocsola', 'Kocsord', 'Kokad', 'Kolontár', 'Komádi', 'Komárom',
             'Komjáti', 'Komló', 'Komlódtótfalu', 'Komlósd', 'Komlóska', 'Komoró', 'Kompolt', 'Kondorfa', 'Kondoros',
             'Kondó', 'Konyár', 'Koppányszántó', 'Korlát', 'Koroncó', 'Kosd', 'Kovácshida', 'Kovácsszénája',
             'Kovácsvágás', 'Kozárd', 'Kozármisleny', 'Kozmadombja', 'Kóka', 'Kóny', 'Kópháza', 'Kórós', 'Kóspallag',
             'Kótaj', 'Köblény', 'Köcsk', 'Kökény', 'Kölcse', 'Kölesd', 'Kölked', 'Kömlő', 'Kömlőd', 'Kömörő',
             'Kömpöc', 'Körmend', 'Környe', 'Köröm', 'Körösladány', 'Körösnagyharsány', 'Körösszakál', 'Körösszegapáti',
             'Köröstarcsa', 'Körösújfalu', 'Kötcse', 'Kötegyán', 'Kövegy', 'Köveskál', 'Kőkút', 'Kőröshegy',
             'Kőröstetétlen', 'Kőszárhegy', 'Kőszeg', 'Kőszegdoroszló', 'Kőszegpaty', 'Kőszegszerdahely', 'Kőtelek',
             'Kővágóörs', 'Kővágószőlős', 'Kővágótőttős', 'Krasznokvajda', 'Kulcs', 'Kunadacs', 'Kunágota', 'Kunbaja',
             'Kunbaracs', 'Kuncsorba', 'Kunfehértó', 'Kunhegyes', 'Kunmadaras', 'Kunpeszér', 'Kunszállás', 'Kunszentmárton',
             'Kunszentmiklós', 'Kunsziget', 'Kup', 'Kupa', 'Kurd', 'Kurityán', 'Kustánszeg', 'Kutas', 'Kutasó',
             'Kübekháza', 'Külsősárd', 'Külsővat', 'Küngös', 'Lad', 'Ladánybene', 'Lajoskomárom', 'Lajosmizse', 'Lak',
             'Lakhegy', 'Lakitelek', 'Lakócsa', 'Lapáncsa', 'Laskod', 'Lasztonya', 'Lábatlan', 'Lábod', 'Lácacséke',
             'Ládbesenyő', 'Lánycsók', 'Lápafő', 'Látrány', 'Lázi', 'Leányfalu', 'Leányvár', 'Legénd', 'Legyesbénye',
             'Lendvadedes', 'Lendvajakabfa', 'Lengyel', 'Lengyeltóti', 'Lenti', 'Lepsény', 'Lesencefalu', 'Lesenceistvánd',
             'Lesencetomaj', 'Letenye', 'Letkés', 'Levelek', 'Levél', 'Lébény', 'Léh', 'Lénárddaróc', 'Létavértes',
             'Libickozma', 'Lickóvadamos', 'Liget', 'Ligetfalva', 'Lipót', 'Lippó', 'Liptód', 'Lispeszentadorján',
             'Liszó', 'Litér', 'Litka', 'Litke', 'Lothárd', 'Lovas', 'Lovasberény', 'Lovászhetény', 'Lovászi',
             'Lovászpatona', 'Lócs', 'Lókút', 'Lónya', 'Lórév', 'Lövő', 'Lövőpetri', 'Lőkösháza', 'Lőrinci', 'Lucfalva',
             'Ludas', 'Ludányhalászi', 'Lukácsháza', 'Lulla', 'Lúzsok', 'Madaras', 'Madocsa', 'Maglóca', 'Maglód',
             'Magosliget', 'Magy', 'Magyaralmás', 'Magyaratád', 'Magyarbánhegyes', 'Magyarbóly', 'Magyarcsanád',
             'Magyardombegyház', 'Magyaregregy', 'Magyaregres', 'Magyarföld', 'Magyargencs', 'Magyargéc',
             'Magyarhertelend', 'Magyarhomorog', 'Magyarkeresztúr', 'Magyarkeszi', 'Magyarlak', 'Magyarlukafa',
             'Magyarmecske', 'Magyarnádalja', 'Magyarnándor', 'Magyarpolány', 'Magyarsarlós', 'Magyarszecsőd',
             'Magyarszentmiklós', 'Magyarszerdahely', 'Magyarszék', 'Magyarszombatfa', 'Magyartelek', 'Majosháza',
             'Majs', 'Makád', 'Makkoshotyka', 'Maklár', 'Makó', 'Malomsok', 'Maráza', 'Marcalgergelyi', 'Marcali',
             'Marcaltő', 'Markaz', 'Markotabödöge', 'Markóc', 'Maroslele', 'Maróc', 'Marócsa', 'Martfű', 'Martonfa',
             'Martonvásár', 'Martonyi', 'Matty', 'Mád', 'Mágocs', 'Mályi', 'Mályinka', 'Mánd', 'Mándok', 'Mánfa',
             'Mány', 'Márfa', 'Máriahalom', 'Máriakálnok', 'Máriakéménd', 'Márianosztra', 'Máriapócs', 'Márkháza',
             'Márkó', 'Márok', 'Márokföld', 'Márokpapi', 'Mártély', 'Mátészalka', 'Mátételke', 'Mátraballa', 'Mátraderecske',
             'Mátramindszent', 'Mátranovák', 'Mátraszele', 'Mátraszentimre', 'Mátraszőlős', 'Mátraterenye',
             'Mátraverebély', 'Mátyásdomb', 'Mátyus', 'Máza', 'Mecseknádasd', 'Mecsekpölöske', 'Mecsér',
             'Medgyesbodzás', 'Medgyesegyháza', 'Medina', 'Meggyeskovácsi', 'Megyaszó', 'Megyehid', 'Megyer',
             'Mekényes', 'Mencshely', 'Mende', 'Merenye', 'Mernye', 'Mersevát', 'Mesterháza', 'Mesteri',
             'Mesterszállás', 'Meszes', 'Meszlen', 'Mesztegnyő', 'Mezőberény', 'Mezőcsát', 'Mezőcsokonya',
             'Meződ', 'Mezőfalva', 'Mezőgyán', 'Mezőhegyes', 'Mezőhék', 'Mezőkeresztes', 'Mezőkomárom',
             'Mezőkovácsháza', 'Mezőkövesd', 'Mezőladány', 'Mezőlak', 'Mezőnagymihály', 'Mezőnyárád', 'Mezőörs',
             'Mezőpeterd', 'Mezősas', 'Mezőszemere', 'Mezőszentgyörgy', 'Mezőszilas', 'Mezőtárkány', 'Mezőtúr',
             'Mezőzombor', 'Méhkerék', 'Méhtelek', 'Mélykút', 'Méra', 'Mérges', 'Mérk', 'Miháld', 'Mihályfa',
             'Mihálygerge', 'Mihályháza', 'Mihályi', 'Mike', 'Mikebuda', 'Mikekarácsonyfa', 'Mikepércs', 'Miklósi',
             'Mikosszéplak', 'Mikófalva', 'Mikóháza', 'Milejszeg', 'Milota', 'Mindszent', 'Mindszentgodisa',
             'Mindszentkálla', 'Misefa', 'Miske', 'Miskolc', 'Miszla', 'Mocsa', 'Mogyoród', 'Mogyorósbánya',
             'Mogyoróska', 'Moha', 'Mohács', 'Mohora', 'Molnaszecsőd', 'Molnári', 'Molvány', 'Monaj', 'Monok',
             'Monor', 'Monostorapáti', 'Monostorpályi', 'Monoszló', 'Monyoród', 'Mosdós', 'Mosonmagyaróvár',
             'Mosonszentmiklós', 'Mosonszolnok', 'Mozsgó', 'Mónosbél', 'Mór', 'Mórahalom', 'Mórágy', 'Móricgát',
             'Mórichida', 'Mőcsény', 'Mucsfa', 'Mucsi', 'Muhi', 'Murakeresztúr', 'Murarátka', 'Muraszemenye', 'Murga',
             'Murony', 'Múcsony', 'Nadap', 'Nagyacsád', 'Nagyalásony', 'Nagyar', 'Nagyatád', 'Nagybajcs', 'Nagybajom',
             'Nagybakónak', 'Nagybaracska', 'Nagybarca', 'Nagybánhegyes', 'Nagybárkány', 'Nagyberény', 'Nagyberki',
             'Nagybörzsöny', 'Nagybudmér', 'Nagycenk', 'Nagycsány', 'Nagycsepely', 'Nagycserkesz', 'Nagycsécs',
             'Nagydém', 'Nagydobos', 'Nagydobsza', 'Nagydorog', 'Nagyecsed', 'Nagyesztergár', 'Nagyér', 'Nagyfüged',
             'Nagygeresd', 'Nagygörbő', 'Nagygyimót', 'Nagyhajmás', 'Nagyhalász', 'Nagyharsány', 'Nagyhegyes', 'Nagyhódos',
             'Nagyhuta', 'Nagyigmánd', 'Nagyiván', 'Nagykamarás', 'Nagykanizsa', 'Nagykapornak', 'Nagykarácsony', 'Nagykálló',
             'Nagykáta', 'Nagykereki', 'Nagykeresztúr', 'Nagykinizs', 'Nagykorpád', 'Nagykovácsi', 'Nagykozár', 'Nagykónyi',
             'Nagykökényes', 'Nagykölked', 'Nagykörű', 'Nagykőrös', 'Nagykutas', 'Nagylak', 'Nagylengyel', 'Nagylóc',
             'Nagylók', 'Nagylózs', 'Nagymaros', 'Nagymágocs', 'Nagymányok', 'Nagymizdó', 'Nagynyárád', 'Nagyoroszi',
             'Nagypall', 'Nagypáli', 'Nagypeterd', 'Nagypirit', 'Nagyrada', 'Nagyrábé', 'Nagyrákos', 'Nagyrécse',
             'Nagyréde', 'Nagyrév', 'Nagyrozvágy', 'Nagysáp', 'Nagysimonyi', 'Nagyszakácsi', 'Nagyszekeres',
             'Nagyszentjános', 'Nagyszékely', 'Nagyszénás', 'Nagyszokoly', 'Nagytarcsa', 'Nagytálya', 'Nagytevel',
             'Nagytilaj', 'Nagytótfalu', 'Nagytőke', 'Nagyút', 'Nagyvarsány', 'Nagyváty', 'Nagyvázsony', 'Nagyvejke',
             'Nagyveleg', 'Nagyvenyim', 'Nagyvisnyó', 'Nak', 'Napkor', 'Narda', 'Naszály', 'Nábrád', 'Nádasd', 'Nádasdladány',
             'Nádudvar', 'Nágocs', 'Nárai', 'Nekézseny', 'Nemesapáti', 'Nemesbikk', 'Nemesborzova', 'Nemesbőd', 'Nemesbük',
             'Nemescsó', 'Nemesdéd', 'Nemesgörzsöny', 'Nemesgulács', 'Nemeshany', 'Nemeshetés', 'Nemeske', 'Nemeskeresztúr',
             'Nemeskér', 'Nemeskisfalud', 'Nemeskocs', 'Nemeskolta', 'Nemesládony', 'Nemesmedves', 'Nemesnádudvar',
             'Nemesnép', 'Nemespátró', 'Nemesrádó', 'Nemesrempehollós', 'Nemessándorháza', 'Nemesszalók',
             'Nemesszentandrás', 'Nemesvámos', 'Nemesvid', 'Nemesvita', 'Nemti', 'Neszmély', 'Négyes', 'Németbánya',
             'Németfalu', 'Németkér', 'Nézsa', 'Nick', 'Nikla', 'Noszlop', 'Noszvaj', 'Nova', 'Novaj', 'Novajidrány',
             'Nógrád', 'Nógrádkövesd', 'Nógrádmarcal', 'Nógrádmegyer', 'Nógrádsáp', 'Nógrádsipek', 'Nógrádszakál', 'Nóráp',
             'Nőtincs', 'Nyalka', 'Nyárád', 'Nyáregyháza', 'Nyárlőrinc', 'Nyársapát', 'Nyergesújfalu', 'Nyékládháza',
             'Nyésta', 'Nyim', 'Nyirád', 'Nyíracsád', 'Nyíradony', 'Nyírábrány', 'Nyírbátor', 'Nyírbéltek',
             'Nyírbogát', 'Nyírbogdány', 'Nyírcsaholy', 'Nyírcsászári', 'Nyírderzs', 'Nyíregyháza', 'Nyírgelse',
             'Nyírgyulaj', 'Nyíri', 'Nyíribrony', 'Nyírjákó', 'Nyírkarász', 'Nyírkáta', 'Nyírkércs', 'Nyírlövő',
             'Nyírlugos', 'Nyírmada', 'Nyírmártonfalva', 'Nyírmeggyes', 'Nyírmihálydi', 'Nyírparasznya', 'Nyírpazony',
             'Nyírpilis', 'Nyírtass', 'Nyírtelek', 'Nyírtét', 'Nyírtura', 'Nyírvasvári', 'Nyomár', 'Nyőgér', 'Nyugotszenterzsébet',
             'Nyúl', 'Okány', 'Okorág', 'Okorvölgy', 'Olasz', 'Olaszfa', 'Olaszfalu', 'Olaszliszka', 'Olcsva',
             'Olcsvaapáti', 'Old', 'Oltárc', 'Onga', 'Orbányosfa', 'Orci', 'Ordacsehi', 'Ordas', 'Orfalu', 'Orfű',
             'Orgovány', 'Ormándlak', 'Ormosbánya', 'Orosháza', 'Oroszi', 'Oroszlány', 'Oroszló', 'Orosztony',
             'Ortaháza', 'Osli', 'Ostffyasszonyfa', 'Ostoros', 'Oszkó', 'Oszlár', 'Osztopán', 'Ozmánbük', 'Ozora',
             'Óbarok', 'Óbánya', 'Óbudavár', 'Ócsa', 'Ócsárd', 'Ófalu', 'Ófehértó', 'Óföldeák', 'Óhid', 'Ólmod',
             'Ónod', 'Ópályi', 'Ópusztaszer', 'Ózd', 'Ózdfalu', 'Öcs', 'Öcsöd', 'Ököritófülpös', 'Ölbő', 'Ömböly',
             'Öregcsertő', 'Öreglak', 'Örkény', 'Örményes', 'Örménykút', 'Örvényes', 'Öskü', 'Öttevény', 'Öttömös',
             'Ötvöskónyi', 'Őcsény', 'Őr', 'Őrbottyán', 'Őrhalom', 'Őrimagyarósd', 'Őriszentpéter', 'Őrtilos',
             'Ősagárd', 'Ősi', 'Pacsa', 'Padár', 'Pakod', 'Paks', 'Palé', 'Palkonya', 'Palotabozsok', 'Palotás',
             'Paloznak', 'Pamlény', 'Pamuk', 'Pankasz', 'Pannonhalma', 'Panyola', 'Pap', 'Papkeszi', 'Papos',
             'Parasznya', 'Parád', 'Parádsasvár', 'Paszab', 'Pat', 'Patak', 'Patalom', 'Patapoklosi', 'Patca',
             'Patosfa', 'Patvarc', 'Pácin', 'Pácsony', 'Páhi', 'Páka', 'Pákozd', 'Pálfa', 'Pálfiszeg', 'Pálháza',
             'Páli', 'Pálmajor', 'Pálmonostora', 'Pánd', 'Pányok', 'Pápa', 'Pápadereske', 'Pápakovácsi', 'Pápasalamon',
             'Pápateszér', 'Pápoc', 'Páprád', 'Pásztori', 'Pásztó', 'Pátka', 'Pátroha', 'Páty', 'Pátyod', 'Pázmánd',
             'Pázmándfalu', 'Pecöl', 'Pellérd', 'Penc', 'Penészlek', 'Penyige', 'Perbál', 'Pere', 'Perecse', 'Pereked',
             'Perenye', 'Peresznye', 'Pereszteg', 'Perkáta', 'Perkupa', 'Perőcsény', 'Peterd', 'Pethőhenye',
             'Petneháza', 'Petőfibánya', 'Petőfiszállás', 'Petőháza', 'Petőmihályfa', 'Petrikeresztúr', 'Petrivente',
             'Pettend', 'Pécel', 'Pécs', 'Pécsbagota', 'Pécsdevecser', 'Pécsely', 'Pécsudvard', 'Pécsvárad', 'Pély',
             'Pénzesgyőr', 'Pér', 'Péterhida', 'Péteri', 'Pétervására', 'Pétfürdő', 'Piliny', 'Pilis',
             'Pilisborosjenő', 'Piliscsaba', 'Piliscsév', 'Pilisjászfalu', 'Pilismarót', 'Pilisszántó',
             'Pilisszentiván', 'Pilisszentkereszt', 'Pilisszentlászló', 'Pilisvörösvár', 'Pincehely', 'Pinkamindszent',
             'Pinnye', 'Piricse', 'Pirtó', 'Piskó', 'Pitvaros', 'Pocsaj', 'Pogány', 'Pogányszentpéter', 'Polány',
             'Polgár', 'Polgárdi', 'Pomáz', 'Porcsalma', 'Pornóapáti', 'Poroszló', 'Porpác', 'Porrog',
             'Porrogszentkirály', 'Porrogszentpál', 'Porva', 'Potony', 'Potyond', 'Pócsa', 'Pócsmegyer', 'Pócspetri',
             'Pókaszepetk', 'Pórszombat', 'Pósfa', 'Pölöske', 'Pölöskefő', 'Pörböly', 'Pördefölde', 'Pötréte',
             'Prügy', 'Pula', 'Pusztaapáti', 'Pusztaberki', 'Pusztacsalád', 'Pusztacsó', 'Pusztadobos', 'Pusztaederics',
             'Pusztafalu', 'Pusztaföldvár', 'Pusztahencse', 'Pusztakovácsi', 'Pusztamagyaród', 'Pusztamérges',
             'Pusztamiske', 'Pusztamonostor', 'Pusztaottlaka', 'Pusztaradvány', 'Pusztaszabolcs', 'Pusztaszemes',
             'Pusztaszentlászló', 'Pusztaszer', 'Pusztavacs', 'Pusztavám', 'Pusztazámor', 'Putnok', 'Püski',
             'Püspökhatvan', 'Püspökladány', 'Püspökmolnári', 'Püspökszilágy', 'Radostyán', 'Ragály', 'Rajka',
             'Rakaca', 'Rakacaszend', 'Rakamaz', 'Ramocsa', 'Ramocsaháza', 'Raposka', 'Ravazd', 'Rábacsanak',
             'Rábacsécsény', 'Rábagyarmat', 'Rábahidvég', 'Rábakecöl', 'Rábapatona', 'Rábapaty', 'Rábapordány',
             'Rábasebes', 'Rábaszentandrás', 'Rábaszentmihály', 'Rábaszentmiklós', 'Rábatamási', 'Rábatöttös',
             'Rábcakapi', 'Rácalmás', 'Ráckeresztúr', 'Ráckeve', 'Rád', 'Rádfalva', 'Rádóckölked', 'Rákóczibánya',
             'Rákóczifalva', 'Rákócziújfalu', 'Ráksi', 'Rápolt', 'Rásonysápberencs', 'Rátka', 'Rátót', 'Recsk',
             'Regenye', 'Regéc', 'Regöly', 'Remeteszőlős', 'Resznek', 'Rezi', 'Réde', 'Rédics', 'Rém', 'Répáshuta',
             'Répcelak', 'Répceszemere', 'Répceszentgyörgy', 'Répcevis', 'Rétalap', 'Rétközberencs', 'Rétság',
             'Révfülöp', 'Révleányvár', 'Ricse', 'Rigács', 'Rigyác', 'Rimóc', 'Rinyabesenyő', 'Rinyakovácsi',
             'Rinyaszentkirály', 'Rinyaújlak', 'Rinyaújnép', 'Rohod', 'Románd', 'Romhány', 'Romonya', 'Rozsály',
             'Rózsafa', 'Rózsaszentmárton', 'Röjtökmuzsaj', 'Rönök', 'Röszke', 'Rudabánya', 'Rudolftelep', 'Rum',
             'Ruzsa', 'Sajóbábony', 'Sajóecseg', 'Sajógalgóc', 'Sajóhidvég', 'Sajóivánka', 'Sajókaza', 'Sajókápolna',
             'Sajókeresztúr', 'Sajólád', 'Sajólászlófalva', 'Sajómercse', 'Sajónémeti', 'Sajóörös', 'Sajópálfala',
             'Sajópetri', 'Sajópüspöki', 'Sajósenye', 'Sajószentpéter', 'Sajószöged', 'Sajóvámos', 'Sajóvelezd',
             'Sajtoskál', 'Salföld', 'Salgótarján', 'Salköveskút', 'Salomvár', 'Sand', 'Sarkad', 'Sarkadkeresztúr',
             'Sarród', 'Sarud', 'Ságújfalu', 'Ságvár', 'Sály', 'Sámod', 'Sámsonháza', 'Sándorfalva', 'Sántos', 'Sáp',
             'Sárazsadány', 'Sáránd', 'Sárbogárd', 'Sáregres', 'Sárfimizdó', 'Sárhida', 'Sárisáp', 'Sárkeresztes',
             'Sárkeresztúr', 'Sárkeszi', 'Sármellék', 'Sárok', 'Sárosd', 'Sárospatak', 'Sárpilis', 'Sárrétudvari',
             'Sárszentágota', 'Sárszentlőrinc', 'Sárszentmihály', 'Sárvár', 'Sásd', 'Sáska', 'Sáta', 'Sátoraljaújhely',
             'Sátorhely', 'Sávoly', 'Segesd', 'Sellye', 'Selyeb', 'Semjén', 'Semjénháza', 'Seregélyes', 'Serényfalva',
             'Sé', 'Sénye', 'Sényő', 'Sérsekszőlős', 'Sikátor', 'Siklós', 'Siklósbodony', 'Siklósnagyfalu', 'Sima',
             'Simaság', 'Simonfa', 'Simontornya', 'Sióagárd', 'Siófok', 'Siójut', 'Sirok', 'Sitke', 'Sobor', 'Sokorópátka',
             'Solt', 'Soltszentimre', 'Soltvadkert', 'Solymár', 'Som', 'Somberek', 'Somlójenő', 'Somlószőlős',
             'Somlóvásárhely', 'Somlóvecse', 'Somodor', 'Somogyacsa', 'Somogyapáti', 'Somogyaracs', 'Somogyaszaló',
             'Somogybabod', 'Somogybükkösd', 'Somogycsicsó', 'Somogydöröcske', 'Somogyegres', 'Somogyfajsz', 'Somogygeszti',
             'Somogyhatvan', 'Somogyhárságy', 'Somogyjád', 'Somogymeggyes', 'Somogysámson', 'Somogysárd', 'Somogysimonyi',
             'Somogyszentpál', 'Somogyszil', 'Somogyszob', 'Somogytúr', 'Somogyudvarhely', 'Somogyvámos', 'Somogyvár',
             'Somogyviszló', 'Somogyzsitfa', 'Sonkád', 'Soponya', 'Sopron', 'Sopronhorpács', 'Sopronkövesd',
             'Sopronnémeti', 'Sorkifalud', 'Sorkikápolna', 'Sormás', 'Sorokpolány', 'Sóly', 'Sóshartyán', 'Sóskút',
             'Sóstófalva', 'Sósvertike', 'Sótony', 'Söjtör', 'Söpte', 'Söréd', 'Sukoró', 'Sumony', 'Surd', 'Súr',
             'Sükösd', 'Sülysáp', 'Sümeg', 'Sümegcsehi', 'Sümegprága', 'Süttő', 'Szabadbattyán', 'Szabadegyháza',
             'Szabadhidvég', 'Szabadi', 'Szabadkígyós', 'Szabadszállás', 'Szabadszentkirály', 'Szabás', 'Szabolcs',
             'Szabolcsbáka', 'Szabolcsveresmart', 'Szada', 'Szajk', 'Szajla', 'Szajol', 'Szakadát', 'Szakácsi', 'Szakáld',
             'Szakály', 'Szakcs', 'Szakmár', 'Szaknyér', 'Szakoly', 'Szakony', 'Szakonyfalu', 'Szalafő', 'Szalapa',
             'Szalaszend', 'Szalatnak', 'Szalánta', 'Szalkszentmárton', 'Szalmatercs', 'Szalonna', 'Szamosangyalos',
             'Szamosbecs', 'Szamoskér', 'Szamossályi', 'Szamosszeg', 'Szamostatárfalva', 'Szamosújlak', 'Szanda',
             'Szank', 'Szany', 'Szaporca', 'Szarvas', 'Szarvasgede', 'Szarvaskend', 'Szarvaskő', 'Szatmárcseke',
             'Szatta', 'Szatymaz', 'Szava', 'Szágy', 'Szákszend', 'Szálka', 'Szántód', 'Szápár', 'Szár', 'Szárazd',
             'Szárász', 'Szárföld', 'Szárliget', 'Szászberek', 'Szászfa', 'Szászvár', 'Szátok', 'Százhalombatta',
             'Szebény', 'Szederkény', 'Szedres', 'Szeged', 'Szegerdő', 'Szeghalom', 'Szegi', 'Szegilong', 'Szegvár',
             'Szekszárd', 'Szeleste', 'Szelevény', 'Szellő', 'Szemely', 'Szemenye', 'Szemere', 'Szendehely', 'Szendrő',
             'Szendrőlád', 'Szenna', 'Szenta', 'Szentantalfa', 'Szentbalázs', 'Szentbékkálla', 'Szentborbás', 'Szentdénes',
             'Szentdomonkos', 'Szente', 'Szentegát', 'Szentendre', 'Szentes', 'Szentgál', 'Szentgáloskér',
             'Szentgotthárd', 'Szentgyörgyvár', 'Szentgyörgyvölgy', 'Szentimrefalva', 'Szentistván', 'Szentistvánbaksa',
             'Szentjakabfa', 'Szentkatalin', 'Szentkirály', 'Szentkirályszabadja', 'Szentkozmadombja', 'Szentlászló',
             'Szentliszló', 'Szentlőrinc', 'Szentlőrinckáta', 'Szentmargitfalva', 'Szentmártonkáta', 'Szentpéterfa',
             'Szentpéterfölde', 'Szentpéterszeg', 'Szentpéterúr', 'Szenyér', 'Szepetnek', 'Szerecseny', 'Szeremle',
             'Szerencs', 'Szerep', 'Szergény', 'Szécsénke', 'Szécsény', 'Szécsényfelfalu', 'Szécsisziget', 'Székely',
             'Székelyszabar', 'Székesfehérvár', 'Székkutas', 'Szigetbecse', 'Szigetcsép', 'Szigethalom', 'Szigetmonostor',
             'Szigetszentmárton', 'Szigetszentmiklós', 'Szigetújfalu', 'Szigetvár', 'Szigliget', 'Szihalom', 'Szijártóháza',
             'Szikszó', 'Szil', 'Szilaspogony', 'Szilágy', 'Szilsárkány', 'Szilvágy', 'Szilvás', 'Szilvásszentmárton',
             'Szilvásvárad', 'Szin', 'Szinpetri', 'Szirák', 'Szirmabesenyő', 'Szob', 'Szokolya', 'Szolnok', 'Szombathely',
             'Szomolya', 'Szomor', 'Szomód', 'Szorgalmatos', 'Szorosad', 'Szólád', 'Szögliget', 'Szörény', 'Szőc',
             'Szőce', 'Sződ', 'Sződliget', 'Szőke', 'Szőkedencs', 'Szőkéd', 'Szőlősardó', 'Szőlősgyörök', 'Szuha',
             'Szuhafő', 'Szuhakálló', 'Szuhogy', 'Szulimán', 'Szulok', 'Szurdokpüspöki', 'Szúcs', 'Szügy', 'Szűcsi',
             'Szűr', 'Tab', 'Tabajd', 'Tabdi', 'Tagyon', 'Tahitótfalu', 'Takácsi', 'Taksony', 'Taktabáj', 'Taktaharkány',
             'Taktakenéz', 'Taktaszada', 'Taliándörögd', 'Tamási', 'Tanakajd', 'Tapolca', 'Tapsony', 'Tar', 'Tarany',
             'Tarcal', 'Tard', 'Tardona', 'Tardos', 'Tarhos', 'Tarján', 'Tarjánpuszta', 'Tarnabod', 'Tarnalelesz',
             'Tarnaméra', 'Tarnaörs', 'Tarnaszentmária', 'Tarnaszentmiklós', 'Tarnazsadány', 'Tarpa', 'Tarrós', 'Tass',
             'Taszár', 'Tata', 'Tatabánya', 'Tataháza', 'Tatárszentgyörgy', 'Táborfalva', 'Tác', 'Tákos', 'Tállya', 'Táp',
             'Tápióbicske', 'Tápiógyörgye', 'Tápióság', 'Tápiószecső', 'Tápiószele', 'Tápiószentmárton', 'Tápiószőlős',
             'Táplánszentkereszt', 'Tápszentmiklós', 'Tárkány', 'Tárnok', 'Tárnokréti', 'Táska', 'Tát', 'Tázlár', 'Teklafalu',
             'Telekes', 'Telekgerendás', 'Teleki', 'Település név', 'Telki', 'Telkibánya', 'Tengelic', 'Tengeri', 'Tengőd',
             'Tenk', 'Terem', 'Tereske', 'Teresztenye', 'Terény', 'Terpes', 'Teskánd', 'Tetétlen', 'Tevel', 'Téglás', 'Tékes',
             'Tényő', 'Tépe', 'Tés', 'Tésa', 'Tésenfa', 'Téseny', 'Tét', 'Tibolddaróc', 'Tiborszállás', 'Tihany', 'Tikos',
             'Tilaj', 'Timár', 'Tinnye', 'Tiszaadony', 'Tiszaalpár', 'Tiszabábolna', 'Tiszabecs', 'Tiszabercel', 'Tiszabezdéd',
             'Tiszabő', 'Tiszabura', 'Tiszacsege', 'Tiszacsermely', 'Tiszacsécse', 'Tiszadada', 'Tiszaderzs', 'Tiszadob',
             'Tiszadorogma', 'Tiszaeszlár', 'Tiszaföldvár', 'Tiszafüred', 'Tiszagyenda', 'Tiszagyulaháza', 'Tiszaigar',
             'Tiszainoka', 'Tiszajenő', 'Tiszakanyár', 'Tiszakarád', 'Tiszakerecseny', 'Tiszakeszi', 'Tiszakécske',
             'Tiszakóród', 'Tiszakürt', 'Tiszaladány', 'Tiszalök', 'Tiszalúc', 'Tiszamogyorós', 'Tiszanagyfalu', 'Tiszanána',
             'Tiszaörs', 'Tiszapalkonya', 'Tiszapüspöki', 'Tiszarád', 'Tiszaroff', 'Tiszasas', 'Tiszasüly', 'Tiszaszalka',
             'Tiszaszentimre', 'Tiszaszentmárton', 'Tiszasziget', 'Tiszaszőlős', 'Tiszatardos', 'Tiszatarján', 'Tiszatelek',
             'Tiszatenyő', 'Tiszaug', 'Tiszaújváros', 'Tiszavalk', 'Tiszavasvári', 'Tiszavárkony', 'Tiszavid', 'Tisztaberek',
             'Tivadar', 'Tokaj', 'Tokod', 'Tokodaltáró', 'Tokorcs', 'Tolcsva', 'Told', 'Tolmács', 'Tolna', 'Tolnanémedi',
             'Tomajmonostora', 'Tomor', 'Tompa', 'Tompaládony', 'Tordas', 'Tormafölde', 'Tormás', 'Tormásliget',
             'Tornabarakony', 'Tornakápolna', 'Tornanádaska', 'Tornaszentandrás', 'Tornaszentjakab', 'Tornyiszentmiklós',
             'Tornyosnémeti', 'Tornyospálca', 'Torony', 'Torvaj', 'Tóalmás', 'Tófalu', 'Tófej', 'Tófű', 'Tószeg',
             'Tótkomlós', 'Tótszentgyörgy', 'Tótszentmárton', 'Tótszerdahely', 'Tótújfalu', 'Tótvázsony', 'Tök', 'Tököl',
             'Töltéstava', 'Tömörd', 'Tömörkény', 'Törökbálint', 'Törökkoppány', 'Törökszentmiklós', 'Törtel',
             'Töttös', 'Trizs', 'Tunyogmatolcs', 'Tura', 'Tuzsér', 'Túristvándi', 'Túrkeve', 'Túrony', 'Túrricse',
             'Türje', 'Tüskevár', 'Tyukod', 'Udvar', 'Udvari', 'Ugod', 'Ukk', 'Und', 'Uppony', 'Ura', 'Uraiújfalu',
             'Uszka', 'Uszód', 'Uzsa', 'Újbarok', 'Újcsanálos', 'Újdombrád', 'Újfehértó', 'Újhartyán', 'Újiráz', 'Újireg',
             'Újkenéz', 'Újkér', 'Újkígyós', 'Újlengyel', 'Újléta', 'Újlőrincfalva', 'Újpetre', 'Újrónafő', 'Újsolt',
             'Újszalonta', 'Újszász', 'Újszentiván', 'Újszentmargita', 'Újszilvás', 'Újtelek', 'Újtikos', 'Újudvar',
             'Újvárfalva', 'Úny', 'Úrhida', 'Úri', 'Úrkút', 'Üllés', 'Üllő', 'Üröm', 'Vadna', 'Vadosfa', 'Vaja', 'Vajdácska',
             'Vajszló', 'Vajta', 'Valkonya', 'Valkó', 'Vanyarc', 'Vanyola', 'Varászló', 'Varbó', 'Varbóc', 'Varga', 'Varsád',
             'Varsány', 'Vasad', 'Vasalja', 'Vasasszonyfa', 'Vasboldogasszony', 'Vasegerszeg', 'Vashosszúfalu', 'Vaskeresztes',
             'Vaskút', 'Vasmegyer', 'Vaspör', 'Vassurány', 'Vasszentmihály', 'Vasszécseny', 'Vasszilvágy', 'Vasvár',
             'Vaszar', 'Vatta', 'Vác', 'Vácduka', 'Vácegres', 'Váchartyán', 'Váckisújfalu', 'Vácrátót', 'Vácszentlászló',
             'Vág', 'Vágáshuta', 'Vál', 'Vállaj', 'Vállus', 'Vámosatya', 'Vámoscsalád', 'Vámosgyörk', 'Vámosmikola',
             'Vámosoroszi', 'Vámospércs', 'Vámosszabadi', 'Vámosújfalu', 'Váncsod', 'Várad', 'Váralja', 'Váraszó',
             'Várbalog', 'Várda', 'Várdomb', 'Várfölde', 'Várgesztes', 'Várkesző', 'Várong', 'Városföld', 'Városlőd',
             'Várpalota', 'Várvölgy', 'Vásárosbéc', 'Vásárosdombó', 'Vásárosfalu', 'Vásárosmiske', 'Vásárosnamény',
             'Vászoly', 'Vát', 'Vázsnok', 'Vecsés', 'Vejti', 'Vekerd', 'Velem', 'Velemér', 'Velence', 'Velény', 'Vereb',
             'Veresegyház', 'Verőce', 'Verpelét', 'Verseg', 'Versend', 'Veszkény', 'Veszprém', 'Veszprémfajsz', 'Veszprémgalsa',
             'Veszprémvarsány', 'Vezseny', 'Vécs', 'Végegyháza', 'Vékény', 'Véménd', 'Vének', 'Vép', 'Vértesacsa',
             'Vértesboglár', 'Vérteskethely', 'Vértessomló', 'Vértesszőlős', 'Vértestolna', 'Vése', 'Vésztő', 'Vid',
             'Vigántpetend', 'Villány', 'Villánykövesd', 'Vilmány', 'Vilonya', 'Vilyvitány', 'Vinár', 'Vindornyafok',
             'Vindornyalak', 'Vindornyaszőlős', 'Visegrád', 'Visnye', 'Visonta', 'Viss', 'Visz', 'Viszák', 'Viszló',
             'Visznek', 'Vitnyéd', 'Vizslás', 'Vizsoly', 'Vízvár', 'Vokány', 'Vonyarcvashegy', 'Vöckönd', 'Völcsej',
             'Vönöck', 'Vöröstó', 'Vörs', 'Zabar', 'Zagyvarékas', 'Zagyvaszántó', 'Zajk', 'Zajta', 'Zala', 'Zalaapáti',
             'Zalabaksa', 'Zalabér', 'Zalaboldogfa', 'Zalacsány', 'Zalacséb', 'Zalaegerszeg', 'Zalaerdőd', 'Zalagyömörő',
             'Zalahaláp', 'Zalaháshágy', 'Zalaigrice', 'Zalaistvánd', 'Zalakaros', 'Zalakomár', 'Zalaköveskút',
             'Zalalövő', 'Zalameggyes', 'Zalamerenye', 'Zalasárszeg', 'Zalaszabar', 'Zalaszántó', 'Zalaszegvár',
             'Zalaszentbalázs', 'Zalaszentgrót', 'Zalaszentgyörgy', 'Zalaszentiván', 'Zalaszentjakab', 'Zalaszentlászló',
             'Zalaszentlőrinc', 'Zalaszentmárton', 'Zalaszentmihály', 'Zalaszombatfa', 'Zalatárnok', 'Zalaújlak',
             'Zalavár', 'Zalavég', 'Zaláta', 'Zalkod', 'Zamárdi', 'Zaránk', 'Zádor', 'Zádorfalva', 'Záhony', 'Zákány',
             'Zákányfalu', 'Zákányszék', 'Zámoly', 'Zánka', 'Závod', 'Zebecke', 'Zebegény', 'Zemplénagárd',
             'Zengővárkony', 'Zichyújfalu', 'Zics', 'Ziliz', 'Zimány', 'Zirc', 'Zomba', 'Zók', 'Zsadány', 'Zsana',
             'Zsarolyán', 'Zsáka', 'Zsámbék', 'Zsámbok', 'Zsebeháza', 'Zselickisfalud', 'Zselickislak', 'Zselicszentpál',
             'Zsennye', 'Zsédeny', 'Zsira', 'Zsombó', 'Zsujta', 'Zsurk', 'Zubogy']

telepules_megye  = [('Dejtár', 'Nógrád'), ('Kistapolca', 'Baranya'), ('Hidasnémeti', 'Borsod-Abaúj-Zemplén'),
                ('Lánycsók', 'Baranya'), ('Nagykörű', 'Jász-Nagykun-Szolnok'), ('Diósjenő', 'Nógrád'),
                ('Pincehely', 'Tolna'), ('Szulimán', 'Baranya'), ('Inárcs', 'Pest'), ('Mogyoród', 'Pest'),
                ('Pölöskefő', 'Zala'), ('Örvényes', 'Veszprém'), ('Balatonfenyves', 'Somogy'),
                ('Ömböly', 'Szabolcs-Szatmár-Bereg'), ('Nemesbőd', 'Vas'), ('Solt', 'Bács-Kiskun'),
                ('Sirok', 'Heves'), ('Veszprémvarsány', 'Győr-Moson-Sopron'),
                ('Esztergom', 'Komárom-Esztergom'), ('Egyházasgerge', 'Nógrád'), ('Koppányszántó', 'Tolna'),
                ('Herend', 'Veszprém'), ('Üllés', 'Csongrád'), ('Győrtelek', 'Szabolcs-Szatmár-Bereg'),
                ('Alsómocsolád', 'Baranya'), ('Dorog', 'Komárom-Esztergom'), ('Bocskaikert', 'Hajdú-Bihar'),
                ('Lengyel', 'Tolna'), ('Terény', 'Nógrád'), ('Vid', 'Veszprém'), ('Salomvár', 'Zala'),
                ('Kerkabarabás', 'Zala'), ('Lapáncsa', 'Baranya'), ('Pusztamiske', 'Veszprém'),
                ('Barbacs', 'Győr-Moson-Sopron'), ('Bábolna', 'Komárom-Esztergom'),
                ('Kiskőrös', 'Bács-Kiskun'), ('Liszó', 'Zala'), ('Meszlen', 'Vas'), ('Nóráp', 'Veszprém'),
                ('Bátor', 'Heves'), ('Győrladamér', 'Győr-Moson-Sopron'), ('Salköveskút', 'Vas'),
                ('Zalaegerszeg', 'Zala'), ('Bucsu', 'Vas'), ('Liptód', 'Baranya'), ('Hajmás', 'Somogy'),
                ('Nagyszékely', 'Tolna'), ('Csipkerek', 'Vas'), ('Magyarszék', 'Baranya'),
                ('Szakony', 'Győr-Moson-Sopron'), ('Sajópüspöki', 'Borsod-Abaúj-Zemplén'),
                ('Arka', 'Borsod-Abaúj-Zemplén'), ('Somogydöröcske', 'Somogy'), ('Vanyarc', 'Nógrád'),
                ('Bögöt', 'Vas'), ('Kömlő', 'Heves'), ('Garbolc', 'Szabolcs-Szatmár-Bereg'),
                ('Olcsva', 'Szabolcs-Szatmár-Bereg'), ('Kétpó', 'Jász-Nagykun-Szolnok'),
                ('Lébény', 'Győr-Moson-Sopron'), ('Mátraterenye', 'Nógrád'), ('Oroszló', 'Baranya'),
                ('Versend', 'Baranya'), ('Tarany', 'Somogy'), ('Edelény', 'Borsod-Abaúj-Zemplén'),
                ('Szalkszentmárton', 'Bács-Kiskun'), ('Túrony', 'Baranya'), ('Vének', 'Győr-Moson-Sopron'),
                ('Kissziget', 'Zala'), ('Ságújfalu', 'Nógrád'), ('Hajdúhadház', 'Hajdú-Bihar'),
                ('Nagyiván', 'Jász-Nagykun-Szolnok'), ('Fulókércs', 'Borsod-Abaúj-Zemplén'),
                ('Szilaspogony', 'Nógrád'), ('Vác', 'Pest'), ('Hosszúpereszteg', 'Vas'),
                ('Meszes', 'Borsod-Abaúj-Zemplén'), ('Rigács', 'Veszprém'),
                ('Vámosatya', 'Szabolcs-Szatmár-Bereg'), ('Kistótfalu', 'Baranya'),
                ('Nagybaracska', 'Bács-Kiskun'), ('Legénd', 'Nógrád'), ('Tiszakürt', 'Jász-Nagykun-Szolnok'),
                ('Szentlászló', 'Baranya'), ('Bőcs', 'Borsod-Abaúj-Zemplén'), ('Ráckeve', 'Pest'),
                ('Páprád', 'Baranya'), ('Magyarmecske', 'Baranya'), ('Fehérvárcsurgó', 'Fejér'),
                ('Nagykutas', 'Zala'), ('Hodász', 'Szabolcs-Szatmár-Bereg'), ('Nagypall', 'Baranya'),
                ('Iharosberény', 'Somogy'), ('Őcsény', 'Tolna'), ('Bihartorda', 'Hajdú-Bihar'),
                ('Lénárddaróc', 'Borsod-Abaúj-Zemplén'), ('Gyömrő', 'Pest'),
                ('Szögliget', 'Borsod-Abaúj-Zemplén'), ('Szálka', 'Tolna'), ('Murakeresztúr', 'Zala'),
                ('Szamosangyalos', 'Szabolcs-Szatmár-Bereg'), ('Kisrákos', 'Vas'),
                ('Aszaló', 'Borsod-Abaúj-Zemplén'), ('Kisdombegyház', 'Békés'), ('Hosszúvölgy', 'Zala'),
                ('Döbrönte', 'Veszprém'), ('Bedegkér', 'Somogy'), ('Zádor', 'Baranya'),
                ('Márkó', 'Veszprém'), ('Kisszékely', 'Tolna'), ('Hort', 'Heves'),
                ('Dunaszekcső', 'Baranya'), ('Nyíracsád', 'Hajdú-Bihar'), ('Felsőpáhok', 'Zala'),
                ('Ivándárda', 'Baranya'), ('Mihályfa', 'Zala'), ('Kökény', 'Baranya'),
                ('Hács', 'Somogy'), ('Öcsöd', 'Jász-Nagykun-Szolnok'), ('Csépa', 'Jász-Nagykun-Szolnok'),
                ('Kerkateskánd', 'Zala'), ('Görcsönydoboka', 'Baranya'), ('Gerjen', 'Tolna'),
                ('Zalaszántó', 'Zala'), ('Balatonőszöd', 'Somogy'), ('Tófej', 'Zala'),
                ('Gagyapáti', 'Borsod-Abaúj-Zemplén'), ('Tormásliget', 'Vas'),
                ('Rétközberencs', 'Szabolcs-Szatmár-Bereg'), ('Kisrécse', 'Zala'), ('Vasasszonyfa', 'Vas'),
                ('Répcelak', 'Vas'), ('Vejti', 'Baranya'), ('Tiszaalpár', 'Bács-Kiskun'),
                ('Kokad', 'Hajdú-Bihar'), ('Baranyahidvég', 'Baranya'), ('Gecse', 'Veszprém'), ('Pálmonostora', 'Bács-Kiskun'), ('Szentliszló', 'Zala'), ('Mőcsény', 'Tolna'), ('Tagyon', 'Veszprém'), ('Csány', 'Heves'), ('Adásztevel', 'Veszprém'), ('Ludányhalászi', 'Nógrád'), ('Érsekhalma', 'Bács-Kiskun'), ('Eger', 'Heves'), ('Udvar', 'Baranya'), ('Erdőhorváti', 'Borsod-Abaúj-Zemplén'), ('Kisnána', 'Heves'), ('Szamossályi', 'Szabolcs-Szatmár-Bereg'), ('Zalaháshágy', 'Zala'), ('Teresztenye', 'Borsod-Abaúj-Zemplén'), ('Besence', 'Baranya'), ('Köcsk', 'Vas'), ('Ág', 'Baranya'), ('Magyarkeresztúr', 'Győr-Moson-Sopron'), ('Tiszaföldvár', 'Jász-Nagykun-Szolnok'), ('Gyóró', 'Győr-Moson-Sopron'), ('Felsőcsatár', 'Vas'), ('Gősfa', 'Zala'), ('Soltvadkert', 'Bács-Kiskun'), ('Nagyrákos', 'Vas'), ('Tiszaszentmárton', 'Szabolcs-Szatmár-Bereg'), ('Püspökmolnári', 'Vas'), ('Taksony', 'Pest'), ('Nemesrempehollós', 'Vas'), ('Pilis', 'Pest'), ('Egervár', 'Zala'), ('Szergény', 'Vas'), ('Siklósnagyfalu', 'Baranya'), ('Marcali', 'Somogy'), ('Nagydobsza', 'Baranya'), ('Felsőszentiván', 'Bács-Kiskun'), ('Kisvaszar', 'Baranya'), ('Hegymagas', 'Veszprém'), ('Kispirit', 'Veszprém'), ('Mályi', 'Borsod-Abaúj-Zemplén'), ('Bánokszentgyörgy', 'Zala'), ('Mernye', 'Somogy'), ('Orgovány', 'Bács-Kiskun'), ('Hernádvécse', 'Borsod-Abaúj-Zemplén'), ('Diósberény', 'Tolna'), ('Eperjes', 'Csongrád'), ('Mágocs', 'Baranya'), ('Szentjakabfa', 'Veszprém'), ('Kistormás', 'Tolna'), ('Köveskál', 'Veszprém'), ('Pétfürdő', 'Veszprém'), ('Hajdúszoboszló', 'Hajdú-Bihar'), ('Sárvár', 'Vas'), ('Balatonrendes', 'Veszprém'), ('Nyőgér', 'Vas'), ('Pölöske', 'Zala'), ('Somogyhárságy', 'Baranya'), ('Szőke', 'Baranya'), ('Lakitelek', 'Bács-Kiskun'), ('Orosháza', 'Békés'), ('Szűcsi', 'Heves'), ('Balatoncsicsó', 'Veszprém'), ('Pusztaottlaka', 'Békés'), ('Lócs', 'Vas'), ('Rudabánya', 'Borsod-Abaúj-Zemplén'), ('Kelemér', 'Borsod-Abaúj-Zemplén'), ('Kurd', 'Tolna'), ('Székkutas', 'Csongrád'), ('Daraboshegy', 'Vas'), ('Szentlőrinc', 'Baranya'), ('Vésztő', 'Békés'), ('Árpádhalom', 'Csongrád'), ('Vereb', 'Fejér'), ('Katymár', 'Bács-Kiskun'), ('Kára', 'Somogy'), ('Döbröce', 'Zala'), ('Mecsekpölöske', 'Baranya'), ('Nemesnép', 'Zala'), ('Nagyacsád', 'Veszprém'), ('Újhartyán', 'Pest'), ('Márfa', 'Baranya'), ('Pilisszentkereszt', 'Pest'), ('Rigyác', 'Zala'), ('Gilvánfa', 'Baranya'), ('Ipolytarnóc', 'Nógrád'), ('Szaporca', 'Baranya'), ('Varga', 'Baranya'), ('Büttös', 'Borsod-Abaúj-Zemplén'), ('Tárnok', 'Pest'), ('Szécsisziget', 'Zala'), ('Potyond', 'Győr-Moson-Sopron'), ('Nagyrécse', 'Zala'), ('Martonfa', 'Baranya'), ('Kilimán', 'Zala'), ('Törökbálint', 'Pest'), ('Nadap', 'Fejér'), ('Almásháza', 'Zala'), ('Nagyszentjános', 'Győr-Moson-Sopron'), ('Újpetre', 'Baranya'), ('Vértesboglár', 'Fejér'), ('Balatonberény', 'Somogy'), ('Baracska', 'Fejér'), ('Mátraverebély', 'Nógrád'), ('Jánd', 'Szabolcs-Szatmár-Bereg'), ('Buzsák', 'Somogy'), ('Csém', 'Komárom-Esztergom'), ('Töttös', 'Baranya'), ('Kunszállás', 'Bács-Kiskun'), ('Várvölgy', 'Zala'), ('Somogyjád', 'Somogy'), ('Dad', 'Komárom-Esztergom'), ('Nagypirit', 'Veszprém'), ('Orci', 'Somogy'), ('Mónosbél', 'Heves'), ('Zalaszegvár', 'Veszprém'), ('Cered', 'Nógrád'), ('Bükkszentkereszt', 'Borsod-Abaúj-Zemplén'), ('Paloznak', 'Veszprém'), ('Dombóvár', 'Tolna'), ('Resznek', 'Zala'), ('Hernád', 'Pest'), ('Alsógagy', 'Borsod-Abaúj-Zemplén'), ('Kisnémedi', 'Pest'), ('Kisbágyon', 'Nógrád'), ('Zsarolyán', 'Szabolcs-Szatmár-Bereg'), ('Benk', 'Szabolcs-Szatmár-Bereg'), ('Heves', 'Heves'), ('Érsekcsanád', 'Bács-Kiskun'), ('Szilvágy', 'Zala'), ('Kunbaja', 'Bács-Kiskun'), ('Varászló', 'Somogy'), ('Kétújfalu', 'Baranya'), ('Tiszatardos', 'Borsod-Abaúj-Zemplén'), ('Ordas', 'Bács-Kiskun'), ('Belsősárd', 'Zala'), ('Szentegát', 'Baranya'), ('Tornanádaska', 'Borsod-Abaúj-Zemplén'), ('Eplény', 'Veszprém'), ('Kisnyárád', 'Baranya'), ('Vilyvitány', 'Borsod-Abaúj-Zemplén'), ('Lesencefalu', 'Veszprém'), ('Becsehely', 'Zala'), ('Döbörhegy', 'Vas'), ('Körösújfalu', 'Békés'), ('Ambrózfalva', 'Csongrád'), ('Kocsola', 'Tolna'), ('Alsótelekes', 'Borsod-Abaúj-Zemplén'), ('Szalaszend', 'Borsod-Abaúj-Zemplén'), ('Balatonkenese', 'Veszprém'), ('Újszentmargita', 'Hajdú-Bihar'), ('Fonó', 'Somogy'), ('Kalocsa', 'Bács-Kiskun'), ('Misefa', 'Zala'), ('Szemely', 'Baranya'), ('Battonya', 'Békés'), ('Mezőhék', 'Jász-Nagykun-Szolnok'), ('Környe', 'Komárom-Esztergom'), ('Sajósenye', 'Borsod-Abaúj-Zemplén'), ('Tésa', 'Pest'), ('Lókút', 'Veszprém'), ('Kisbajcs', 'Győr-Moson-Sopron'), ('Doba', 'Veszprém'), ('Kaposkeresztúr', 'Somogy'), ('Tivadar', 'Szabolcs-Szatmár-Bereg'), ('Szokolya', 'Pest'), ('Szakonyfalu', 'Vas'), ('Boldogkőváralja', 'Borsod-Abaúj-Zemplén'), ('Kisjakabfalva', 'Baranya'), ('Hejce', 'Borsod-Abaúj-Zemplén'), ('Nagytarcsa', 'Pest'), ('Kerecsend', 'Heves'), ('Csanádapáca', 'Békés'), ('Győrasszonyfa', 'Győr-Moson-Sopron'), ('Álmosd', 'Hajdú-Bihar'), ('Jánkmajtis', 'Szabolcs-Szatmár-Bereg'), ('Nagyréde', 'Heves'), ('Felsőpetény', 'Nógrád'), ('Kisvásárhely', 'Zala'), ('Tépe', 'Hajdú-Bihar'), ('Imola', 'Borsod-Abaúj-Zemplén'), ('Győrzámoly', 'Győr-Moson-Sopron'), ('Kakasd', 'Tolna'), ('Mezőkeresztes', 'Borsod-Abaúj-Zemplén'), ('Fülöpjakab', 'Bács-Kiskun'), ('Nagylóc', 'Nógrád'), ('Fedémes', 'Heves'), ('Sántos', 'Somogy'), ('Sárospatak', 'Borsod-Abaúj-Zemplén'), ('Apátvarasd', 'Baranya'), ('Gyód', 'Baranya'), ('Surd', 'Zala'), ('Bikal', 'Baranya'), ('Gerendás', 'Békés'), ('Tiszavalk', 'Borsod-Abaúj-Zemplén'), ('Fertőhomok', 'Győr-Moson-Sopron'), ('Tolcsva', 'Borsod-Abaúj-Zemplén'), ('Rákóczifalva', 'Jász-Nagykun-Szolnok'), ('Tiszacsécse', 'Szabolcs-Szatmár-Bereg'), ('Jánoshalma', 'Bács-Kiskun'), ('Kunágota', 'Békés'), ('Nyírmihálydi', 'Szabolcs-Szatmár-Bereg'), ('Pakod', 'Zala'), ('Varbóc', 'Borsod-Abaúj-Zemplén'), ('Bakonya', 'Baranya'), ('Harc', 'Tolna'), ('Szápár', 'Veszprém'), ('Szentkirály', 'Bács-Kiskun'), ('Vácszentlászló', 'Pest'), ('Kovácsvágás', 'Borsod-Abaúj-Zemplén'), ('Szikszó', 'Borsod-Abaúj-Zemplén'), ('Somogymeggyes', 'Somogy'), ('Cák', 'Vas'), ('Rózsafa', 'Baranya'), ('Erdőtarcsa', 'Nógrád'), ('Aggtelek', 'Borsod-Abaúj-Zemplén'), ('Domony', 'Pest'), ('Maroslele', 'Csongrád'), ('Ősagárd', 'Nógrád'), ('Szentistván', 'Borsod-Abaúj-Zemplén'), ('Hetefejércse', 'Szabolcs-Szatmár-Bereg'), ('Sellye', 'Baranya'), ('Vindornyafok', 'Zala'), ('Orfű', 'Baranya'), ('Zalaboldogfa', 'Zala'), ('Zalaszentiván', 'Zala'), ('Rinyaújnép', 'Somogy'), ('Szajol', 'Jász-Nagykun-Szolnok'), ('Tiszasas', 'Jász-Nagykun-Szolnok'), ('Farmos', 'Pest'), ('Túristvándi', 'Szabolcs-Szatmár-Bereg'), ('Galgagyörk', 'Pest'), ('Sajóvámos', 'Borsod-Abaúj-Zemplén'), ('Harkakötöny', 'Bács-Kiskun'), ('Pannonhalma', 'Győr-Moson-Sopron'), ('Újkenéz', 'Szabolcs-Szatmár-Bereg'), ('Kisar', 'Szabolcs-Szatmár-Bereg'), ('Aranyosgadány', 'Baranya'), ('Kimle', 'Győr-Moson-Sopron'), ('Tótújfalu', 'Somogy'), ('Gagyvendégi', 'Borsod-Abaúj-Zemplén'), ('Kalaznó', 'Tolna'), ('Apostag', 'Bács-Kiskun'), ('Csér', 'Győr-Moson-Sopron'), ('Iván', 'Győr-Moson-Sopron'), ('Kötegyán', 'Békés'), ('Marócsa', 'Baranya'), ('Gyúró', 'Fejér'), ('Orosztony', 'Zala'), ('Ecseny', 'Somogy'), ('Gerde', 'Baranya'), ('Palotabozsok', 'Baranya'), ('Mezőszemere', 'Heves'), ('Bóly', 'Baranya'), ('Bagamér', 'Hajdú-Bihar'), ('Városlőd', 'Veszprém'), ('Velemér', 'Vas'), ('Csehimindszent', 'Vas'), ('Taliándörögd', 'Veszprém'), ('Dötk', 'Zala'), ('Ligetfalva', 'Zala'), ('Szentlőrinckáta', 'Pest'), ('Zalaapáti', 'Zala'), ('Bükkszenterzsébet', 'Heves'), ('Felsőrajk', 'Zala'), ('Nyárlőrinc', 'Bács-Kiskun'), ('Szank', 'Bács-Kiskun'), ('Kéked', 'Borsod-Abaúj-Zemplén'), ('Tát', 'Komárom-Esztergom'), ('Semjénháza', 'Zala'), ('Ábrahámhegy', 'Veszprém'), ('Budakeszi', 'Pest'), ('Porcsalma', 'Szabolcs-Szatmár-Bereg'), ('Felgyő', 'Csongrád'), ('Szügy', 'Nógrád'), ('Kecskéd', 'Komárom-Esztergom'), ('Kemeneshőgyész', 'Veszprém'), ('Göd', 'Pest'), ('Somogytúr', 'Somogy'), ('Veszprémfajsz', 'Veszprém'), ('Hevesaranyos', 'Heves'), ('Jákfalva', 'Borsod-Abaúj-Zemplén'), ('Budapest', 'Főváros'), ('Nagymizdó', 'Vas'), ('Ároktő', 'Borsod-Abaúj-Zemplén'), ('Mátraszőlős', 'Nógrád'), ('Imrehegy', 'Bács-Kiskun'), ('Sonkád', 'Szabolcs-Szatmár-Bereg'), ('Szomolya', 'Borsod-Abaúj-Zemplén'), ('Tápiószele', 'Pest'), ('Szabás', 'Somogy'), ('Pinnye', 'Győr-Moson-Sopron'), ('Sóly', 'Veszprém'), ('Karácsond', 'Heves'), ('Pörböly', 'Tolna'), ('Sajóhidvég', 'Borsod-Abaúj-Zemplén'), ('Tard', 'Borsod-Abaúj-Zemplén'), ('Csót', 'Veszprém'), ('Monoszló', 'Veszprém'), ('Békés', 'Békés'), ('Kiskunmajsa', 'Bács-Kiskun'), ('Kisoroszi', 'Pest'), ('Bodroghalom', 'Borsod-Abaúj-Zemplén'), ('Márok', 'Baranya'), ('Egyházashetye', 'Vas'), ('Kisharsány', 'Baranya'), ('Alsóvadász', 'Borsod-Abaúj-Zemplén'), ('Szentbalázs', 'Somogy'), ('Ötvöskónyi', 'Somogy'), ('Tokod', 'Komárom-Esztergom'), ('Kup', 'Veszprém'), ('Gasztony', 'Vas'), ('Nagylak', 'Csongrád'), ('Gelénes', 'Szabolcs-Szatmár-Bereg'), ('Bakonybánk', 'Komárom-Esztergom'), ('Vése', 'Somogy'), ('Kásád', 'Baranya'), ('Algyő', 'Csongrád'), ('Apagy', 'Szabolcs-Szatmár-Bereg'), ('Felsőberecki', 'Borsod-Abaúj-Zemplén'), ('Boda', 'Baranya'), ('Egeraracsa', 'Zala'), ('Kőszegszerdahely', 'Vas'), ('Kozárd', 'Nógrád'), ('Balatonszepezd', 'Veszprém'), ('Romonya', 'Baranya'), ('Alsónyék', 'Tolna'), ('Baks', 'Csongrád'), ('Keszthely', 'Zala'), ('Karcsa', 'Borsod-Abaúj-Zemplén'), ('Füzérkajata', 'Borsod-Abaúj-Zemplén'), ('Hidvégardó', 'Borsod-Abaúj-Zemplén'), ('Rásonysápberencs', 'Borsod-Abaúj-Zemplén'), ('Érsekvadkert', 'Nógrád'), ('Nemesvámos', 'Veszprém'), ('Kispáli', 'Zala'), ('Matty', 'Baranya'), ('Bakonyszentiván', 'Veszprém'), ('Súr', 'Komárom-Esztergom'), ('Bárna', 'Nógrád'), ('Taktabáj', 'Borsod-Abaúj-Zemplén'), ('Ikervár', 'Vas'), ('Galvács', 'Borsod-Abaúj-Zemplén'), ('Badacsonytomaj', 'Veszprém'), ('Kisszentmárton', 'Baranya'), ('Hegyhátszentmárton', 'Vas'), ('Vassurány', 'Vas'), ('Üllő', 'Pest'), ('Zsebeháza', 'Győr-Moson-Sopron'), ('Vezseny', 'Jász-Nagykun-Szolnok'), ('Galambok', 'Zala'), ('Feked', 'Baranya'), ('Bolhás', 'Somogy'), ('Petrivente', 'Zala'), ('Noszvaj', 'Heves'), ('Tenk', 'Heves'), ('Lesencetomaj', 'Veszprém'), ('Tököl', 'Pest'), ('Rábakecöl', 'Győr-Moson-Sopron'), ('Lenti', 'Zala'), ('Meződ', 'Baranya'), ('Szolnok', 'Jász-Nagykun-Szolnok'), ('Irota', 'Borsod-Abaúj-Zemplén'), ('Drávacsehi', 'Baranya'), ('Pördefölde', 'Zala'), ('Nagyszakácsi', 'Somogy'), ('Bejcgyertyános', 'Vas'), ('Jobbágyi', 'Nógrád'), ('Gyanógeregye', 'Vas'), ('Gadna', 'Borsod-Abaúj-Zemplén'), ('Kőszegdoroszló', 'Vas'), ('Nézsa', 'Nógrád'), ('Balatonújlak', 'Somogy'), ('Bakonyoszlop', 'Veszprém'), ('Pusztavacs', 'Pest'), ('Mihálygerge', 'Nógrád'), ('Szalonna', 'Borsod-Abaúj-Zemplén'), ('Tornabarakony', 'Borsod-Abaúj-Zemplén'), ('Császártöltés', 'Bács-Kiskun'), ('Cserénfa', 'Somogy'), ('Istvándi', 'Somogy'), ('Mezőtúr', 'Jász-Nagykun-Szolnok'), ('Sümegcsehi', 'Zala'), ('Szentkatalin', 'Baranya'), ('Pusztaederics', 'Zala'), ('Magyartelek', 'Baranya'), ('Pálháza', 'Borsod-Abaúj-Zemplén'), ('Mikosszéplak', 'Vas'), ('Rábapatona', 'Győr-Moson-Sopron'), ('Tiszakarád', 'Borsod-Abaúj-Zemplén'), ('Galgahévíz', 'Pest'), ('Lakócsa', 'Somogy'), ('Nyírmeggyes', 'Szabolcs-Szatmár-Bereg'), ('Köröm', 'Borsod-Abaúj-Zemplén'), ('Záhony', 'Szabolcs-Szatmár-Bereg'), ('Csetény', 'Veszprém'), ('Magyarpolány', 'Veszprém'), ('Százhalombatta', 'Pest'), ('Dunaszentpál', 'Győr-Moson-Sopron'), ('Szerep', 'Hajdú-Bihar'), ('Maráza', 'Baranya'), ('Megyaszó', 'Borsod-Abaúj-Zemplén'), ('Tószeg', 'Jász-Nagykun-Szolnok'), ('Demecser', 'Szabolcs-Szatmár-Bereg'), ('Rábaszentmiklós', 'Győr-Moson-Sopron'), ('Told', 'Hajdú-Bihar'), ('Tata', 'Komárom-Esztergom'), ('Nyugotszenterzsébet', 'Baranya'), ('Medina', 'Tolna'), ('Mindszent', 'Csongrád'), ('Püski', 'Győr-Moson-Sopron'), ('Jászkarajenő', 'Pest'), ('Siklósbodony', 'Baranya'), ('Ivánc', 'Vas'), ('Lövő', 'Győr-Moson-Sopron'), ('Koroncó', 'Győr-Moson-Sopron'), ('Nyíri', 'Borsod-Abaúj-Zemplén'), ('Teskánd', 'Zala'), ('Nemeskeresztúr', 'Vas'), ('Pilismarót', 'Komárom-Esztergom'), ('Hajdúböszörmény', 'Hajdú-Bihar'), ('Magy', 'Szabolcs-Szatmár-Bereg'), ('Bögöte', 'Vas'), ('Rohod', 'Szabolcs-Szatmár-Bereg'), ('Andrásfa', 'Vas'), ('Ebes', 'Hajdú-Bihar'), ('Sajókápolna', 'Borsod-Abaúj-Zemplén'), ('Beleg', 'Somogy'), ('Hidegség', 'Győr-Moson-Sopron'), ('Felsőpakony', 'Pest'), ('Őr', 'Szabolcs-Szatmár-Bereg'), ('Somogyzsitfa', 'Somogy'), ('Hernádcéce', 'Borsod-Abaúj-Zemplén'), ('Nagycserkesz', 'Szabolcs-Szatmár-Bereg'), ('Pethőhenye', 'Zala'), ('Fertőboz', 'Győr-Moson-Sopron'), ('Mályinka', 'Borsod-Abaúj-Zemplén'), ('Áporka', 'Pest'), ('Dunaszentmiklós', 'Komárom-Esztergom'), ('Nemesmedves', 'Vas'), ('Cún', 'Baranya'), ('Győrújfalu', 'Győr-Moson-Sopron'), ('Kiskorpád', 'Somogy'), ('Sósvertike', 'Baranya'), ('Drávaszabolcs', 'Baranya'), ('Bonyhádvarasd', 'Tolna'), ('Rönök', 'Vas'), ('Szigetbecse', 'Pest'), ('Tetétlen', 'Hajdú-Bihar'), ('Ózd', 'Borsod-Abaúj-Zemplén'), ('Torony', 'Vas'), ('Sződ', 'Pest'), ('Nógrádmegyer', 'Nógrád'), ('Karcag', 'Jász-Nagykun-Szolnok'), ('Ófalu', 'Baranya'), ('Nagykőrös', 'Pest'), ('Mórahalom', 'Csongrád'), ('Újvárfalva', 'Somogy'), ('Tiszaszőlős', 'Jász-Nagykun-Szolnok'), ('Kéleshalom', 'Bács-Kiskun'), ('Rábatöttös', 'Vas'), ('Magyargéc', 'Nógrád'), ('Enese', 'Győr-Moson-Sopron'), ('Nádasdladány', 'Fejér'), ('Hunya', 'Békés'), ('Lengyeltóti', 'Somogy'), ('Pinkamindszent', 'Vas'), ('Miske', 'Bács-Kiskun'), ('Fazekasboda', 'Baranya'), ('Pusztaszabolcs', 'Fejér'), ('Gáborján', 'Hajdú-Bihar'), ('Méra', 'Borsod-Abaúj-Zemplén'), ('Pócspetri', 'Szabolcs-Szatmár-Bereg'), ('Cikó', 'Tolna'), ('Múcsony', 'Borsod-Abaúj-Zemplén'), ('Szabadszentkirály', 'Baranya'), ('Mezőnyárád', 'Borsod-Abaúj-Zemplén'), ('Lasztonya', 'Zala'), ('Tamási', 'Tolna'), ('Markotabödöge', 'Győr-Moson-Sopron'), ('Jánossomorja', 'Győr-Moson-Sopron'), ('Csajág', 'Veszprém'), ('Kunadacs', 'Bács-Kiskun'), ('Nagyszénás', 'Békés'), ('Tök', 'Pest'), ('Olasz', 'Baranya'), ('Újléta', 'Hajdú-Bihar'), ('Bátaapáti', 'Tolna'), ('Dunakiliti', 'Győr-Moson-Sopron'), ('Rápolt', 'Szabolcs-Szatmár-Bereg'), ('Csaholc', 'Szabolcs-Szatmár-Bereg'), ('Kisunyom', 'Vas'), ('Nyírpilis', 'Szabolcs-Szatmár-Bereg'), ('Bácsszőlős', 'Bács-Kiskun'), ('Egyek', 'Hajdú-Bihar'), ('Tornaszentjakab', 'Borsod-Abaúj-Zemplén'), ('Somogygeszti', 'Somogy'), ('Kolontár', 'Veszprém'), ('Pusztacsó', 'Vas'), ('Györe', 'Tolna'), ('Hövej', 'Győr-Moson-Sopron'), ('Kaposhomok', 'Somogy'), ('Bükkzsérc', 'Borsod-Abaúj-Zemplén'), ('Botpalád', 'Szabolcs-Szatmár-Bereg'), ('Birján', 'Baranya'), ('Bogyiszló', 'Tolna'), ('Hejőszalonta', 'Borsod-Abaúj-Zemplén'), ('Tömörd', 'Vas'), ('Ópályi', 'Szabolcs-Szatmár-Bereg'), ('Pápateszér', 'Veszprém'), ('Hárskút', 'Veszprém'), ('Tiszarád', 'Szabolcs-Szatmár-Bereg'), ('Gönyű', 'Győr-Moson-Sopron'), ('Forráskút', 'Csongrád'), ('Mekényes', 'Baranya'), ('Tunyogmatolcs', 'Szabolcs-Szatmár-Bereg'), ('Kertészsziget', 'Békés'), ('Kistelek', 'Csongrád'), ('Andocs', 'Somogy'), ('Gádoros', 'Békés'), ('Encs', 'Borsod-Abaúj-Zemplén'), ('Hegykő', 'Győr-Moson-Sopron'), ('Maglóca', 'Győr-Moson-Sopron'), ('Gyál', 'Pest'), ('Kemse', 'Baranya'), ('Makkoshotyka', 'Borsod-Abaúj-Zemplén'), ('Sárszentágota', 'Fejér'), ('Tiszamogyorós', 'Szabolcs-Szatmár-Bereg'), ('Hajdúnánás', 'Hajdú-Bihar'), ('Mátramindszent', 'Nógrád'), ('Jásd', 'Veszprém'), ('Sarkad', 'Békés'), ('Hugyag', 'Nógrád'), ('Edde', 'Somogy'), ('Mátranovák', 'Nógrád'), ('Polgárdi', 'Fejér'), ('Bérbaltavár', 'Vas'), ('Magyargencs', 'Veszprém'), ('Padár', 'Zala'), ('Bálványos', 'Somogy'), ('Nemesgörzsöny', 'Veszprém'), ('Vámoscsalád', 'Vas'), ('Osli', 'Győr-Moson-Sopron'), ('Bölcske', 'Tolna'), ('Darnó', 'Szabolcs-Szatmár-Bereg'), ('Nagyfüged', 'Heves'), ('Madaras', 'Bács-Kiskun'), ('Kislippó', 'Baranya'), ('Újkér', 'Győr-Moson-Sopron'), ('Szombathely', 'Vas'), ('Balajt', 'Borsod-Abaúj-Zemplén'), ('Nyírcsászári', 'Szabolcs-Szatmár-Bereg'), ('Ozmánbük', 'Zala'), ('Pankasz', 'Vas'), ('Szatta', 'Vas'), ('Szentpéterfölde', 'Zala'), ('Kismarja', 'Hajdú-Bihar'), ('Ormosbánya', 'Borsod-Abaúj-Zemplén'), ('Mende', 'Pest'), ('Sárbogárd', 'Fejér'), ('Harta', 'Bács-Kiskun'), ('Hetes', 'Somogy'), ('Pátroha', 'Szabolcs-Szatmár-Bereg'), ('Ozora', 'Tolna'), ('Felsőszentmárton', 'Baranya'), ('Átány', 'Heves'), ('Domoszló', 'Heves'), ('Tiszabezdéd', 'Szabolcs-Szatmár-Bereg'), ('Újkígyós', 'Békés'), ('Aba', 'Fejér'), ('Csécse', 'Nógrád'), ('Dombegyház', 'Békés'), ('Szakály', 'Tolna'), ('Dég', 'Fejér'), ('Halmajugra', 'Heves'), ('Villánykövesd', 'Baranya'), ('Tápiószecső', 'Pest'), ('Golop', 'Borsod-Abaúj-Zemplén'), ('Hernádnémeti', 'Borsod-Abaúj-Zemplén'), ('Torvaj', 'Somogy'), ('Závod', 'Tolna'), ('Csenger', 'Szabolcs-Szatmár-Bereg'), ('Keszeg', 'Nógrád'), ('Pusztaszer', 'Csongrád'), ('Hajdúbagos', 'Hajdú-Bihar'), ('Visznek', 'Heves'), ('Csesztve', 'Nógrád'), ('Kemenessömjén', 'Vas'), ('Balmazújváros', 'Hajdú-Bihar'), ('Varsány', 'Nógrád'), ('Almáskeresztúr', 'Baranya'), ('Szekszárd', 'Tolna'), ('Nagyút', 'Heves'), ('Biharnagybajom', 'Hajdú-Bihar'), ('Cirák', 'Győr-Moson-Sopron'), ('Királd', 'Borsod-Abaúj-Zemplén'), ('Lázi', 'Győr-Moson-Sopron'), ('Szabadhidvég', 'Fejér'), ('Szarvasgede', 'Nógrád'), ('Aldebrő', 'Heves'), ('Nagygyimót', 'Veszprém'), ('Páty', 'Pest'), ('Zagyvarékas', 'Jász-Nagykun-Szolnok'), ('Kistarcsa', 'Pest'), ('Kazsok', 'Somogy'), ('Vöröstó', 'Veszprém'), ('Szabadbattyán', 'Fejér'), ('Körmend', 'Vas'), ('Sárok', 'Baranya'), ('Dióskál', 'Zala'), ('Törökszentmiklós', 'Jász-Nagykun-Szolnok'), ('Zalasárszeg', 'Zala'), ('Újtikos', 'Hajdú-Bihar'), ('Szamosújlak', 'Szabolcs-Szatmár-Bereg'), ('Úny', 'Komárom-Esztergom'), ('Nemeshany', 'Veszprém'), ('Alsóbogát', 'Somogy'), ('Nyírtura', 'Szabolcs-Szatmár-Bereg'), ('Somogyhatvan', 'Baranya'), ('Hejőkeresztúr', 'Borsod-Abaúj-Zemplén'), ('Kisbudmér', 'Baranya'), ('Lendvadedes', 'Zala'), ('Káptalantóti', 'Veszprém'), ('Kercseliget', 'Somogy'), ('Létavértes', 'Hajdú-Bihar'), ('Aparhant', 'Tolna'), ('Dömsöd', 'Pest'), ('Tanakajd', 'Vas'), ('Boconád', 'Heves'), ('Szentdomonkos', 'Heves'), ('Baskó', 'Borsod-Abaúj-Zemplén'), ('Söjtör', 'Zala'), ('Máriakálnok', 'Győr-Moson-Sopron'), ('Nemesszalók', 'Veszprém'), ('Bakonyszentkirály', 'Veszprém'), ('Szentdénes', 'Baranya'), ('Nagykónyi', 'Tolna'), ('Tiszacsermely', 'Borsod-Abaúj-Zemplén'), ('Ibrány', 'Szabolcs-Szatmár-Bereg'), ('Bükkábrány', 'Borsod-Abaúj-Zemplén'), ('Bakonyjákó', 'Veszprém'), ('Kéthely', 'Somogy'), ('Sajólád', 'Borsod-Abaúj-Zemplén'), ('Cserhátszentiván', 'Nógrád'), ('Balatonederics', 'Veszprém'), ('Békéscsaba', 'Békés'), ('Kismaros', 'Pest'), ('Magyaregres', 'Somogy'), ('Oroszlány', 'Komárom-Esztergom'), ('Ramocsa', 'Zala'), ('Csempeszkopács', 'Vas'), ('Székely', 'Szabolcs-Szatmár-Bereg'), ('Hangács', 'Borsod-Abaúj-Zemplén'), ('Ólmod', 'Vas'), ('Csesznek', 'Veszprém'), ('Mezőlak', 'Veszprém'), ('Iszkáz', 'Veszprém'), ('Váraszó', 'Heves'), ('Táp', 'Győr-Moson-Sopron'), ('Furta', 'Hajdú-Bihar'), ('Sátoraljaújhely', 'Borsod-Abaúj-Zemplén'), ('Vép', 'Vas'), ('Kisgyőr', 'Borsod-Abaúj-Zemplén'), ('Iklad', 'Pest'), ('Szárász', 'Baranya'), ('Hetyefő', 'Veszprém'), ('Lúzsok', 'Baranya'), ('Vág', 'Győr-Moson-Sopron'), ('Ziliz', 'Borsod-Abaúj-Zemplén'), ('Szeremle', 'Bács-Kiskun'), ('Istenmezeje', 'Heves'), ('Zalacsány', 'Zala'), ('Ivád', 'Heves'), ('Nagyalásony', 'Veszprém'), ('Magyarszentmiklós', 'Zala'), ('Jászboldogháza', 'Jász-Nagykun-Szolnok'), ('Lendvajakabfa', 'Zala'), ('Hévízgyörk', 'Pest'), ('Jászfelsőszentgyörgy', 'Jász-Nagykun-Szolnok'), ('Peterd', 'Baranya'), ('Nagykölked', 'Vas'), ('Bodrogolaszi', 'Borsod-Abaúj-Zemplén'), ('Varbó', 'Borsod-Abaúj-Zemplén'), ('Balatonmáriafürdő', 'Somogy'), ('Borjád', 'Baranya'), ('Nagyberki', 'Somogy'), ('Vászoly', 'Veszprém'), ('Vizsoly', 'Borsod-Abaúj-Zemplén'), ('Etes', 'Nógrád'), ('Osztopán', 'Somogy'), ('Kunszentmiklós', 'Bács-Kiskun'), ('Mikepércs', 'Hajdú-Bihar'), ('Börcs', 'Győr-Moson-Sopron'), ('Nagykorpád', 'Somogy'), ('Szőlősardó', 'Borsod-Abaúj-Zemplén'), ('Nőtincs', 'Nógrád'), ('Vasalja', 'Vas'), ('Várpalota', 'Veszprém'), ('Berkesd', 'Baranya'), ('Bakonypölöske', 'Veszprém'), ('Miklósi', 'Somogy'), ('Szerencs', 'Borsod-Abaúj-Zemplén'), ('Viszló', 'Borsod-Abaúj-Zemplén'), ('Balatonlelle', 'Somogy'), ('Dunaharaszti', 'Pest'), ('Iszkaszentgyörgy', 'Fejér'), ('Nyíradony', 'Hajdú-Bihar'), ('Doboz', 'Békés'), ('Öregcsertő', 'Bács-Kiskun'), ('Polány', 'Somogy'), ('Karos', 'Borsod-Abaúj-Zemplén'), ('Edve', 'Győr-Moson-Sopron'), ('Porrogszentkirály', 'Somogy'), ('Nagykökényes', 'Heves'), ('Csanádalberti', 'Csongrád'), ('Jászszentandrás', 'Jász-Nagykun-Szolnok'), ('Tarcal', 'Borsod-Abaúj-Zemplén'), ('Ravazd', 'Győr-Moson-Sopron'), ('Alsódobsza', 'Borsod-Abaúj-Zemplén'), ('Bekecs', 'Borsod-Abaúj-Zemplén'), ('Csabaszabadi', 'Békés'), ('Márkháza', 'Nógrád'), ('Himod', 'Győr-Moson-Sopron'), ('Vasegerszeg', 'Vas'), ('Sajókeresztúr', 'Borsod-Abaúj-Zemplén'), ('Máriapócs', 'Szabolcs-Szatmár-Bereg'), ('Filkeháza', 'Borsod-Abaúj-Zemplén'), ('Bazsi', 'Veszprém'), ('Sorkifalud', 'Vas'), ('Bogdása', 'Baranya'), ('Felsőmocsolád', 'Somogy'), ('Kereki', 'Somogy'), ('Mánd', 'Szabolcs-Szatmár-Bereg'), ('Kardos', 'Békés'), ('Mátraballa', 'Heves'), ('Emőd', 'Borsod-Abaúj-Zemplén'), ('Kisszállás', 'Bács-Kiskun'), ('Borsodszentgyörgy', 'Borsod-Abaúj-Zemplén'), ('Tiszalúc', 'Borsod-Abaúj-Zemplén'), ('Sobor', 'Győr-Moson-Sopron'), ('Szigetcsép', 'Pest'), ('Nógrádsipek', 'Nógrád'), ('Őriszentpéter', 'Vas'), ('Szentmargitfalva', 'Zala'), ('Sárazsadány', 'Borsod-Abaúj-Zemplén'), ('Őrtilos', 'Somogy'), ('Bogács', 'Borsod-Abaúj-Zemplén'), ('Tompaládony', 'Vas'), ('Lajosmizse', 'Bács-Kiskun'), ('Szentgáloskér', 'Somogy'), ('Gávavencsellő', 'Szabolcs-Szatmár-Bereg'), ('Penc', 'Pest'), ('Szendrőlád', 'Borsod-Abaúj-Zemplén'), ('Tiszadob', 'Szabolcs-Szatmár-Bereg'), ('Beregdaróc', 'Szabolcs-Szatmár-Bereg'), ('Bük', 'Vas'), ('Csenyéte', 'Borsod-Abaúj-Zemplén'), ('Halimba', 'Veszprém'), ('Újbarok', 'Fejér'), ('Baracs', 'Fejér'), ('Esztergályhorváti', 'Zala'), ('Akasztó', 'Bács-Kiskun'), ('Kákics', 'Baranya'), ('Kisdér', 'Baranya'), ('Dalmand', 'Tolna'), ('Litke', 'Nógrád'), ('Csöde', 'Zala'), ('Sajóbábony', 'Borsod-Abaúj-Zemplén'), ('Bodonhely', 'Győr-Moson-Sopron'), ('Várad', 'Baranya'), ('Feldebrő', 'Heves'), ('Felsőszölnök', 'Vas'), ('Kislőd', 'Veszprém'), ('Rákóczibánya', 'Nógrád'), ('Szászfa', 'Borsod-Abaúj-Zemplén'), ('Jánosháza', 'Vas'), ('Kisapáti', 'Veszprém'), ('Várbalog', 'Győr-Moson-Sopron'), ('Gerényes', 'Baranya'), ('Kaskantyú', 'Bács-Kiskun'), ('Kiskassa', 'Baranya'), ('Gulács', 'Szabolcs-Szatmár-Bereg'), ('Balatonszemes', 'Somogy'), ('Hagyárosbörönd', 'Zala'), ('Nyírtelek', 'Szabolcs-Szatmár-Bereg'), ('Kőröshegy', 'Somogy'), ('Nemespátró', 'Zala'), ('Lukácsháza', 'Vas'), ('Péteri', 'Pest'), ('Babosdöbréte', 'Zala'), ('Tápiógyörgye', 'Pest'), ('Nagydém', 'Veszprém'), ('Szőkedencs', 'Somogy'), ('Tiszaderzs', 'Jász-Nagykun-Szolnok'), ('Dunavecse', 'Bács-Kiskun'), ('Ásotthalom', 'Csongrád'), ('Botykapeterd', 'Baranya'), ('Ballószög', 'Bács-Kiskun'), ('Kétegyháza', 'Békés'), ('Cibakháza', 'Jász-Nagykun-Szolnok'), ('Szákszend', 'Komárom-Esztergom'), ('Árpás', 'Győr-Moson-Sopron'), ('Zalaerdőd', 'Veszprém'), ('Csögle', 'Veszprém'), ('Kishartyán', 'Nógrád'), ('Ópusztaszer', 'Csongrád'), ('Kuncsorba', 'Jász-Nagykun-Szolnok'), ('Egyházasharaszti', 'Baranya'), ('Teklafalu', 'Baranya'), ('Perenye', 'Vas'), ('Sárkeszi', 'Fejér'), ('Csepreg', 'Vas'), ('Ősi', 'Veszprém'), ('Zalagyömörő', 'Veszprém'), ('Balinka', 'Fejér'), ('Tiszaadony', 'Szabolcs-Szatmár-Bereg'), ('Kincsesbánya', 'Fejér'), ('Dunaszentgyörgy', 'Tolna'), ('Bakóca', 'Baranya'), ('Grábóc', 'Tolna'), ('Kübekháza', 'Csongrád'), ('Uzsa', 'Veszprém'), ('Nemesbikk', 'Borsod-Abaúj-Zemplén'), ('Tordas', 'Fejér'), ('Mucsfa', 'Tolna'), ('Szentgál', 'Veszprém'), ('Kissikátor', 'Borsod-Abaúj-Zemplén'), ('Csátalja', 'Bács-Kiskun'), ('Porpác', 'Vas'), ('Taktakenéz', 'Borsod-Abaúj-Zemplén'), ('Magyarnándor', 'Nógrád'), ('Besenyőtelek', 'Heves'), ('Körösszegapáti', 'Hajdú-Bihar'), ('Ispánk', 'Vas'), ('Szebény', 'Baranya'), ('Epöl', 'Komárom-Esztergom'), ('Kétvölgy', 'Vas'), ('Magyaratád', 'Somogy'), ('Bogádmindszent', 'Baranya'), ('Magyarnádalja', 'Vas'), ('Egyed', 'Győr-Moson-Sopron'), ('Somlószőlős', 'Veszprém'), ('Vécs', 'Heves'), ('Sajóvelezd', 'Borsod-Abaúj-Zemplén'), ('Tiszavárkony', 'Jász-Nagykun-Szolnok'), ('Écs', 'Győr-Moson-Sopron'), ('Tiszakeszi', 'Borsod-Abaúj-Zemplén'), ('Ivánbattyán', 'Baranya'), ('Felsőörs', 'Veszprém'), ('Chernelházadamonya', 'Vas'), ('Erdőkövesd', 'Heves'), ('Csővár', 'Pest'), ('Szárazd', 'Tolna'), ('Makád', 'Pest'), ('Vaspör', 'Zala'), ('Alibánfa', 'Zala'), ('Szorgalmatos', 'Szabolcs-Szatmár-Bereg'), ('Narda', 'Vas'), ('Tarnaörs', 'Heves'), ('Tereske', 'Nógrád'), ('Rákócziújfalu', 'Jász-Nagykun-Szolnok'), ('Nemesbük', 'Zala'), ('Somlóvásárhely', 'Veszprém'), ('Gyulakeszi', 'Veszprém'), ('Karmacs', 'Zala'), ('Decs', 'Tolna'), ('Fertőendréd', 'Győr-Moson-Sopron'), ('Kompolt', 'Heves'), ('Kevermes', 'Békés'), ('Nagyszokoly', 'Tolna'), ('Kenéz', 'Vas'), ('Keménfa', 'Zala'), ('Murony', 'Békés'), ('Fertőd', 'Győr-Moson-Sopron'), ('Zalaszentgyörgy', 'Zala'), ('Barnag', 'Veszprém'), ('Döge', 'Szabolcs-Szatmár-Bereg'), ('Kérsemjén', 'Szabolcs-Szatmár-Bereg'), ('Meggyeskovácsi', 'Vas'), ('Zsámbék', 'Pest'), ('Tiszapüspöki', 'Jász-Nagykun-Szolnok'), ('Kétsoprony', 'Békés'), ('Váckisújfalu', 'Pest'), ('Kisbárkány', 'Nógrád'), ('Magyarcsanád', 'Csongrád'), ('Recsk', 'Heves'), ('Himesháza', 'Baranya'), ('Tótkomlós', 'Békés'), ('Borgáta', 'Vas'), ('Drávapalkonya', 'Baranya'), ('Fony', 'Borsod-Abaúj-Zemplén'), ('Kéty', 'Tolna'), ('Újudvar', 'Zala'), ('Viss', 'Borsod-Abaúj-Zemplén'), ('Felsőtárkány', 'Heves'), ('Kisbeszterce', 'Baranya'), ('Berente', 'Borsod-Abaúj-Zemplén'), ('Dövény', 'Borsod-Abaúj-Zemplén'), ('Bonyhád', 'Tolna'), ('Kisnamény', 'Szabolcs-Szatmár-Bereg'), ('Györköny', 'Tolna'), ('Aszód', 'Pest'), ('Dóc', 'Csongrád'), ('Hatvan', 'Heves'), ('Dunafalva', 'Bács-Kiskun'), ('Nagykereki', 'Hajdú-Bihar'), ('Biri', 'Szabolcs-Szatmár-Bereg'), ('Bakonyság', 'Veszprém'), ('Kótaj', 'Szabolcs-Szatmár-Bereg'), ('Cigánd', 'Borsod-Abaúj-Zemplén'), ('Pap', 'Szabolcs-Szatmár-Bereg'), ('Hercegkút', 'Borsod-Abaúj-Zemplén'), ('Vonyarcvashegy', 'Zala'), ('Bodony', 'Heves'), ('Szamostatárfalva', 'Szabolcs-Szatmár-Bereg'), ('Kisecset', 'Nógrád'), ('Gyenesdiás', 'Zala'), ('Csabdi', 'Fejér'), ('Nekézseny', 'Borsod-Abaúj-Zemplén'), ('Füzér', 'Borsod-Abaúj-Zemplén'), ('Sikátor', 'Győr-Moson-Sopron'), ('Ipacsfa', 'Baranya'), ('Lesenceistvánd', 'Veszprém'), ('Vértessomló', 'Komárom-Esztergom'), ('Kiskinizs', 'Borsod-Abaúj-Zemplén'), ('Ipolydamásd', 'Pest'), ('Pere', 'Borsod-Abaúj-Zemplén'), ('Barabás', 'Szabolcs-Szatmár-Bereg'), ('Rábacsécsény', 'Győr-Moson-Sopron'), ('Kőszegpaty', 'Vas'), ('Kazincbarcika', 'Borsod-Abaúj-Zemplén'), ('Vácduka', 'Pest'), ('Vértestolna', 'Komárom-Esztergom'), ('Csomád', 'Pest'), ('Esztár', 'Hajdú-Bihar'), ('Hejőkürt', 'Borsod-Abaúj-Zemplén'), ('Kiscsősz', 'Veszprém'), ('Tiszanagyfalu', 'Szabolcs-Szatmár-Bereg'), ('Alsópetény', 'Nógrád'), ('Dánszentmiklós', 'Pest'), ('Nagyharsány', 'Baranya'), ('Nagyvenyim', 'Fejér'), ('Sárszentlőrinc', 'Tolna'), ('Monok', 'Borsod-Abaúj-Zemplén'), ('Váncsod', 'Hajdú-Bihar'), ('Szegilong', 'Borsod-Abaúj-Zemplén'), ('Mecseknádasd', 'Baranya'), ('Zákányszék', 'Csongrád'), ('Naszály', 'Komárom-Esztergom'), ('Kemeneskápolna', 'Vas'), ('Borsodszirák', 'Borsod-Abaúj-Zemplén'), ('Bakonszeg', 'Hajdú-Bihar'), ('Szabadegyháza', 'Fejér'), ('Érd', 'Pest'), ('Daruszentmiklós', 'Fejér'), ('Mezőgyán', 'Békés'), ('Vásárosmiske', 'Vas'), ('Izsófalva', 'Borsod-Abaúj-Zemplén'), ('Szanda', 'Nógrád'), ('Dormánd', 'Heves'), ('Belvárdgyula', 'Baranya'), ('Völcsej', 'Győr-Moson-Sopron'), ('Zalatárnok', 'Zala'), ('Mezőberény', 'Békés'), ('Békéssámson', 'Békés'), ('Jászjákóhalma', 'Jász-Nagykun-Szolnok'), ('Abda', 'Győr-Moson-Sopron'), ('Enying', 'Fejér'), ('Sióagárd', 'Tolna'), ('Szabolcs', 'Szabolcs-Szatmár-Bereg'), ('Nagyszekeres', 'Szabolcs-Szatmár-Bereg'), ('Csávoly', 'Bács-Kiskun'), ('Pér', 'Győr-Moson-Sopron'), ('Badacsonytördemic', 'Veszprém'), ('Perkupa', 'Borsod-Abaúj-Zemplén'), ('Jéke', 'Szabolcs-Szatmár-Bereg'), ('Maglód', 'Pest'), ('Dunavarsány', 'Pest'), ('Szűr', 'Baranya'), ('Körösnagyharsány', 'Békés'), ('Szalmatercs', 'Nógrád'), ('Dévaványa', 'Békés'), ('Nagybajcs', 'Győr-Moson-Sopron'), ('Hernádbűd', 'Borsod-Abaúj-Zemplén'), ('Nagyar', 'Szabolcs-Szatmár-Bereg'), ('Gyulaháza', 'Szabolcs-Szatmár-Bereg'), ('Nagycenk', 'Győr-Moson-Sopron'), ('Dámóc', 'Borsod-Abaúj-Zemplén'), ('Hidegkút', 'Veszprém'), ('Patvarc', 'Nógrád'), ('Héreg', 'Komárom-Esztergom'), ('Bázakerettye', 'Zala'), ('Gemzse', 'Szabolcs-Szatmár-Bereg'), ('Magyaralmás', 'Fejér'), ('Pacsa', 'Zala'), ('Szentkirályszabadja', 'Veszprém'), ('Gyöngyöshalász', 'Heves'), ('Vázsnok', 'Baranya'), ('Örkény', 'Pest'), ('Simaság', 'Vas'), ('Fábiánsebestyén', 'Csongrád'), ('Kurityán', 'Borsod-Abaúj-Zemplén'), ('Mérges', 'Győr-Moson-Sopron'), ('Áta', 'Baranya'), ('Hosszúpályi', 'Hajdú-Bihar'), ('Kulcs', 'Fejér'), ('Németkér', 'Tolna'), ('Sárkeresztúr', 'Fejér'), ('Nyírmada', 'Szabolcs-Szatmár-Bereg'), ('Ruzsa', 'Csongrád'), ('Káva', 'Pest'), ('Buj', 'Szabolcs-Szatmár-Bereg'), ('Alsónemesapáti', 'Zala'), ('Kisláng', 'Fejér'), ('Kállósemjén', 'Szabolcs-Szatmár-Bereg'), ('Borsosberény', 'Nógrád'), ('Csörnyeföld', 'Zala'), ('Cserhátsurány', 'Nógrád'), ('Tázlár', 'Bács-Kiskun'), ('Somogyacsa', 'Somogy'), ('Felsődobsza', 'Borsod-Abaúj-Zemplén'), ('Bosta', 'Baranya'), ('Lábatlan', 'Komárom-Esztergom'), ('Litka', 'Borsod-Abaúj-Zemplén'), ('Csincse', 'Borsod-Abaúj-Zemplén'), ('Borsodgeszt', 'Borsod-Abaúj-Zemplén'), ('Iregszemcse', 'Tolna'), ('Nikla', 'Somogy'), ('Kistokaj', 'Borsod-Abaúj-Zemplén'), ('Nemescsó', 'Vas'), ('Szentantalfa', 'Veszprém'), ('Bácsalmás', 'Bács-Kiskun'), ('Balatongyörök', 'Zala'), ('Maklár', 'Heves'), ('Gánt', 'Fejér'), ('Somogyszil', 'Somogy'), ('Tarnazsadány', 'Heves'), ('Adorjás', 'Baranya'), ('Bakonybél', 'Veszprém'), ('Nyírtét', 'Szabolcs-Szatmár-Bereg'), ('Gesztely', 'Borsod-Abaúj-Zemplén'), ('Terem', 'Szabolcs-Szatmár-Bereg'), ('Bolhó', 'Somogy'), ('Kunsziget', 'Győr-Moson-Sopron'), ('Balástya', 'Csongrád'), ('Gacsály', 'Szabolcs-Szatmár-Bereg'), ('Pécsely', 'Veszprém'), ('Salgótarján', 'Nógrád'), ('Gyermely', 'Komárom-Esztergom'), ('Nyírbogát', 'Szabolcs-Szatmár-Bereg'), ('Kemenesszentpéter', 'Veszprém'), ('Tolnanémedi', 'Tolna'), ('Nyírkarász', 'Szabolcs-Szatmár-Bereg'), ('Királyhegyes', 'Csongrád'), ('Semjén', 'Borsod-Abaúj-Zemplén'), ('Bátorliget', 'Szabolcs-Szatmár-Bereg'), ('Marcaltő', 'Veszprém'), ('Véménd', 'Baranya'), ('Zsámbok', 'Pest'), ('Hegyesd', 'Veszprém'), ('Jágónak', 'Tolna'), ('Nárai', 'Vas'), ('Okány', 'Békés'), ('Rábasebes', 'Győr-Moson-Sopron'), ('Homokszentgyörgy', 'Somogy'), ('Nagykinizs', 'Borsod-Abaúj-Zemplén'), ('Szarvas', 'Békés'), ('Petrikeresztúr', 'Zala'), ('Veszprémgalsa', 'Veszprém'), ('Gyugy', 'Somogy'), ('Baranyajenő', 'Baranya'), ('Egerfarmos', 'Heves'), ('Alsószentiván', 'Fejér'), ('Nagykapornak', 'Zala'), ('Németbánya', 'Veszprém'), ('Fenyőfő', 'Győr-Moson-Sopron'), ('Szigetszentmiklós', 'Pest'), ('Petneháza', 'Szabolcs-Szatmár-Bereg'), ('Kaposszekcső', 'Tolna'), ('Egyházashollós', 'Vas'), ('Nyírtass', 'Szabolcs-Szatmár-Bereg'), ('Újszász', 'Jász-Nagykun-Szolnok'), ('Gencsapáti', 'Vas'), ('Gamás', 'Somogy'), ('Németfalu', 'Zala'), ('Csatka', 'Komárom-Esztergom'), ('Jákó', 'Somogy'), ('Füzesgyarmat', 'Békés'), ('Balatonfőkajár', 'Veszprém'), ('Kunpeszér', 'Bács-Kiskun'), ('Bokod', 'Komárom-Esztergom'), ('Mezőkomárom', 'Fejér'), ('Bélapátfalva', 'Heves'), ('Tormafölde', 'Zala'), ('Egerág', 'Baranya'), ('Borszörcsök', 'Veszprém'), ('Soponya', 'Fejér'), ('Albertirsa', 'Pest'), ('Tokaj', 'Borsod-Abaúj-Zemplén'), ('Nyírderzs', 'Szabolcs-Szatmár-Bereg'), ('Petőháza', 'Győr-Moson-Sopron'), ('Ajka', 'Veszprém'), ('Varsád', 'Tolna'), ('Vértesszőlős', 'Komárom-Esztergom'), ('Muraszemenye', 'Zala'), ('Tengelic', 'Tolna'), ('Szamoskér', 'Szabolcs-Szatmár-Bereg'), ('Drávasztára', 'Baranya'), ('Telekes', 'Vas'), ('Bükkaranyos', 'Borsod-Abaúj-Zemplén'), ('Dunakeszi', 'Pest'), ('Héhalom', 'Nógrád'), ('Dudar', 'Veszprém'), ('Csegöld', 'Szabolcs-Szatmár-Bereg'), ('Porrog', 'Somogy'), ('Füzvölgy', 'Zala'), ('Bátya', 'Bács-Kiskun'), ('Sümegprága', 'Veszprém'), ('Újrónafő', 'Győr-Moson-Sopron'), ('Tömörkény', 'Csongrád'), ('Parasznya', 'Borsod-Abaúj-Zemplén'), ('Rum', 'Vas'), ('Kálmáncsa', 'Somogy'), ('Bakonytamási', 'Veszprém'), ('Felsőtold', 'Nógrád'), ('Söréd', 'Fejér'), ('Bakonycsernye', 'Fejér'), ('Csanádpalota', 'Csongrád'), ('Juta', 'Somogy'), ('Szentgyörgyvölgy', 'Zala'), ('Mezősas', 'Hajdú-Bihar'), ('Kőszeg', 'Vas'), ('Tápiószentmárton', 'Pest'), ('Újdombrád', 'Szabolcs-Szatmár-Bereg'), ('Göncruszka', 'Borsod-Abaúj-Zemplén'), ('Biatorbágy', 'Pest'), ('Tabdi', 'Bács-Kiskun'), ('Balatonszőlős', 'Veszprém'), ('Nagylengyel', 'Zala'), ('Dabronc', 'Veszprém'), ('Vajta', 'Fejér'), ('Okorág', 'Baranya'), ('Kapospula', 'Tolna'), ('Fót', 'Pest'), ('Pilisszentlászló', 'Pest'), ('Helvécia', 'Bács-Kiskun'), ('Gyűrűs', 'Zala'), ('Basal', 'Baranya'), ('Mikekarácsonyfa', 'Zala'), ('Bocska', 'Zala'), ('Drávaiványi', 'Baranya'), ('Nemesapáti', 'Zala'), ('Zalakomár', 'Zala'), ('Drégelypalánk', 'Nógrád'), ('Felsővadász', 'Borsod-Abaúj-Zemplén'), ('Rinyaújlak', 'Somogy'), ('Büssü', 'Somogy'), ('Kömpöc', 'Bács-Kiskun'), ('Tormás', 'Baranya'), ('Dédestapolcsány', 'Borsod-Abaúj-Zemplén'), ('Gátér', 'Bács-Kiskun'), ('Vásárosfalu', 'Győr-Moson-Sopron'), ('Kozmadombja', 'Zala'), ('Dunapataj', 'Bács-Kiskun'), ('Jászfényszaru', 'Jász-Nagykun-Szolnok'), ('Szalapa', 'Zala'), ('Homokmégy', 'Bács-Kiskun'), ('Veszkény', 'Győr-Moson-Sopron'), ('Baranyaszentgyörgy', 'Baranya'), ('Csabrendek', 'Veszprém'), ('Ecseg', 'Nógrád'), ('Ágasegyháza', 'Bács-Kiskun'), ('Marcalgergelyi', 'Veszprém'), ('Bodajk', 'Fejér'), ('Beret', 'Borsod-Abaúj-Zemplén'), ('Gérce', 'Vas'), ('Pányok', 'Borsod-Abaúj-Zemplén'), ('Báránd', 'Hajdú-Bihar'), ('Lajoskomárom', 'Fejér'), ('Csapod', 'Győr-Moson-Sopron'), ('Acsalag', 'Győr-Moson-Sopron'), ('Csurgó', 'Somogy'), ('Paszab', 'Szabolcs-Szatmár-Bereg'), ('Solymár', 'Pest'), ('Bábonymegyer', 'Somogy'), ('Vámosgyörk', 'Heves'), ('Homokkomárom', 'Zala'), ('Bocfölde', 'Zala'), ('Balatonakali', 'Veszprém'), ('Répcevis', 'Győr-Moson-Sopron'), ('Cserszegtomaj', 'Zala'), ('Ostffyasszonyfa', 'Vas'), ('Levél', 'Győr-Moson-Sopron'), ('Szúcs', 'Heves'), ('Rábaszentandrás', 'Győr-Moson-Sopron'), ('Selyeb', 'Borsod-Abaúj-Zemplén'), ('Nagydobos', 'Szabolcs-Szatmár-Bereg'), ('Apácatorna', 'Veszprém'), ('Mátételke', 'Bács-Kiskun'), ('Tiszaroff', 'Jász-Nagykun-Szolnok'), ('Nyírgyulaj', 'Szabolcs-Szatmár-Bereg'), ('Buják', 'Nógrád'), ('Hegyháthodász', 'Vas'), ('Csikvánd', 'Győr-Moson-Sopron'), ('Dusnok', 'Bács-Kiskun'), ('Kecskemét', 'Bács-Kiskun'), ('Patapoklosi', 'Baranya'), ('Szabolcsbáka', 'Szabolcs-Szatmár-Bereg'), ('Bácsszentgyörgy', 'Bács-Kiskun'), ('Ferencszállás', 'Csongrád'), ('Kisújszállás', 'Jász-Nagykun-Szolnok'), ('Nagygeresd', 'Vas'), ('Csorna', 'Győr-Moson-Sopron'), ('Böhönye', 'Somogy'), ('Nagyhalász', 'Szabolcs-Szatmár-Bereg'), ('Szántód', 'Somogy'), ('Szob', 'Pest'), ('Vasmegyer', 'Szabolcs-Szatmár-Bereg'), ('Dúzs', 'Tolna'), ('Drágszél', 'Bács-Kiskun'), ('Győröcske', 'Szabolcs-Szatmár-Bereg'), ('Tákos', 'Szabolcs-Szatmár-Bereg'), ('Csurgónagymarton', 'Somogy'), ('Táska', 'Somogy'), ('Csesztreg', 'Zala'), ('Mórichida', 'Győr-Moson-Sopron'), ('Harka', 'Győr-Moson-Sopron'), ('Bozsok', 'Vas'), ('Noszlop', 'Veszprém'), ('Terpes', 'Heves'), ('Dorogháza', 'Nógrád'), ('Erdősmecske', 'Baranya'), ('Szőce', 'Vas'), ('Nyírvasvári', 'Szabolcs-Szatmár-Bereg'), ('Nyalka', 'Győr-Moson-Sopron'), ('Páhi', 'Bács-Kiskun'), ('Prügy', 'Borsod-Abaúj-Zemplén'), ('Várdomb', 'Tolna'), ('Nógrádsáp', 'Nógrád'), ('Egerbakta', 'Heves'), ('Sopronkövesd', 'Győr-Moson-Sopron'), ('Adony', 'Fejér'), ('Hernádkércs', 'Borsod-Abaúj-Zemplén'), ('Cece', 'Fejér'), ('Pötréte', 'Zala'), ('Sajónémeti', 'Borsod-Abaúj-Zemplén'), ('Vasboldogasszony', 'Zala'), ('Cégénydányád', 'Szabolcs-Szatmár-Bereg'), ('Tiszakanyár', 'Szabolcs-Szatmár-Bereg'), ('Verőce', 'Pest'), ('Kenderes', 'Jász-Nagykun-Szolnok'), ('Szava', 'Baranya'), ('Kondó', 'Borsod-Abaúj-Zemplén'), ('Gyüre', 'Szabolcs-Szatmár-Bereg'), ('Balatonföldvár', 'Somogy'), ('Nagyvázsony', 'Veszprém'), ('Bodorfa', 'Veszprém'), ('Berettyóújfalu', 'Hajdú-Bihar'), ('Révfülöp', 'Veszprém'), ('Szuhafő', 'Borsod-Abaúj-Zemplén'), ('Kunszentmárton', 'Jász-Nagykun-Szolnok'), ('Fényeslitke', 'Szabolcs-Szatmár-Bereg'), ('Gelse', 'Zala'), ('Pilisborosjenő', 'Pest'), ('Bürüs', 'Baranya'), ('Pusztacsalád', 'Győr-Moson-Sopron'), ('Szilsárkány', 'Győr-Moson-Sopron'), ('Kékcse', 'Szabolcs-Szatmár-Bereg'), ('Vatta', 'Borsod-Abaúj-Zemplén'), ('Újcsanálos', 'Borsod-Abaúj-Zemplén'), ('Parádsasvár', 'Heves'), ('Kadarkút', 'Somogy'), ('Somogybabod', 'Somogy'), ('Rábapordány', 'Győr-Moson-Sopron'), ('Röszke', 'Csongrád'), ('Pusztamagyaród', 'Zala'), ('Vindornyalak', 'Zala'), ('Fadd', 'Tolna'), ('Sárrétudvari', 'Hajdú-Bihar'), ('Herencsény', 'Nógrád'), ('Csévharaszt', 'Pest'), ('Szécsényfelfalu', 'Nógrád'), ('Csép', 'Komárom-Esztergom'), ('Felsőgagy', 'Borsod-Abaúj-Zemplén'), ('Nyim', 'Somogy'), ('Táplánszentkereszt', 'Vas'), ('Milejszeg', 'Zala'), ('Csatár', 'Zala'), ('Tarpa', 'Szabolcs-Szatmár-Bereg'), ('Pápoc', 'Vas'), ('Győrújbarát', 'Győr-Moson-Sopron'), ('Moha', 'Fejér'), ('Márianosztra', 'Pest'), ('Velem', 'Vas'), ('Abaújszántó', 'Borsod-Abaúj-Zemplén'), ('Taktaharkány', 'Borsod-Abaúj-Zemplén'), ('Nagycsepely', 'Somogy'), ('Zalaszentgrót', 'Zala'), ('Komlósd', 'Somogy'), ('Szabadi', 'Somogy'), ('Rimóc', 'Nógrád'), ('Almamellék', 'Baranya'), ('Ászár', 'Komárom-Esztergom'), ('Gyulaj', 'Tolna'), ('Ináncs', 'Borsod-Abaúj-Zemplén'), ('Sormás', 'Zala'), ('Pázmándfalu', 'Győr-Moson-Sopron'), ('Pátyod', 'Szabolcs-Szatmár-Bereg'), ('Csaroda', 'Szabolcs-Szatmár-Bereg'), ('Konyár', 'Hajdú-Bihar'), ('Szentgyörgyvár', 'Zala'), ('Nyúl', 'Győr-Moson-Sopron'), ('Hévíz', 'Zala'), ('Pusztadobos', 'Szabolcs-Szatmár-Bereg'), ('Újfehértó', 'Szabolcs-Szatmár-Bereg'), ('Apátistvánfalva', 'Vas'), ('Tengeri', 'Baranya'), ('Zalaszentjakab', 'Zala'), ('Miháld', 'Zala'), ('Bőszénfa', 'Somogy'), ('Gödre', 'Baranya'), ('Gyöngyöstarján', 'Heves'), ('Mesterháza', 'Vas'), ('Malomsok', 'Veszprém'), ('Rozsály', 'Szabolcs-Szatmár-Bereg'), ('Móricgát', 'Bács-Kiskun'), ('Somogyvámos', 'Somogy'), ('Nemesrádó', 'Zala'), ('Gyömöre', 'Győr-Moson-Sopron'), ('Palotás', 'Nógrád'), ('Vasad', 'Pest'), ('Újsolt', 'Bács-Kiskun'), ('Nemesvid', 'Somogy'), ('Ebergőc', 'Győr-Moson-Sopron'), ('Pettend', 'Baranya'), ('Nagybárkány', 'Nógrád'), ('Ura', 'Szabolcs-Szatmár-Bereg'), ('Szólád', 'Somogy'), ('Csököly', 'Somogy'), ('Gyöngyösfalu', 'Vas'), ('Magyarhertelend', 'Baranya'), ('Beremend', 'Baranya'), ('Szigliget', 'Veszprém'), ('Cserdi', 'Baranya'), ('Dunasziget', 'Győr-Moson-Sopron'), ('Kánó', 'Borsod-Abaúj-Zemplén'), ('Bócsa', 'Bács-Kiskun'), ('Kallósd', 'Zala'), ('Igal', 'Somogy'), ('Balatonfüred', 'Veszprém'), ('Kocsord', 'Szabolcs-Szatmár-Bereg'), ('Valkó', 'Pest'), ('Bér', 'Nógrád'), ('Dubicsány', 'Borsod-Abaúj-Zemplén'), ('Nagybajom', 'Somogy'), ('Petőmihályfa', 'Vas'), ('Mindszentgodisa', 'Baranya'), ('Kám', 'Vas'), ('Szany', 'Győr-Moson-Sopron'), ('Szár', 'Fejér'), ('Mezőpeterd', 'Hajdú-Bihar'), ('Perbál', 'Pest'), ('Fajsz', 'Bács-Kiskun'), ('Bicsérd', 'Baranya'), ('Rajka', 'Győr-Moson-Sopron'), ('Piliny', 'Nógrád'), ('Pálfa', 'Tolna'), ('Pereked', 'Baranya'), ('Ugod', 'Veszprém'), ('Kisigmánd', 'Komárom-Esztergom'), ('Kaposvár', 'Somogy'), ('Barlahida', 'Zala'), ('Gordisa', 'Baranya'), ('Forró', 'Borsod-Abaúj-Zemplén'), ('Szin', 'Borsod-Abaúj-Zemplén'), ('Pusztakovácsi', 'Somogy'), ('Dömös', 'Komárom-Esztergom'), ('Szaknyér', 'Vas'), ('Felsőszenterzsébet', 'Zala'), ('Nagyhuta', 'Borsod-Abaúj-Zemplén'), ('Ete', 'Komárom-Esztergom'), ('Gelej', 'Borsod-Abaúj-Zemplén'), ('Kamut', 'Békés'), ('Dunaújváros', 'Fejér'), ('Szigetújfalu', 'Pest'), ('Alsóörs', 'Veszprém'), ('Lepsény', 'Fejér'), ('Kiszsidány', 'Vas'), ('Réde', 'Komárom-Esztergom'), ('Szakadát', 'Tolna'), ('Tiszaladány', 'Borsod-Abaúj-Zemplén'), ('Cserépváralja', 'Borsod-Abaúj-Zemplén'), ('Pogány', 'Baranya'), ('Zalaszentmárton', 'Zala'), ('Nyírbátor', 'Szabolcs-Szatmár-Bereg'), ('Zsadány', 'Békés'), ('Sávoly', 'Somogy'), ('Magyarsarlós', 'Baranya'), ('Nyirád', 'Veszprém'), ('Bánfa', 'Baranya'), ('Gönc', 'Borsod-Abaúj-Zemplén'), ('Nemessándorháza', 'Zala'), ('Bodmér', 'Fejér'), ('Iklódbördőce', 'Zala'), ('Szalatnak', 'Baranya'), ('Zajk', 'Zala'), ('Kövegy', 'Csongrád'), ('Nemesvita', 'Veszprém'), ('Madocsa', 'Tolna'), ('Hernyék', 'Zala'), ('Nagykovácsi', 'Pest'), ('Szuhogy', 'Borsod-Abaúj-Zemplén'), ('Andornaktálya', 'Heves'), ('Tolna', 'Tolna'), ('Kecel', 'Bács-Kiskun'), ('Nyírpazony', 'Szabolcs-Szatmár-Bereg'), ('Felcsút', 'Fejér'), ('Kisbabot', 'Győr-Moson-Sopron'), ('Jánoshida', 'Jász-Nagykun-Szolnok'), ('Zalaszentbalázs', 'Zala'), ('Putnok', 'Borsod-Abaúj-Zemplén'), ('Szörény', 'Baranya'), ('Papos', 'Szabolcs-Szatmár-Bereg'), ('Alsónána', 'Tolna'), ('Rétság', 'Nógrád'), ('Földes', 'Hajdú-Bihar'), ('Erzsébet', 'Baranya'), ('Vásárosnamény', 'Szabolcs-Szatmár-Bereg'), ('Köröstarcsa', 'Békés'), ('Kissomlyó', 'Vas'), ('Paks', 'Tolna'), ('Gyékényes', 'Somogy'), ('Nyírábrány', 'Hajdú-Bihar'), ('Győrsövényház', 'Győr-Moson-Sopron'), ('Alsószentmárton', 'Baranya'), ('Garadna', 'Borsod-Abaúj-Zemplén'), ('Nagyveleg', 'Fejér'), ('Szigethalom', 'Pest'), ('Monaj', 'Borsod-Abaúj-Zemplén'), ('Óbánya', 'Baranya'), ('Előszállás', 'Fejér'), ('Kővágószőlős', 'Baranya'), ('Litér', 'Veszprém'), ('Bükkszentmárton', 'Heves'), ('Izmény', 'Tolna'), ('Bokor', 'Nógrád'), ('Baj', 'Komárom-Esztergom'), ('Rád', 'Pest'), ('Ózdfalu', 'Baranya'), ('Boldog', 'Heves'), ('Somlójenő', 'Veszprém'), ('Dáka', 'Veszprém'), ('Geszt', 'Békés'), ('Garé', 'Baranya'), ('Tomajmonostora', 'Jász-Nagykun-Szolnok'), ('Őrhalom', 'Nógrád'), ('Kovácshida', 'Baranya'), ('Tabajd', 'Fejér'), ('Szada', 'Pest'), ('Szijártóháza', 'Zala'), ('Gödöllő', 'Pest'), ('Kávás', 'Zala'), ('Oltárc', 'Zala'), ('Pilisszentiván', 'Pest'), ('Tass', 'Bács-Kiskun'), ('Nógrádszakál', 'Nógrád'), ('Heresznye', 'Somogy'), ('Bojt', 'Hajdú-Bihar'), ('Csökmő', 'Hajdú-Bihar'), ('Bakonysárkány', 'Komárom-Esztergom'), ('Füzesabony', 'Heves'), ('Küngös', 'Veszprém'), ('Attala', 'Tolna'), ('Nagybörzsöny', 'Pest'), ('Szemere', 'Borsod-Abaúj-Zemplén'), ('Kupa', 'Borsod-Abaúj-Zemplén'), ('Sajógalgóc', 'Borsod-Abaúj-Zemplén'), ('Sáregres', 'Fejér'), ('Nagyváty', 'Baranya'), ('Mihályi', 'Győr-Moson-Sopron'), ('Pecöl', 'Vas'), ('Csehbánya', 'Veszprém'), ('Felsőnyárád', 'Borsod-Abaúj-Zemplén'), ('Kondorfa', 'Vas'), ('Hegyhátszentpéter', 'Vas'), ('Répceszentgyörgy', 'Vas'), ('Vajszló', 'Baranya'), ('Vámosújfalu', 'Borsod-Abaúj-Zemplén'), ('Bácsborsód', 'Bács-Kiskun'), ('Abaliget', 'Baranya'), ('Bózsva', 'Borsod-Abaúj-Zemplén'), ('Kálmánháza', 'Szabolcs-Szatmár-Bereg'), ('Parád', 'Heves'), ('Szellő', 'Baranya'), ('Pápasalamon', 'Veszprém'), ('Budakalász', 'Pest'), ('Nyergesújfalu', 'Komárom-Esztergom'), ('Rácalmás', 'Fejér'), ('Mencshely', 'Veszprém'), ('Tilaj', 'Zala'), ('Nábrád', 'Szabolcs-Szatmár-Bereg'), ('Kocs', 'Komárom-Esztergom'), ('Tápszentmiklós', 'Győr-Moson-Sopron'), ('Sima', 'Borsod-Abaúj-Zemplén'), ('Szelevény', 'Jász-Nagykun-Szolnok'), ('Mezőkövesd', 'Borsod-Abaúj-Zemplén'), ('Ságvár', 'Somogy'), ('Báta', 'Tolna'), ('Dombrád', 'Szabolcs-Szatmár-Bereg'), ('Nova', 'Zala'), ('Som', 'Somogy'), ('Rábacsanak', 'Győr-Moson-Sopron'), ('Debréte', 'Borsod-Abaúj-Zemplén'), ('Berekböszörmény', 'Hajdú-Bihar'), ('Bajna', 'Komárom-Esztergom'), ('Rádfalva', 'Baranya'), ('Zalameggyes', 'Veszprém'), ('Mád', 'Borsod-Abaúj-Zemplén'), ('Nak', 'Tolna'), ('Téglás', 'Hajdú-Bihar'), ('Tompa', 'Bács-Kiskun'), ('Vaszar', 'Veszprém'), ('Ecsegfalva', 'Békés'), ('Nagycsécs', 'Borsod-Abaúj-Zemplén'), ('Mátyásdomb', 'Fejér'), ('Mocsa', 'Komárom-Esztergom'), ('Tiszagyenda', 'Jász-Nagykun-Szolnok'), ('Megyer', 'Veszprém'), ('Ádánd', 'Somogy'), ('Tiszakécske', 'Bács-Kiskun'), ('Erdőbénye', 'Borsod-Abaúj-Zemplén'), ('Dénesfa', 'Győr-Moson-Sopron'), ('Ecser', 'Pest'), ('Patak', 'Nógrád'), ('Révleányvár', 'Borsod-Abaúj-Zemplén'), ('Rábcakapi', 'Győr-Moson-Sopron'), ('Szuhakálló', 'Borsod-Abaúj-Zemplén'), ('Tótszentgyörgy', 'Baranya'), ('Zabar', 'Nógrád'), ('Veresegyház', 'Pest'), ('Somogybükkösd', 'Somogy'), ('Batyk', 'Zala'), ('Méhkerék', 'Békés'), ('Répáshuta', 'Borsod-Abaúj-Zemplén'), ('Ikrény', 'Győr-Moson-Sopron'), ('Óhid', 'Zala'), ('Szászberek', 'Jász-Nagykun-Szolnok'), ('Szepetnek', 'Zala'), ('Endrefalva', 'Nógrád'), ('Törökkoppány', 'Somogy'), ('Balatonboglár', 'Somogy'), ('Tibolddaróc', 'Borsod-Abaúj-Zemplén'), ('Cakóháza', 'Győr-Moson-Sopron'), ('Szederkény', 'Baranya'), ('Porrogszentpál', 'Somogy'), ('Abony', 'Pest'), ('Alsópáhok', 'Zala'), ('Detek', 'Borsod-Abaúj-Zemplén'), ('Szentistvánbaksa', 'Borsod-Abaúj-Zemplén'), ('Iborfia', 'Zala'), ('Borsodbóta', 'Borsod-Abaúj-Zemplén'), ('Geresdlak', 'Baranya'), ('Pásztori', 'Győr-Moson-Sopron'), ('Zákányfalu', 'Somogy'), ('Sajópetri', 'Borsod-Abaúj-Zemplén'), ('Bátmonostor', 'Bács-Kiskun'), ('Jászalsószentgyörgy', 'Jász-Nagykun-Szolnok'), ('Bucsuta', 'Zala'), ('Kapolcs', 'Veszprém'), ('Besnyő', 'Fejér'), ('Zalaszentmihály', 'Zala'), ('Zamárdi', 'Somogy'), ('Balotaszállás', 'Bács-Kiskun'), ('Leányfalu', 'Pest'), ('Ölbő', 'Vas'), ('Nemeskér', 'Győr-Moson-Sopron'), ('Tatabánya', 'Komárom-Esztergom'), ('Verseg', 'Pest'), ('Várgesztes', 'Komárom-Esztergom'), ('Nádasd', 'Vas'), ('Tarnaméra', 'Heves'), ('Jászkisér', 'Jász-Nagykun-Szolnok'), ('Balaton', 'Heves'), ('Bátonyterenye', 'Nógrád'), ('Gelsesziget', 'Zala'), ('Kishódos', 'Szabolcs-Szatmár-Bereg'), ('Penyige', 'Szabolcs-Szatmár-Bereg'), ('Pornóapáti', 'Vas'), ('Ják', 'Vas'), ('Jákfa', 'Vas'), ('Palé', 'Baranya'), ('Újszentiván', 'Csongrád'), ('Zsana', 'Bács-Kiskun'), ('Jászberény', 'Jász-Nagykun-Szolnok'), ('Monostorapáti', 'Veszprém'), ('Kápolnásnyék', 'Fejér'), ('Tüskevár', 'Veszprém'), ('Vadosfa', 'Győr-Moson-Sopron'), ('Sáp', 'Hajdú-Bihar'), ('Szenta', 'Somogy'), ('Tótvázsony', 'Veszprém'), ('Mátraszele', 'Nógrád'), ('Lucfalva', 'Nógrád'), ('Boncodfölde', 'Zala'), ('Magyaregregy', 'Baranya'), ('Tiszavasvári', 'Szabolcs-Szatmár-Bereg'), ('Homokbödöge', 'Veszprém'), ('Pilisjászfalu', 'Pest'), ('Tótszerdahely', 'Zala'), ('Sé', 'Vas'), ('Egyházaskozár', 'Baranya'), ('Pusztaföldvár', 'Békés'), ('Kutas', 'Somogy'), ('Vizslás', 'Nógrád'), ('Boldogkőújfalu', 'Borsod-Abaúj-Zemplén'), ('Öcs', 'Veszprém'), ('Sopronhorpács', 'Győr-Moson-Sopron'), ('Borzavár', 'Veszprém'), ('Bezenye', 'Győr-Moson-Sopron'), ('Hangony', 'Borsod-Abaúj-Zemplén'), ('Lothárd', 'Baranya'), ('Bárdudvarnok', 'Somogy'), ('Bogád', 'Baranya'), ('Szabadszállás', 'Bács-Kiskun'), ('Bucsuszentlászló', 'Zala'), ('Győr', 'Győr-Moson-Sopron'), ('Szőkéd', 'Baranya'), ('Csibrák', 'Tolna'), ('Szentborbás', 'Somogy'), ('Vasvár', 'Vas'), ('Sótony', 'Vas'), ('Simontornya', 'Tolna'), ('Tapolca', 'Veszprém'), ('Felsőzsolca', 'Borsod-Abaúj-Zemplén'), ('Berzence', 'Somogy'), ('Magyardombegyház', 'Békés'), ('Somogyszob', 'Somogy'), ('Babarcszőlős', 'Baranya'), ('Majosháza', 'Pest'), ('Balatonfűzfő', 'Veszprém'), ('Hollóháza', 'Borsod-Abaúj-Zemplén'), ('Keléd', 'Vas'), ('Nagylók', 'Fejér'), ('Sámsonháza', 'Nógrád'), ('Baksa', 'Baranya'), ('Darnózseli', 'Győr-Moson-Sopron'), ('Kovácsszénája', 'Baranya'), ('Tiszaújváros', 'Borsod-Abaúj-Zemplén'), ('Ipolytölgyes', 'Pest'), ('Korlát', 'Borsod-Abaúj-Zemplén'), ('Kelevíz', 'Somogy'), ('Lickóvadamos', 'Zala'), ('Rátka', 'Borsod-Abaúj-Zemplén'), ('Tápióbicske', 'Pest'), ('Répceszemere', 'Győr-Moson-Sopron'), ('Simonfa', 'Somogy'), ('Kány', 'Borsod-Abaúj-Zemplén'), ('Letenye', 'Zala'), ('Újtelek', 'Bács-Kiskun'), ('Kishajmás', 'Baranya'), ('Sumony', 'Baranya'), ('Fertőszéplak', 'Győr-Moson-Sopron'), ('Segesd', 'Somogy'), ('Mezőcsát', 'Borsod-Abaúj-Zemplén'), ('Berzék', 'Borsod-Abaúj-Zemplén'), ('Egerszalók', 'Heves'), ('Pilisszántó', 'Pest'), ('Dunaremete', 'Győr-Moson-Sopron'), ('Kisdobsza', 'Baranya'), ('Kánya', 'Somogy'), ('Csörög', 'Pest'), ('Ládbesenyő', 'Borsod-Abaúj-Zemplén'), ('Nemeske', 'Baranya'), ('Egyházasrádóc', 'Vas'), ('Cserépfalu', 'Borsod-Abaúj-Zemplén'), ('Gyöngyös', 'Heves'), ('Visegrád', 'Pest'), ('Karancsberény', 'Nógrád'), ('Sajószöged', 'Borsod-Abaúj-Zemplén'), ('Pácsony', 'Vas'), ('Nagybudmér', 'Baranya'), ('Szamosbecs', 'Szabolcs-Szatmár-Bereg'), ('Felsőegerszeg', 'Baranya'), ('Jásztelek', 'Jász-Nagykun-Szolnok'), ('Szamosszeg', 'Szabolcs-Szatmár-Bereg'), ('Tiszajenő', 'Jász-Nagykun-Szolnok'), ('Aka', 'Komárom-Esztergom'), ('Viszák', 'Vas'), ('Mánfa', 'Baranya'), ('Tarjánpuszta', 'Győr-Moson-Sopron'), ('Sümeg', 'Veszprém'), ('Mérk', 'Szabolcs-Szatmár-Bereg'), ('Bihardancsháza', 'Hajdú-Bihar'), ('Cserháthaláp', 'Nógrád'), ('Kehidakustány', 'Zala'), ('Vinár', 'Veszprém'), ('Zalaszentlászló', 'Zala'), ('Molnári', 'Zala'), ('Rinyabesenyő', 'Somogy'), ('Drávacsepely', 'Baranya'), ('Rátót', 'Vas'), ('Biharugra', 'Békés'), ('Nagyhegyes', 'Hajdú-Bihar'), ('Nagyrábé', 'Hajdú-Bihar'), ('Kismányok', 'Tolna'), ('Besenyszög', 'Jász-Nagykun-Szolnok'), ('Kántorjánosi', 'Szabolcs-Szatmár-Bereg'), ('Tataháza', 'Bács-Kiskun'), ('Encsencs', 'Szabolcs-Szatmár-Bereg'), ('Bakonygyirót', 'Győr-Moson-Sopron'), ('Dobronhegy', 'Zala'), ('Eszteregnye', 'Zala'), ('Tiszadada', 'Szabolcs-Szatmár-Bereg'), ('Szenna', 'Somogy'), ('Kőröstetétlen', 'Pest'), ('Bordány', 'Csongrád'), ('Kál', 'Heves'), ('Vajdácska', 'Borsod-Abaúj-Zemplén'), ('Endrőc', 'Baranya'), ('Murarátka', 'Zala'), ('Halmaj', 'Borsod-Abaúj-Zemplén'), ('Öskü', 'Veszprém'), ('Somodor', 'Somogy'), ('Nemesszentandrás', 'Zala'), ('Pusztamonostor', 'Jász-Nagykun-Szolnok'), ('Beloiannisz', 'Fejér'), ('Karancskeszi', 'Nógrád'), ('Dörgicse', 'Veszprém'), ('Mihályháza', 'Veszprém'), ('Városföld', 'Bács-Kiskun'), ('Mindszentkálla', 'Veszprém'), ('Legyesbénye', 'Borsod-Abaúj-Zemplén'), ('Szeged', 'Csongrád'), ('Kázsmárk', 'Borsod-Abaúj-Zemplén'), ('Kiscsehi', 'Zala'), ('Karancsalja', 'Nógrád'), ('Tar', 'Nógrád'), ('Ladánybene', 'Bács-Kiskun'), ('Ásványráró', 'Győr-Moson-Sopron'), ('Szilvásszentmárton', 'Somogy'), ('Zánka', 'Veszprém'), ('Tarrós', 'Baranya'), ('Szirmabesenyő', 'Borsod-Abaúj-Zemplén'), ('Visz', 'Somogy'), ('Tuzsér', 'Szabolcs-Szatmár-Bereg'), ('Magyarkeszi', 'Tolna'), ('Zubogy', 'Borsod-Abaúj-Zemplén'), ('Alsóregmec', 'Borsod-Abaúj-Zemplén'), ('Háromfa', 'Somogy'), ('Sopronnémeti', 'Győr-Moson-Sopron'), ('Galgaguta', 'Nógrád'), ('Bisse', 'Baranya'), ('Elek', 'Békés'), ('Magyarszecsőd', 'Vas'), ('Aszófő', 'Veszprém'), ('Nagytevel', 'Veszprém'), ('Patalom', 'Somogy'), ('Nemeskocs', 'Vas'), ('Jászapáti', 'Jász-Nagykun-Szolnok'), ('Sényő', 'Szabolcs-Szatmár-Bereg'), ('Kemendollár', 'Zala'), ('Jobaháza', 'Győr-Moson-Sopron'), ('Köblény', 'Baranya'), ('Besenyőd', 'Szabolcs-Szatmár-Bereg'), ('Kaposszerdahely', 'Somogy'), ('Hosztót', 'Veszprém'), ('Hegymeg', 'Borsod-Abaúj-Zemplén'), ('Csoma', 'Somogy'), ('Nyáregyháza', 'Pest'), ('Léh', 'Borsod-Abaúj-Zemplén'), ('Pat', 'Zala'), ('Körösszakál', 'Hajdú-Bihar'), ('Ordacsehi', 'Somogy'), ('Biharkeresztes', 'Hajdú-Bihar'), ('Kölesd', 'Tolna'), ('Magyarszombatfa', 'Vas'), ('Miskolc', 'Borsod-Abaúj-Zemplén'), ('Jászszentlászló', 'Bács-Kiskun'), ('Libickozma', 'Somogy'), ('Perecse', 'Borsod-Abaúj-Zemplén'), ('Mikebuda', 'Pest'), ('Ganna', 'Veszprém'), ('Ricse', 'Borsod-Abaúj-Zemplén'), ('Berhida', 'Veszprém'), ('Döbrököz', 'Tolna'), ('Karád', 'Somogy'), ('Kustánszeg', 'Zala'), ('Bugyi', 'Pest'), ('Kálócfa', 'Zala'), ('Nyékládháza', 'Borsod-Abaúj-Zemplén'), ('Telki', 'Pest'), ('Zemplénagárd', 'Borsod-Abaúj-Zemplén'), ('Kaposmérő', 'Somogy'), ('Mezőnagymihály', 'Borsod-Abaúj-Zemplén'), ('Pilisvörösvár', 'Pest'), ('Murga', 'Tolna'), ('Söpte', 'Vas'), ('Somogyaracs', 'Somogy'), ('Tiszanána', 'Heves'), ('Molvány', 'Baranya'), ('Nagyigmánd', 'Komárom-Esztergom'), ('Vönöck', 'Vas'), ('Nagyrozvágy', 'Borsod-Abaúj-Zemplén'), ('Zagyvaszántó', 'Heves'), ('Merenye', 'Baranya'), ('Balkány', 'Szabolcs-Szatmár-Bereg'), ('Fertőszentmiklós', 'Győr-Moson-Sopron'), ('Hegyszentmárton', 'Baranya'), ('Tarnaszentmiklós', 'Heves'), ('Jászdózsa', 'Jász-Nagykun-Szolnok'), ('Vashosszúfalu', 'Vas'), ('Ács', 'Komárom-Esztergom'), ('Sarud', 'Heves'), ('Kemecse', 'Szabolcs-Szatmár-Bereg'), ('Hont', 'Nógrád'), ('Tornyiszentmiklós', 'Zala'), ('Somogyapáti', 'Baranya'), ('Zsira', 'Győr-Moson-Sopron'), ('Kisasszonyfa', 'Baranya'), ('Káld', 'Vas'), ('Pusztavám', 'Fejér'), ('Pásztó', 'Nógrád'), ('Gersekarát', 'Vas'), ('Kamond', 'Veszprém'), ('Bodrogkisfalud', 'Borsod-Abaúj-Zemplén'), ('Nyírkáta', 'Szabolcs-Szatmár-Bereg'), ('Karancsság', 'Nógrád'), ('Kondoros', 'Békés'), ('Udvari', 'Tolna'), ('Mátraszentimre', 'Heves'), ('Tarján', 'Komárom-Esztergom'), ('Hirics', 'Baranya'), ('Csokvaomány', 'Borsod-Abaúj-Zemplén'), ('Tiszadorogma', 'Borsod-Abaúj-Zemplén'), ('Fonyód', 'Somogy'), ('Tomor', 'Borsod-Abaúj-Zemplén'), ('Jármi', 'Szabolcs-Szatmár-Bereg'), ('Bükkmogyorósd', 'Borsod-Abaúj-Zemplén'), ('Karakó', 'Vas'), ('Magyarföld', 'Zala'), ('Mesteri', 'Vas'), ('Gyöngyösmellék', 'Baranya'), ('Hernádpetri', 'Borsod-Abaúj-Zemplén'), ('Tornyosnémeti', 'Borsod-Abaúj-Zemplén'), ('Kőkút', 'Somogy'), ('Vadna', 'Borsod-Abaúj-Zemplén'), ('Veszprém', 'Veszprém'), ('Csobánka', 'Pest'), ('Bajót', 'Komárom-Esztergom'), ('Bakonynána', 'Veszprém'), ('Sajólászlófalva', 'Borsod-Abaúj-Zemplén'), ('Tyukod', 'Szabolcs-Szatmár-Bereg'), ('Vát', 'Vas'), ('Tésenfa', 'Baranya'), ('Somogyaszaló', 'Somogy'), ('Bánréve', 'Borsod-Abaúj-Zemplén'), ('Kenézlő', 'Borsod-Abaúj-Zemplén'), ('Kispalád', 'Szabolcs-Szatmár-Bereg'), ('Abaújvár', 'Borsod-Abaúj-Zemplén'), ('Vágáshuta', 'Borsod-Abaúj-Zemplén'), ('Katádfa', 'Baranya'), ('Sárpilis', 'Tolna'), ('Jászivány', 'Jász-Nagykun-Szolnok'), ('Kömörő', 'Szabolcs-Szatmár-Bereg'), ('Lőrinci', 'Heves'), ('Napkor', 'Szabolcs-Szatmár-Bereg'), ('Csömend', 'Somogy'), ('Vállaj', 'Szabolcs-Szatmár-Bereg'), ('Kányavár', 'Zala'), ('Jenő', 'Fejér'), ('Románd', 'Győr-Moson-Sopron'), ('Pusztaszemes', 'Somogy'), ('Egyházasfalu', 'Győr-Moson-Sopron'), ('Farkaslyuk', 'Borsod-Abaúj-Zemplén'), ('Nagyér', 'Csongrád'), ('Garáb', 'Nógrád'), ('Csebény', 'Baranya'), ('Kömlőd', 'Komárom-Esztergom'), ('Pánd', 'Pest'), ('Baktalórántháza', 'Szabolcs-Szatmár-Bereg'), ('Tarnalelesz', 'Heves'), ('Mezőszilas', 'Fejér'), ('Szátok', 'Nógrád'), ('Bakonypéterd', 'Győr-Moson-Sopron'), ('Timár', 'Szabolcs-Szatmár-Bereg'), ('Szőlősgyörök', 'Somogy'), ('Tiszasüly', 'Jász-Nagykun-Szolnok'), ('Geszteréd', 'Szabolcs-Szatmár-Bereg'), ('Kesztölc', 'Komárom-Esztergom'), ('Hejőbába', 'Borsod-Abaúj-Zemplén'), ('Hortobágy', 'Hajdú-Bihar'), ('Őrimagyarósd', 'Vas'), ('Nagyecsed', 'Szabolcs-Szatmár-Bereg'), ('Nagyvejke', 'Tolna'), ('Pomáz', 'Pest'), ('Végegyháza', 'Békés'), ('Csárdaszállás', 'Békés'), ('Tornakápolna', 'Borsod-Abaúj-Zemplén'), ('Kastélyosdombó', 'Somogy'), ('Csikóstőttős', 'Tolna'), ('Újiráz', 'Hajdú-Bihar'), ('Penészlek', 'Szabolcs-Szatmár-Bereg'), ('Kerékteleki', 'Komárom-Esztergom'), ('Babócsa', 'Somogy'), ('Dávod', 'Bács-Kiskun'), ('Királyszentistván', 'Veszprém'), ('Újszalonta', 'Békés'), ('Berekfürdő', 'Jász-Nagykun-Szolnok'), ('Zsáka', 'Hajdú-Bihar'), ('Bár', 'Baranya'), ('Háromhuta', 'Borsod-Abaúj-Zemplén'), ('Pécsdevecser', 'Baranya'), ('Visnye', 'Somogy'), ('Berkesz', 'Szabolcs-Szatmár-Bereg'), ('Bükkösd', 'Baranya'), ('Szőc', 'Veszprém'), ('Hét', 'Borsod-Abaúj-Zemplén'), ('Kiskunfélegyháza', 'Bács-Kiskun'), ('Márokföld', 'Zala'), ('Nagymaros', 'Pest'), ('Martonyi', 'Borsod-Abaúj-Zemplén'), ('Kerkakutas', 'Zala'), ('Sükösd', 'Bács-Kiskun'), ('Zalalövő', 'Zala'), ('Kemenesszentmárton', 'Vas'), ('Alsóújlak', 'Vas'), ('Örményes', 'Jász-Nagykun-Szolnok'), ('Magyarbóly', 'Baranya'), ('Hahót', 'Zala'), ('Taktaszada', 'Borsod-Abaúj-Zemplén'), ('Somogyvár', 'Somogy'), ('Nagytálya', 'Heves'), ('Halászi', 'Győr-Moson-Sopron'), ('Magyarbánhegyes', 'Békés'), ('Sorkikápolna', 'Vas'), ('Tinnye', 'Pest'), ('Arló', 'Borsod-Abaúj-Zemplén'), ('Monostorpályi', 'Hajdú-Bihar'), ('Nádudvar', 'Hajdú-Bihar'), ('Piricse', 'Szabolcs-Szatmár-Bereg'), ('Debrecen', 'Hajdú-Bihar'), ('Kisbucsa', 'Zala'), ('Illocska', 'Baranya'), ('Hajdúszovát', 'Hajdú-Bihar'), ('Csataszög', 'Jász-Nagykun-Szolnok'), ('Egerbocs', 'Heves'), ('Csabacsűd', 'Békés'), ('Bánhorváti', 'Borsod-Abaúj-Zemplén'), ('Nemesnádudvar', 'Bács-Kiskun'), ('Tikos', 'Somogy'), ('Kisszekeres', 'Szabolcs-Szatmár-Bereg'), ('Gellénháza', 'Zala'), ('Fülesd', 'Szabolcs-Szatmár-Bereg'), ('Taszár', 'Somogy'), ('Tékes', 'Baranya'), ('Abaújszolnok', 'Borsod-Abaúj-Zemplén'), ('Dány', 'Pest'), ('Szentgotthárd', 'Vas'), ('Folyás', 'Hajdú-Bihar'), ('Szulok', 'Somogy'), ('Kálló', 'Nógrád'), ('Lippó', 'Baranya'), ('Horpács', 'Nógrád'), ('Lovászpatona', 'Veszprém'), ('Sajóörös', 'Borsod-Abaúj-Zemplén'), ('Hejőpapi', 'Borsod-Abaúj-Zemplén'), ('Külsővat', 'Veszprém'), ('Rábapaty', 'Vas'), ('Dabrony', 'Veszprém'), ('Nagytőke', 'Csongrád'), ('Várda', 'Somogy'), ('Császló', 'Szabolcs-Szatmár-Bereg'), ('Becske', 'Nógrád'), ('Okorvölgy', 'Baranya'), ('Somogyudvarhely', 'Somogy'), ('Úrkút', 'Veszprém'), ('Mohács', 'Baranya'), ('Sérsekszőlős', 'Somogy'), ('Bódvalenke', 'Borsod-Abaúj-Zemplén'), ('Hidas', 'Baranya'), ('Nemesgulács', 'Veszprém'), ('Babarc', 'Baranya'), ('Bélmegyer', 'Békés'), ('Csáfordjánosfa', 'Győr-Moson-Sopron'), ('Alcsútdoboz', 'Fejér'), ('Csemő', 'Pest'), ('Bezedek', 'Baranya'), ('Mártély', 'Csongrád'), ('Pirtó', 'Bács-Kiskun'), ('Túrkeve', 'Jász-Nagykun-Szolnok'), ('Raposka', 'Veszprém'), ('Üröm', 'Pest'), ('Kakucs', 'Pest'), ('Császár', 'Komárom-Esztergom'), ('Csólyospálos', 'Bács-Kiskun'), ('Szenyér', 'Somogy'), ('Tállya', 'Borsod-Abaúj-Zemplén'), ('Fegyvernek', 'Jász-Nagykun-Szolnok'), ('Zala', 'Somogy'), ('Abádszalók', 'Jász-Nagykun-Szolnok'), ('Ócsárd', 'Baranya'), ('Füzérradvány', 'Borsod-Abaúj-Zemplén'), ('Becsvölgye', 'Zala'), ('Nyírcsaholy', 'Szabolcs-Szatmár-Bereg'), ('Gyarmat', 'Győr-Moson-Sopron'), ('Pócsa', 'Baranya'), ('Patca', 'Somogy'), ('Pereszteg', 'Győr-Moson-Sopron'), ('Sóstófalva', 'Borsod-Abaúj-Zemplén'), ('Bonnya', 'Somogy'), ('Somberek', 'Baranya'), ('Bekölce', 'Heves'), ('Ukk', 'Veszprém'), ('Kisbajom', 'Somogy'), ('Csörötnek', 'Vas'), ('Szarvaskő', 'Heves'), ('Tiszabura', 'Jász-Nagykun-Szolnok'), ('Igrici', 'Borsod-Abaúj-Zemplén'), ('Rétalap', 'Győr-Moson-Sopron'), ('Somogysárd', 'Somogy'), ('Öttevény', 'Győr-Moson-Sopron'), ('Pósfa', 'Vas'), ('Tác', 'Fejér'), ('Alsószölnök', 'Vas'), ('Sárisáp', 'Komárom-Esztergom'), ('Mikóháza', 'Borsod-Abaúj-Zemplén'), ('Körösladány', 'Békés'), ('Kisfüzes', 'Heves'), ('Örménykút', 'Békés'), ('Sajópálfala', 'Borsod-Abaúj-Zemplén'), ('Levelek', 'Szabolcs-Szatmár-Bereg'), ('Harkány', 'Baranya'), ('Berkenye', 'Nógrád'), ('Dinnyeberki', 'Baranya'), ('Demjén', 'Heves'), ('Kiskutas', 'Zala'), ('Rinyakovácsi', 'Somogy'), ('Felsőkelecsény', 'Borsod-Abaúj-Zemplén'), ('Sitke', 'Vas'), ('Gömörszőlős', 'Borsod-Abaúj-Zemplén'), ('Pákozd', 'Fejér'), ('Mezőhegyes', 'Békés'), ('Géderlak', 'Bács-Kiskun'), ('Gomba', 'Pest'), ('Isaszeg', 'Pest'), ('Látrány', 'Somogy'), ('Tiszatelek', 'Szabolcs-Szatmár-Bereg'), ('Nagyatád', 'Somogy'), ('Külsősárd', 'Zala'), ('Szabolcsveresmart', 'Szabolcs-Szatmár-Bereg'), ('Tornyospálca', 'Szabolcs-Szatmár-Bereg'), ('Bársonyos', 'Komárom-Esztergom'), ('Csapi', 'Zala'), ('Csönge', 'Vas'), ('Lovászhetény', 'Baranya'), ('Szurdokpüspöki', 'Nógrád'), ('Harasztifalu', 'Vas'), ('Dobri', 'Zala'), ('Iharos', 'Somogy'), ('Sárfimizdó', 'Vas'), ('Somlóvecse', 'Veszprém'), ('Tihany', 'Veszprém'), ('Hajmáskér', 'Veszprém'), ('Pázmánd', 'Fejér'), ('Csengőd', 'Bács-Kiskun'), ('Zalavég', 'Zala'), ('Sopron', 'Győr-Moson-Sopron'), ('Csákvár', 'Fejér'), ('Somogycsicsó', 'Somogy'), ('Karakószörcsök', 'Veszprém'), ('Fáj', 'Borsod-Abaúj-Zemplén'), ('Királyegyháza', 'Baranya'), ('Tiszatenyő', 'Jász-Nagykun-Szolnok'), ('Lövőpetri', 'Szabolcs-Szatmár-Bereg'), ('Markóc', 'Baranya'), ('Somogyfajsz', 'Somogy'), ('Csongrád', 'Csongrád'), ('Csányoszró', 'Baranya'), ('Szentbékkálla', 'Veszprém'), ('Hencida', 'Hajdú-Bihar'), ('Balatonhenye', 'Veszprém'), ('Törtel', 'Pest'), ('Keszü', 'Baranya'), ('Gyalóka', 'Győr-Moson-Sopron'), ('Kápolna', 'Heves'), ('Mezőfalva', 'Fejér'), ('Zengővárkony', 'Baranya'), ('Hédervár', 'Győr-Moson-Sopron'), ('Tiszabő', 'Jász-Nagykun-Szolnok'), ('Zalabér', 'Zala'), ('Remeteszőlős', 'Pest'), ('Megyehid', 'Vas'), ('Gadány', 'Somogy'), ('Szajk', 'Baranya'), ('Tengőd', 'Somogy'), ('Tokodaltáró', 'Komárom-Esztergom'), ('Sénye', 'Zala'), ('Harsány', 'Borsod-Abaúj-Zemplén'), ('Pátka', 'Fejér'), ('Tápióság', 'Pest'), ('Máriahalom', 'Komárom-Esztergom'), ('Pórszombat', 'Zala'), ('Tiszaörs', 'Jász-Nagykun-Szolnok'), ('Pálmajor', 'Somogy'), ('Vaskút', 'Bács-Kiskun'), ('Sásd', 'Baranya'), ('Kisdorog', 'Tolna'), ('Patosfa', 'Somogy'), ('Méhtelek', 'Szabolcs-Szatmár-Bereg'), ('Krasznokvajda', 'Borsod-Abaúj-Zemplén'), ('Nagyrév', 'Jász-Nagykun-Szolnok'), ('Lakhegy', 'Zala'), ('Csömödér', 'Zala'), ('Hevesvezekény', 'Heves'), ('Lábod', 'Somogy'), ('Abasár', 'Heves'), ('Szigetmonostor', 'Pest'), ('Alattyán', 'Jász-Nagykun-Szolnok'), ('Kaszaper', 'Békés'), ('Gálosfa', 'Somogy'), ('Szakcs', 'Tolna'), ('Hollókő', 'Nógrád'), ('Bajánsenye', 'Vas'), ('Kórós', 'Baranya'), ('Kisbodak', 'Győr-Moson-Sopron'), ('Bernecebaráti', 'Pest'), ('Nyárád', 'Veszprém'), ('Kiscsécs', 'Borsod-Abaúj-Zemplén'), ('Földeák', 'Csongrád'), ('Kóka', 'Pest'), ('Petőfiszállás', 'Bács-Kiskun'), ('Rakamaz', 'Szabolcs-Szatmár-Bereg'), ('Nagykarácsony', 'Fejér'), ('Csopak', 'Veszprém'), ('Adács', 'Heves'), ('Szihalom', 'Heves'), ('Mezőörs', 'Győr-Moson-Sopron'), ('Felsőnyék', 'Tolna'), ('Békésszentandrás', 'Békés'), ('Gétye', 'Zala'), ('Kétbodony', 'Nógrád'), ('Mohora', 'Nógrád'), ('Orbányosfa', 'Zala'), ('Tornaszentandrás', 'Borsod-Abaúj-Zemplén'), ('Fülpösdaróc', 'Szabolcs-Szatmár-Bereg'), ('Mátraderecske', 'Heves'), ('Kapuvár', 'Győr-Moson-Sopron'), ('Domaszék', 'Csongrád'), ('Balatonudvari', 'Veszprém'), ('Nagybarca', 'Borsod-Abaúj-Zemplén'), ('Gombosszeg', 'Zala'), ('Tab', 'Somogy'), ('Kajászó', 'Fejér'), ('Rakacaszend', 'Borsod-Abaúj-Zemplén'), ('Kesznyéten', 'Borsod-Abaúj-Zemplén'), ('Duka', 'Vas'), ('Kisköre', 'Heves'), ('Pécs', 'Baranya'), ('Ártánd', 'Hajdú-Bihar'), ('Baja', 'Bács-Kiskun'), ('Kemestaródfa', 'Vas'), ('Peresznye', 'Vas'), ('Sajómercse', 'Borsod-Abaúj-Zemplén'), ('Bácsbokod', 'Bács-Kiskun'), ('Bödeháza', 'Zala'), ('Nagylózs', 'Győr-Moson-Sopron'), ('Sáska', 'Veszprém'), ('Beled', 'Győr-Moson-Sopron'), ('Hajdúdorog', 'Hajdú-Bihar'), ('Mosonszentmiklós', 'Győr-Moson-Sopron'), ('Kisasszond', 'Somogy'), ('Túrricse', 'Szabolcs-Szatmár-Bereg'), ('Lovászi', 'Zala'), ('Kópháza', 'Győr-Moson-Sopron'), ('Borota', 'Bács-Kiskun'), ('Székesfehérvár', 'Fejér'), ('Csömör', 'Pest'), ('Herceghalom', 'Pest'), ('Szilágy', 'Baranya'), ('Bikács', 'Tolna'), ('Balatonszentgyörgy', 'Somogy'), ('Nagyhajmás', 'Baranya'), ('Cserkeszőlő', 'Jász-Nagykun-Szolnok'), ('Szirák', 'Nógrád'), ('Szinpetri', 'Borsod-Abaúj-Zemplén'), ('Csénye', 'Vas'), ('Drávapiski', 'Baranya'), ('Kengyel', 'Jász-Nagykun-Szolnok'), ('Pécel', 'Pest'), ('Dág', 'Komárom-Esztergom'), ('Tiszainoka', 'Jász-Nagykun-Szolnok'), ('Nógrád', 'Nógrád'), ('Kacorlak', 'Zala'), ('Kenyeri', 'Vas'), ('Hegyhátsál', 'Vas'), ('Kóny', 'Győr-Moson-Sopron'), ('Laskod', 'Szabolcs-Szatmár-Bereg'), ('Pély', 'Heves'), ('Hegyfalu', 'Vas'), ('Fülöp', 'Hajdú-Bihar'), ('Jászágó', 'Jász-Nagykun-Szolnok'), ('Vácrátót', 'Pest'), ('Füle', 'Fejér'), ('Csengerújfalu', 'Szabolcs-Szatmár-Bereg'), ('Verpelét', 'Heves'), ('Görgeteg', 'Somogy'), ('Abaújkér', 'Borsod-Abaúj-Zemplén'), ('Vállus', 'Zala'), ('Vöckönd', 'Zala'), ('Lápafő', 'Tolna'), ('Téseny', 'Baranya'), ('Jósvafő', 'Borsod-Abaúj-Zemplén'), ('Borsfa', 'Zala'), ('Pocsaj', 'Hajdú-Bihar'), ('Diósviszló', 'Baranya'), ('Fancsal', 'Borsod-Abaúj-Zemplén'), ('Szerecseny', 'Győr-Moson-Sopron'), ('Zalacséb', 'Zala'), ('Borsodivánka', 'Borsod-Abaúj-Zemplén'), ('Rezi', 'Zala'), ('Csákánydoroszló', 'Vas'), ('Nemesborzova', 'Szabolcs-Szatmár-Bereg'), ('Kisfalud', 'Győr-Moson-Sopron'), ('Bezi', 'Győr-Moson-Sopron'), ('Várkesző', 'Veszprém'), ('Vérteskethely', 'Komárom-Esztergom'), ('Zaláta', 'Baranya'), ('Balatonalmádi', 'Veszprém'), ('Nagypeterd', 'Baranya'), ('Farkasgyepű', 'Veszprém'), ('Szentimrefalva', 'Veszprém'), ('Ajak', 'Szabolcs-Szatmár-Bereg'), ('Pamuk', 'Somogy'), ('Nagysimonyi', 'Vas'), ('Kisapostag', 'Fejér'), ('Nyírgelse', 'Szabolcs-Szatmár-Bereg'), ('Kozármisleny', 'Baranya'), ('Sajóecseg', 'Borsod-Abaúj-Zemplén'), ('Tófű', 'Baranya'), ('Isztimér', 'Fejér'), ('Balatonmagyaród', 'Zala'), ('Agyagosszergény', 'Győr-Moson-Sopron'), ('Mosonszolnok', 'Győr-Moson-Sopron'), ('Somogyegres', 'Somogy'), ('Sajóivánka', 'Borsod-Abaúj-Zemplén'), ('Olaszliszka', 'Borsod-Abaúj-Zemplén'), ('Nemti', 'Nógrád'), ('Nyírlövő', 'Szabolcs-Szatmár-Bereg'), ('Bő', 'Vas'), ('Alsónémedi', 'Pest'), ('Onga', 'Borsod-Abaúj-Zemplén'), ('Drávatamási', 'Somogy'), ('Égerszög', 'Borsod-Abaúj-Zemplén'), ('Bugacpusztaháza', 'Bács-Kiskun'), ('Horvátzsidány', 'Vas'), ('Kékkút', 'Veszprém'), ('Baglad', 'Zala'), ('Nyíribrony', 'Szabolcs-Szatmár-Bereg'), ('Bőny', 'Győr-Moson-Sopron'), ('Vál', 'Fejér'), ('Mezőszentgyörgy', 'Fejér'), ('Csobaj', 'Borsod-Abaúj-Zemplén'), ('Boldogasszonyfa', 'Baranya'), ('Cserkút', 'Baranya'), ('Lispeszentadorján', 'Zala'), ('Zics', 'Somogy'), ('Rádóckölked', 'Vas'), ('Öttömös', 'Csongrád'), ('Keszőhidegkút', 'Tolna'), ('Püspökszilágy', 'Pest'), ('Tiszakerecseny', 'Szabolcs-Szatmár-Bereg'), ('Nagytilaj', 'Vas'), ('Nyársapát', 'Pest'), ('Gógánfa', 'Veszprém'), ('Vízvár', 'Somogy'), ('Szuha', 'Nógrád'), ('Debercsény', 'Nógrád'), ('Abaújalpár', 'Borsod-Abaúj-Zemplén'), ('Pécsbagota', 'Baranya'), ('Uraiújfalu', 'Vas'), ('Öreglak', 'Somogy'), ('Lipót', 'Győr-Moson-Sopron'), ('Gárdony', 'Fejér'), ('Szakmár', 'Bács-Kiskun'), ('Vilmány', 'Borsod-Abaúj-Zemplén'), ('Hosszúhetény', 'Baranya'), ('Mezőkovácsháza', 'Békés'), ('Acsád', 'Vas'), ('Maróc', 'Zala'), ('Tiszacsege', 'Hajdú-Bihar'), ('Radostyán', 'Borsod-Abaúj-Zemplén'), ('Vértesacsa', 'Fejér'), ('Valkonya', 'Zala'), ('Tiszavid', 'Szabolcs-Szatmár-Bereg'), ('Piliscsaba', 'Pest'), ('Serényfalva', 'Borsod-Abaúj-Zemplén'), ('Rábatamási', 'Győr-Moson-Sopron'), ('Szentkozmadombja', 'Zala'), ('Panyola', 'Szabolcs-Szatmár-Bereg'), ('Csernely', 'Borsod-Abaúj-Zemplén'), ('Vámosszabadi', 'Győr-Moson-Sopron'), ('Hottó', 'Zala'), ('Almáskamarás', 'Békés'), ('Nyírbogdány', 'Szabolcs-Szatmár-Bereg'), ('Kárász', 'Baranya'), ('Püspökladány', 'Hajdú-Bihar'), ('Kaszó', 'Somogy'), ('Tótszentmárton', 'Zala'), ('Gige', 'Somogy'), ('Lovas', 'Veszprém'), ('Velence', 'Fejér'), ('Kelebia', 'Bács-Kiskun'), ('Kerkafalva', 'Zala'), ('Mány', 'Fejér'), ('Gyepükaján', 'Veszprém'), ('Péterhida', 'Somogy'), ('Budajenő', 'Pest'), ('Komló', 'Baranya'), ('Perkáta', 'Fejér'), ('Kunfehértó', 'Bács-Kiskun'), ('Tapsony', 'Somogy'), ('Teleki', 'Somogy'), ('Tófalu', 'Heves'), ('Felpéc', 'Győr-Moson-Sopron'), ('Somogysámson', 'Somogy'), ('Szorosad', 'Somogy'), ('Pusztaradvány', 'Borsod-Abaúj-Zemplén'), ('Zalaszentlőrinc', 'Zala'), ('Sóshartyán', 'Nógrád'), ('Siklós', 'Baranya'), ('Zalavár', 'Zala'), ('Feketeerdő', 'Győr-Moson-Sopron'), ('Romhány', 'Nógrád'), ('Siójut', 'Somogy'), ('Sátorhely', 'Baranya'), ('Tápiószőlős', 'Pest'), ('Egyházasdengeleg', 'Nógrád'), ('Nagymányok', 'Tolna'), ('Újlőrincfalva', 'Heves'), ('Iklanberény', 'Vas'), ('Sokorópátka', 'Győr-Moson-Sopron'), ('Csorvás', 'Békés'), ('Dunabogdány', 'Pest'), ('Türje', 'Zala'), ('Kőtelek', 'Jász-Nagykun-Szolnok'), ('Hódmezővásárhely', 'Csongrád'), ('Somogyviszló', 'Baranya'), ('Kisvárda', 'Szabolcs-Szatmár-Bereg'), ('Visonta', 'Heves'), ('Mogyorósbánya', 'Komárom-Esztergom'), ('Nagytótfalu', 'Baranya'), ('Szente', 'Nógrád'), ('Szatymaz', 'Csongrád'), ('Magyarlukafa', 'Baranya'), ('Sárhida', 'Zala'), ('Balatonszabadi', 'Somogy'), ('Csengele', 'Csongrád'), ('Mogyoróska', 'Borsod-Abaúj-Zemplén'), ('Tardona', 'Borsod-Abaúj-Zemplén'), ('Balatonvilágos', 'Veszprém'), ('Rábagyarmat', 'Vas'), ('Csolnok', 'Komárom-Esztergom'), ('Szilvás', 'Baranya'), ('Bódvaszilas', 'Borsod-Abaúj-Zemplén'), ('Egerszólát', 'Heves'), ('Hegyeshalom', 'Győr-Moson-Sopron'), ('Röjtökmuzsaj', 'Győr-Moson-Sopron'), ('Farád', 'Győr-Moson-Sopron'), ('Rakaca', 'Borsod-Abaúj-Zemplén'), ('Apaj', 'Pest'), ('Annavölgy', 'Komárom-Esztergom'), ('Egervölgy', 'Vas'), ('Nemeshetés', 'Zala'), ('Tóalmás', 'Pest'), ('Kővágóörs', 'Veszprém'), ('Egercsehi', 'Heves'), ('Zalaújlak', 'Zala'), ('Ónod', 'Borsod-Abaúj-Zemplén'), ('Polgár', 'Hajdú-Bihar'), ('Bedő', 'Hajdú-Bihar'), ('Mersevát', 'Vas'), ('Sarród', 'Győr-Moson-Sopron'), ('Szakoly', 'Szabolcs-Szatmár-Bereg'), ('Helesfa', 'Baranya'), ('Zámoly', 'Fejér'), ('Tiszafüred', 'Jász-Nagykun-Szolnok'), ('Vaja', 'Szabolcs-Szatmár-Bereg'), ('Horvátlövő', 'Vas'), ('Telkibánya', 'Borsod-Abaúj-Zemplén'), ('Domaháza', 'Borsod-Abaúj-Zemplén'), ('Zalahaláp', 'Veszprém'), ('Dunaföldvár', 'Tolna'), ('Nagyrada', 'Zala'), ('Balatonszárszó', 'Somogy'), ('Tiszaszentimre', 'Jász-Nagykun-Szolnok'), ('Pula', 'Veszprém'), ('Zomba', 'Tolna'), ('Felsőtelekes', 'Borsod-Abaúj-Zemplén'), ('Kazár', 'Nógrád'), ('Pusztahencse', 'Tolna'), ('Kisvejke', 'Tolna'), ('Hásságy', 'Baranya'), ('Nyíregyháza', 'Szabolcs-Szatmár-Bereg'), ('Pápakovácsi', 'Veszprém'), ('Uppony', 'Borsod-Abaúj-Zemplén'), ('Szendrő', 'Borsod-Abaúj-Zemplén'), ('Ráckeresztúr', 'Fejér'), ('Táborfalva', 'Pest'), ('Béb', 'Veszprém'), ('Barcs', 'Somogy'), ('Novajidrány', 'Borsod-Abaúj-Zemplén'), ('Vokány', 'Baranya'), ('Zalaszombatfa', 'Zala'), ('Fertőrákos', 'Győr-Moson-Sopron'), ('Nemeskolta', 'Vas'), ('Szegi', 'Borsod-Abaúj-Zemplén'), ('Vindornyaszőlős', 'Zala'), ('Bakonykúti', 'Fejér'), ('Óbarok', 'Fejér'), ('Kisberzseny', 'Veszprém'), ('Bozzai', 'Vas'), ('Erdőtelek', 'Heves'), ('Pusztafalu', 'Borsod-Abaúj-Zemplén'), ('Úri', 'Pest'), ('Bakonyszücs', 'Veszprém'), ('Rábaszentmihály', 'Győr-Moson-Sopron'), ('Rinyaszentkirály', 'Somogy'), ('Nyomár', 'Borsod-Abaúj-Zemplén'), ('Monor', 'Pest'), ('Nyírjákó', 'Szabolcs-Szatmár-Bereg'), ('Etyek', 'Fejér'), ('Leányvár', 'Komárom-Esztergom'), ('Komjáti', 'Borsod-Abaúj-Zemplén'), ('Püspökhatvan', 'Pest'), ('Várong', 'Tolna'), ('Győrszemere', 'Győr-Moson-Sopron'), ('Mecsér', 'Győr-Moson-Sopron'), ('Mórágy', 'Tolna'), ('Gégény', 'Szabolcs-Szatmár-Bereg'), ('Tevel', 'Tolna'), ('Várfölde', 'Zala'), ('Zebecke', 'Zala'), ('Gadács', 'Somogy'), ('Zsennye', 'Vas'), ('Mucsi', 'Tolna'), ('Nagykamarás', 'Békés'), ('Alsórajk', 'Zala'), ('Dunaegyháza', 'Bács-Kiskun'), ('Pápa', 'Veszprém'), ('Mesztegnyő', 'Somogy'), ('Sződliget', 'Pest'), ('Szentpéterúr', 'Zala'), ('Tiszakóród', 'Szabolcs-Szatmár-Bereg'), ('Sajtoskál', 'Vas'), ('Felsőlajos', 'Bács-Kiskun'), ('Liget', 'Baranya'), ('Tarnabod', 'Heves'), ('Szatmárcseke', 'Szabolcs-Szatmár-Bereg'), ('Ceglédbercel', 'Pest'), ('Erdőkertes', 'Pest'), ('Mezőzombor', 'Borsod-Abaúj-Zemplén'), ('Szedres', 'Tolna'), ('Villány', 'Baranya'), ('Darány', 'Somogy'), ('Siófok', 'Somogy'), ('Zók', 'Baranya'), ('Úrhida', 'Fejér'), ('Vasszilvágy', 'Vas'), ('Süttő', 'Komárom-Esztergom'), ('Bököny', 'Szabolcs-Szatmár-Bereg'), ('Zajta', 'Szabolcs-Szatmár-Bereg'), ('Szemenye', 'Vas'), ('Csonkahegyhát', 'Zala'), ('Kajdacs', 'Tolna'), ('Hosszúvíz', 'Somogy'), ('Kardoskút', 'Békés'), ('Pócsmegyer', 'Pest'), ('Pusztaberki', 'Nógrád'), ('Beregsurány', 'Szabolcs-Szatmár-Bereg'), ('Vámosoroszi', 'Szabolcs-Szatmár-Bereg'), ('Zselickislak', 'Somogy'), ('Vilonya', 'Veszprém'), ('Kóspallag', 'Pest'), ('Vasszécseny', 'Vas'), ('Nagykálló', 'Szabolcs-Szatmár-Bereg'), ('Kistolmács', 'Zala'), ('Erdősmárok', 'Baranya'), ('Izsák', 'Bács-Kiskun'), ('Salföld', 'Veszprém'), ('Kisberény', 'Somogy'), ('Kerepes', 'Pest'), ('Óbudavár', 'Veszprém'), ('Balassagyarmat', 'Nógrád'), ('Vekerd', 'Hajdú-Bihar'), ('Alsóberecki', 'Borsod-Abaúj-Zemplén'), ('Alsószenterzsébet', 'Zala'), ('Nyírmártonfalva', 'Hajdú-Bihar'), ('Szilvásvárad', 'Heves'), ('Kővágótőttős', 'Baranya'), ('Mezőladány', 'Szabolcs-Szatmár-Bereg'), ('Diósd', 'Pest'), ('Babót', 'Győr-Moson-Sopron'), ('Husztót', 'Baranya'), ('Ófehértó', 'Szabolcs-Szatmár-Bereg'), ('Nógrádmarcal', 'Nógrád'), ('Szakáld', 'Borsod-Abaúj-Zemplén'), ('Zádorfalva', 'Borsod-Abaúj-Zemplén'), ('Nemesládony', 'Vas'), ('Nagykeresztúr', 'Nógrád'), ('Magyarlak', 'Vas'), ('Sukoró', 'Fejér'), ('Halásztelek', 'Pest'), ('Regenye', 'Baranya'), ('Pusztaapáti', 'Zala'), ('Galgamácsa', 'Pest'), ('Mélykút', 'Bács-Kiskun'), ('Abaújlak', 'Borsod-Abaúj-Zemplén'), ('Tiszaigar', 'Jász-Nagykun-Szolnok'), ('Balatonkeresztúr', 'Somogy'), ('Nagynyárád', 'Baranya'), ('Zsombó', 'Csongrád'), ('Mátészalka', 'Szabolcs-Szatmár-Bereg'), ('Nagygörbő', 'Zala'), ('Géberjén', 'Szabolcs-Szatmár-Bereg'), ('Nagyoroszi', 'Nógrád'), ('Igar', 'Fejér'), ('Négyes', 'Borsod-Abaúj-Zemplén'), ('Kisszőlős', 'Veszprém'), ('Bogyoszló', 'Győr-Moson-Sopron'), ('Zirc', 'Veszprém'), ('Baté', 'Somogy'), ('Görcsöny', 'Baranya'), ('Nyírparasznya', 'Szabolcs-Szatmár-Bereg'), ('Pitvaros', 'Csongrád'), ('Csanytelek', 'Csongrád'), ('Pókaszepetk', 'Zala'), ('Pusztazámor', 'Pest'), ('Kisbárapáti', 'Somogy'), ('Hernádszurdok', 'Borsod-Abaúj-Zemplén'), ('Pamlény', 'Borsod-Abaúj-Zemplén'), ('Komádi', 'Hajdú-Bihar'), ('Töltéstava', 'Győr-Moson-Sopron'), ('Abod', 'Borsod-Abaúj-Zemplén'), ('Sajókaza', 'Borsod-Abaúj-Zemplén'), ('Kék', 'Szabolcs-Szatmár-Bereg'), ('Vámospércs', 'Hajdú-Bihar'), ('Balogunyom', 'Vas'), ('Hegyhátszentjakab', 'Vas'), ('Székelyszabar', 'Baranya'), ('Szécsénke', 'Nógrád'), ('Aranyosapáti', 'Szabolcs-Szatmár-Bereg'), ('Kékesd', 'Baranya'), ('Sorokpolány', 'Vas'), ('Szécsény', 'Nógrád'), ('Szalafő', 'Vas'), ('Szendehely', 'Nógrád'), ('Dunaalmás', 'Komárom-Esztergom'), ('Csobád', 'Borsod-Abaúj-Zemplén'), ('Drávakeresztúr', 'Baranya'), ('Vasszentmihály', 'Vas'), ('Dombiratos', 'Békés'), ('Kaposfő', 'Somogy'), ('Zalkod', 'Borsod-Abaúj-Zemplén'), ('Ragály', 'Borsod-Abaúj-Zemplén'), ('Jakabszállás', 'Bács-Kiskun'), ('Vanyola', 'Veszprém'), ('Csákberény', 'Fejér'), ('Alacska', 'Borsod-Abaúj-Zemplén'), ('Eperjeske', 'Szabolcs-Szatmár-Bereg'), ('Tarhos', 'Békés'), ('Ellend', 'Baranya'), ('Monyoród', 'Baranya'), ('Lónya', 'Szabolcs-Szatmár-Bereg'), ('Jászárokszállás', 'Jász-Nagykun-Szolnok'), ('Hunyadfalva', 'Jász-Nagykun-Szolnok'), ('Váchartyán', 'Pest'), ('Hercegszántó', 'Bács-Kiskun'), ('Zalaistvánd', 'Zala'), ('Bénye', 'Pest'), ('Detk', 'Heves'), ('Adorjánháza', 'Veszprém'), ('Kemenesmihályfa', 'Vas'), ('Járdánháza', 'Borsod-Abaúj-Zemplén'), ('Szeghalom', 'Békés'), ('Hernádkak', 'Borsod-Abaúj-Zemplén'), ('Bodrogkeresztúr', 'Borsod-Abaúj-Zemplén'), ('Tura', 'Pest'), ('Zebegény', 'Pest'), ('Inke', 'Somogy'), ('Szil', 'Győr-Moson-Sopron'), ('Sárszentmihály', 'Fejér'), ('Boba', 'Vas'), ('Gyula', 'Békés'), ('Ácsteszér', 'Komárom-Esztergom'), ('Bakonyszentlászló', 'Győr-Moson-Sopron'), ('Páka', 'Zala'), ('Komárom', 'Komárom-Esztergom'), ('Sáta', 'Borsod-Abaúj-Zemplén'), ('Balatonendréd', 'Somogy'), ('Gáborjánháza', 'Zala'), ('Tiszabercel', 'Szabolcs-Szatmár-Bereg'), ('Csonkamindszent', 'Baranya'), ('Tarnaszentmária', 'Heves'), ('Váralja', 'Tolna'), ('Márokpapi', 'Szabolcs-Szatmár-Bereg'), ('Kishuta', 'Borsod-Abaúj-Zemplén'), ('Szászvár', 'Baranya'), ('Alap', 'Fejér'), ('Telekgerendás', 'Békés'), ('Muhi', 'Borsod-Abaúj-Zemplén'), ('Nyírbéltek', 'Szabolcs-Szatmár-Bereg'), ('Iváncsa', 'Fejér'), ('Vácegres', 'Pest'), ('Fürged', 'Tolna'), ('Nemeskisfalud', 'Somogy'), ('Orfalu', 'Vas'), ('Bükkszék', 'Heves'), ('Nyírlugos', 'Szabolcs-Szatmár-Bereg'), ('Páli', 'Győr-Moson-Sopron'), ('Nagyvarsány', 'Szabolcs-Szatmár-Bereg'), ('Petőfibánya', 'Heves'), ('Ludas', 'Heves'), ('Tét', 'Győr-Moson-Sopron'), ('Apc', 'Heves'), ('Tiszabábolna', 'Borsod-Abaúj-Zemplén'), ('Károlyháza', 'Győr-Moson-Sopron'), ('Tés', 'Veszprém'), ('Csókakő', 'Fejér'), ('Komlóska', 'Borsod-Abaúj-Zemplén'), ('Kisrozvágy', 'Borsod-Abaúj-Zemplén'), ('Kistamási', 'Baranya'), ('Zákány', 'Somogy'), ('Hedrehely', 'Somogy'), ('Vámosmikola', 'Pest'), ('Beszterec', 'Szabolcs-Szatmár-Bereg'), ('Derekegyház', 'Csongrád'), ('Erk', 'Heves'), ('Felsőregmec', 'Borsod-Abaúj-Zemplén'), ('Kocsér', 'Pest'), ('Pusztamérges', 'Csongrád'), ('Főnyed', 'Somogy'), ('Kátoly', 'Baranya'), ('Újireg', 'Tolna'), ('Nagyberény', 'Somogy'), ('Bag', 'Pest'), ('Győrvár', 'Vas'), ('Szajla', 'Heves'), ('Gagybátor', 'Borsod-Abaúj-Zemplén'), ('Damak', 'Borsod-Abaúj-Zemplén'), ('Vitnyéd', 'Győr-Moson-Sopron'), ('Dunaszeg', 'Győr-Moson-Sopron'), ('Drávagárdony', 'Somogy'), ('Káptalanfa', 'Veszprém'), ('Lovasberény', 'Fejér'), ('Kisherend', 'Baranya'), ('Csokonyavisonta', 'Somogy'), ('Kisgörbő', 'Zala'), ('Kémes', 'Baranya'), ('Lak', 'Borsod-Abaúj-Zemplén'), ('Somogyszentpál', 'Somogy'), ('Sály', 'Borsod-Abaúj-Zemplén'), ('Molnaszecsőd', 'Vas'), ('Nógrádkövesd', 'Nógrád'), ('Ráksi', 'Somogy'), ('Sáránd', 'Hajdú-Bihar'), ('Poroszló', 'Heves'), ('Tényő', 'Győr-Moson-Sopron'), ('Fehértó', 'Győr-Moson-Sopron'), ('Gyöngyöspata', 'Heves'), ('Szigetvár', 'Baranya'), ('Bugac', 'Bács-Kiskun'), ('Martonvásár', 'Fejér'), ('Vásárosdombó', 'Baranya'), ('Hermánszeg', 'Szabolcs-Szatmár-Bereg'), ('Gyöngyfa', 'Baranya'), ('Szegvár', 'Csongrád'), ('Szomor', 'Komárom-Esztergom'), ('Zalaköveskút', 'Zala'), ('Kapoly', 'Somogy'), ('Foktő', 'Bács-Kiskun'), ('Gölle', 'Somogy'), ('Kercaszomor', 'Vas'), ('Máza', 'Baranya'), ('Letkés', 'Pest'), ('Bősárkány', 'Győr-Moson-Sopron'), ('Dozmat', 'Vas'), ('Erdőkürt', 'Nógrád'), ('Halastó', 'Vas'), ('Homorúd', 'Baranya'), ('Kisvarsány', 'Szabolcs-Szatmár-Bereg'), ('Cegléd', 'Pest'), ('Kiskunhalas', 'Bács-Kiskun'), ('Alsótold', 'Nógrád'), ('Csór', 'Fejér'), ('Bezeréd', 'Zala'), ('Nagyhódos', 'Szabolcs-Szatmár-Bereg'), ('Csákány', 'Somogy'), ('Novaj', 'Heves'), ('Tiszaeszlár', 'Szabolcs-Szatmár-Bereg'), ('Hőgyész', 'Tolna'), ('Ágfalva', 'Győr-Moson-Sopron'), ('Mikófalva', 'Heves'), ('Olaszfa', 'Vas'), ('Alsószuha', 'Borsod-Abaúj-Zemplén'), ('Nagykáta', 'Pest'), ('Ököritófülpös', 'Szabolcs-Szatmár-Bereg'), ('Acsa', 'Pest'), ('Regéc', 'Borsod-Abaúj-Zemplén'), ('Girincs', 'Borsod-Abaúj-Zemplén'), ('Lácacséke', 'Borsod-Abaúj-Zemplén'), ('Pápadereske', 'Veszprém'), ('Ipolyvece', 'Nógrád'), ('Hernádszentandrás', 'Borsod-Abaúj-Zemplén'), ('Bókaháza', 'Zala'), ('Tiborszállás', 'Szabolcs-Szatmár-Bereg'), ('Vaskeresztes', 'Vas'), ('Perőcsény', 'Pest'), ('Kerecseny', 'Zala'), ('Olaszfalu', 'Veszprém'), ('Ortaháza', 'Zala'), ('Bakonykoppány', 'Veszprém'), ('Dabas', 'Pest'), ('Atkár', 'Heves'), ('Pécsudvard', 'Baranya'), ('Tiszaszalka', 'Szabolcs-Szatmár-Bereg'), ('Kunmadaras', 'Jász-Nagykun-Szolnok'), ('Medgyesegyháza', 'Békés'), ('Derecske', 'Hajdú-Bihar'), ('Győrság', 'Győr-Moson-Sopron'), ('Bodolyabér', 'Baranya'), ('Újlengyel', 'Pest'), ('Hencse', 'Somogy'), ('Dencsháza', 'Baranya'), ('Tiszatarján', 'Borsod-Abaúj-Zemplén'), ('Kaba', 'Hajdú-Bihar'), ('Újszilvás', 'Pest'), ('Pácin', 'Borsod-Abaúj-Zemplén'), ('Fehérgyarmat', 'Szabolcs-Szatmár-Bereg'), ('Vékény', 'Baranya'), ('Oszkó', 'Vas'), ('Érpatak', 'Szabolcs-Szatmár-Bereg'), ('Boldva', 'Borsod-Abaúj-Zemplén'), ('Ócsa', 'Pest'), ('Magyarszerdahely', 'Zala'), ('Kisbér', 'Komárom-Esztergom'), ('Hantos', 'Fejér'), ('Mosdós', 'Somogy'), ('Medgyesbodzás', 'Békés'), ('Nyésta', 'Borsod-Abaúj-Zemplén'), ('Rózsaszentmárton', 'Heves'), ('Pétervására', 'Heves'), ('Gyönk', 'Tolna'), ('Szentpéterszeg', 'Hajdú-Bihar'), ('Uszód', 'Bács-Kiskun'), ('Hobol', 'Baranya'), ('Bodrog', 'Somogy'), ('Kunhegyes', 'Jász-Nagykun-Szolnok'), ('Nagykozár', 'Baranya'), ('Óföldeák', 'Csongrád'), ('Vásárosbéc', 'Baranya'), ('Tárnokréti', 'Győr-Moson-Sopron'), ('Tiszapalkonya', 'Borsod-Abaúj-Zemplén'), ('Nagybánhegyes', 'Békés'), ('Sárkeresztes', 'Fejér'), ('Csengersima', 'Szabolcs-Szatmár-Bereg'), ('Bana', 'Komárom-Esztergom'), ('Kacsóta', 'Baranya'), ('Ecséd', 'Heves'), ('Felsőmarác', 'Vas'), ('Neszmély', 'Komárom-Esztergom'), ('Nick', 'Vas'), ('Csánig', 'Vas'), ('Sülysáp', 'Pest'), ('Fiad', 'Somogy'), ('Lőkösháza', 'Békés'), ('Iliny', 'Nógrád'), ('Gara', 'Bács-Kiskun'), ('Délegyháza', 'Pest'), ('Bódvarákó', 'Borsod-Abaúj-Zemplén'), ('Szentpéterfa', 'Vas'), ('Tiszabecs', 'Szabolcs-Szatmár-Bereg'), ('Bánk', 'Nógrád'), ('Belezna', 'Zala'), ('Csarnóta', 'Baranya'), ('Fülöpszállás', 'Bács-Kiskun'), ('Markaz', 'Heves'), ('Somogysimonyi', 'Somogy'), ('Őrbottyán', 'Pest'), ('Drávaszerdahely', 'Baranya'), ('Szágy', 'Baranya'), ('Sárosd', 'Fejér'), ('Mátyus', 'Szabolcs-Szatmár-Bereg'), ('Ramocsaháza', 'Szabolcs-Szatmár-Bereg'), ('Szabadkígyós', 'Békés'), ('Mezőcsokonya', 'Somogy'), ('Drávafok', 'Baranya'), ('Zselickisfalud', 'Somogy'), ('Ostoros', 'Heves'), ('Vecsés', 'Pest'), ('Kemenesmagasi', 'Vas'), ('Nagycsány', 'Baranya'), ('Pusztaszentlászló', 'Zala'), ('Takácsi', 'Veszprém'), ('Pogányszentpéter', 'Somogy'), ('Kölked', 'Baranya'), ('Soltszentimre', 'Bács-Kiskun'), ('Szentmártonkáta', 'Pest'), ('Devecser', 'Veszprém'), ('Börzönce', 'Zala'), ('Szárföld', 'Győr-Moson-Sopron'), ('Fábiánháza', 'Szabolcs-Szatmár-Bereg'), ('Trizs', 'Borsod-Abaúj-Zemplén'), ('Ilk', 'Szabolcs-Szatmár-Bereg'), ('Kaposgyarmat', 'Somogy'), ('Nagydorog', 'Tolna'), ('Kerekegyháza', 'Bács-Kiskun'), ('Kőszárhegy', 'Fejér'), ('Keresztéte', 'Borsod-Abaúj-Zemplén'), ('Békás', 'Veszprém'), ('Horváthertelend', 'Baranya'), ('Zalamerenye', 'Zala'), ('Tardos', 'Komárom-Esztergom'), ('Hetvehely', 'Baranya'), ('Egerlövő', 'Borsod-Abaúj-Zemplén'), ('Bagod', 'Zala'), ('Martfű', 'Jász-Nagykun-Szolnok'), ('Bercel', 'Nógrád'), ('Hajós', 'Bács-Kiskun'), ('Dunaszentbenedek', 'Bács-Kiskun'), ('Egyházaskesző', 'Veszprém'), ('Gyöngyösoroszi', 'Heves'), ('Kunbaracs', 'Bács-Kiskun'), ('Oroszi', 'Veszprém'), ('Halogy', 'Vas'), ('Palkonya', 'Baranya'), ('Csertalakos', 'Zala'), ('Gyomaendrőd', 'Békés'), ('Velény', 'Baranya'), ('Csikéria', 'Bács-Kiskun'), ('Arnót', 'Borsod-Abaúj-Zemplén'), ('Nagybakónak', 'Zala'), ('Oszlár', 'Borsod-Abaúj-Zemplén'), ('Klárafalva', 'Csongrád'), ('Tárkány', 'Komárom-Esztergom'), ('Sóskút', 'Pest'), ('Kerkáskápolna', 'Vas'), ('Regöly', 'Tolna'), ('Mesterszállás', 'Jász-Nagykun-Szolnok'), ('Bátaszék', 'Tolna'), ('Mór', 'Fejér'), ('Szeleste', 'Vas'), ('Fácánkert', 'Tolna'), ('Apátfalva', 'Csongrád'), ('Almásfüzitő', 'Komárom-Esztergom'), ('Balsa', 'Szabolcs-Szatmár-Bereg'), ('Kisléta', 'Szabolcs-Szatmár-Bereg'), ('Old', 'Baranya'), ('Szarvaskend', 'Vas'), ('Máriakéménd', 'Baranya'), ('Mezőtárkány', 'Heves'), ('Papkeszi', 'Veszprém'), ('Zsurk', 'Szabolcs-Szatmár-Bereg'), ('Bakonyszombathely', 'Komárom-Esztergom'), ('Kosd', 'Pest'), ('Lórév', 'Pest'), ('Pálfiszeg', 'Zala'), ('Magosliget', 'Szabolcs-Szatmár-Bereg'), ('Vörs', 'Somogy'), ('Rédics', 'Zala'), ('Csehi', 'Vas'), ('Baktakék', 'Borsod-Abaúj-Zemplén'), ('Homrogd', 'Borsod-Abaúj-Zemplén'), ('Zalaszabar', 'Zala'), ('Gyöngyössolymos', 'Heves'), ('Tiszalök', 'Szabolcs-Szatmár-Bereg'), ('Bakháza', 'Somogy'), ('Csombárd', 'Somogy'), ('Bánd', 'Veszprém'), ('Szentendre', 'Pest'), ('Alsózsolca', 'Borsod-Abaúj-Zemplén'), ('Zalakaros', 'Zala'), ('Szalánta', 'Baranya'), ('Zalabaksa', 'Zala'), ('Tatárszentgyörgy', 'Pest'), ('Budaörs', 'Pest'), ('Nagysáp', 'Komárom-Esztergom'), ('Nagyesztergár', 'Veszprém'), ('Szárliget', 'Komárom-Esztergom'), ('Magyarhomorog', 'Hajdú-Bihar'), ('Zsujta', 'Borsod-Abaúj-Zemplén'), ('Nagymágocs', 'Csongrád'), ('Tolmács', 'Nógrád'), ('Mike', 'Somogy'), ('Nagypáli', 'Zala'), ('Sajószentpéter', 'Borsod-Abaúj-Zemplén'), ('Értény', 'Tolna'), ('Pénzesgyőr', 'Veszprém'), ('Kiszombor', 'Csongrád'), ('Kölcse', 'Szabolcs-Szatmár-Bereg'), ('Tisztaberek', 'Szabolcs-Szatmár-Bereg'), ('Sand', 'Zala'), ('Gutorfölde', 'Zala'), ('Gic', 'Veszprém'), ('Hegyhátmaróc', 'Baranya'), ('Ercsi', 'Fejér'), ('Und', 'Győr-Moson-Sopron'), ('Csitár', 'Nógrád'), ('Bak', 'Zala'), ('Egeralja', 'Veszprém'), ('Böde', 'Zala'), ('Káloz', 'Fejér'), ('Felsőjánosfa', 'Vas'), ('Karancslapujtő', 'Nógrád'), ('Piliscsév', 'Komárom-Esztergom'), ('Celldömölk', 'Vas'), ('Rém', 'Bács-Kiskun'), ('Sarkadkeresztúr', 'Békés'), ('Olcsvaapáti', 'Szabolcs-Szatmár-Bereg'), ('Csertő', 'Baranya'), ('Nágocs', 'Somogy'), ('Tahitótfalu', 'Pest'), ('Katafa', 'Vas'), ('Mándok', 'Szabolcs-Szatmár-Bereg'), ('Lad', 'Somogy'), ('Csősz', 'Fejér'), ('Uszka', 'Szabolcs-Szatmár-Bereg'), ('Zselicszentpál', 'Somogy'), ('Szegerdő', 'Somogy'), ('Mosonmagyaróvár', 'Győr-Moson-Sopron'), ('Bucsa', 'Békés'), ('Hollád', 'Somogy'), ('Kemenespálfa', 'Vas'), ('Kiskunlacháza', 'Pest'), ('Dör', 'Győr-Moson-Sopron'), ('Tiszagyulaháza', 'Hajdú-Bihar'), ('Kutasó', 'Nógrád'), ('Gosztola', 'Zala'), ('Kötcse', 'Somogy'), ('Szigetszentmárton', 'Pest'), ('Fülöpháza', 'Bács-Kiskun'), ('Gyügye', 'Szabolcs-Szatmár-Bereg'), ('Dunatetétlen', 'Bács-Kiskun'), ('Ibafa', 'Baranya'), ('Anarcs', 'Szabolcs-Szatmár-Bereg'), ('Tiszaug', 'Bács-Kiskun'), ('Bicske', 'Fejér'), ('Kerkaszentkirály', 'Zala'), ('Makó', 'Csongrád'), ('Zimány', 'Somogy'), ('Borsodnádasd', 'Borsod-Abaúj-Zemplén'), ('Nagyvisnyó', 'Heves'), ('Porva', 'Veszprém'), ('Garabonc', 'Zala'), ('Ormándlak', 'Zala'), ('Kaposújlak', 'Somogy'), ('Kajárpéc', 'Győr-Moson-Sopron'), ('Nyírkércs', 'Szabolcs-Szatmár-Bereg'), ('Zichyújfalu', 'Fejér'), ('Bágyogszovát', 'Győr-Moson-Sopron'), ('Kisgyalán', 'Somogy'), ('Döröske', 'Vas'), ('Szentes', 'Csongrád'), ('Heréd', 'Heves'), ('Miszla', 'Tolna'), ('Jászladány', 'Jász-Nagykun-Szolnok'), ('Majs', 'Baranya'), ('Zaránk', 'Heves'), ('Nemesdéd', 'Somogy'), ('Darvas', 'Hajdú-Bihar'), ('Pécsvárad', 'Baranya'), ('Sámod', 'Baranya'), ('Milota', 'Szabolcs-Szatmár-Bereg'), ('Felsőnána', 'Tolna'), ('Kács', 'Borsod-Abaúj-Zemplén'), ('Zsédeny', 'Vas'), ('Becskeháza', 'Borsod-Abaúj-Zemplén'), ('Tokorcs', 'Vas'), ('Komlódtótfalu', 'Szabolcs-Szatmár-Bereg'), ('Pellérd', 'Baranya'), ('Potony', 'Somogy'), ('Bélavár', 'Somogy'), ('Nagykanizsa', 'Zala'), ('Seregélyes', 'Fejér'), ('Görbeháza', 'Hajdú-Bihar'), ('Rudolftelep', 'Borsod-Abaúj-Zemplén'), ('Szakácsi', 'Borsod-Abaúj-Zemplén'), ('Komoró', 'Szabolcs-Szatmár-Bereg'), ('Mozsgó', 'Baranya'), ('Deszk', 'Csongrád'), ('Füzérkomlós', 'Borsod-Abaúj-Zemplén'), ('Rábahidvég', 'Vas'), ('Györgytarló', 'Borsod-Abaúj-Zemplén'), ('Kerta', 'Veszprém'), ('Baktüttös', 'Zala'), ('Kemence', 'Pest'), ('Lulla', 'Somogy'), ('Sándorfalva', 'Csongrád'), ('Gór', 'Vas'), ('Hajdúsámson', 'Hajdú-Bihar'), ('Tiszasziget', 'Csongrád'), ('Belecska', 'Tolna'), ('Kartal', 'Pest'), ('Vigántpetend', 'Veszprém'), ('Fityeház', 'Zala'), ('Szomód', 'Komárom-Esztergom'), ('Sármellék', 'Zala'), ('Piskó', 'Baranya'), ('Zalaigrice', 'Zala')]


megye = ['Bács-Kiskun', 'Baranya', 'Békés', 'Borsod-Abaúj-Zemplén', 'Csongrád-Csanád', 'Fejér',
         'Győr-Moson-Sopron', 'Hajdú-Bihar', 'Heves', 'Jász-Nagykun-Szolnok', 'Komárom-Esztergom',
         'Nógrád', 'Pest', 'Somogy', 'Szabolcs-Szatmár-Bereg', 'Tolna', 'Vas', 'Veszprém', 'Zala']

folyo = ['Duna', 'Tisza', 'Dráva', 'Rába', 'Marcal', 'Szamos', 'Körös', 'Zagyva', 'Sajó', 'Ipoly',
         'Driszavica', 'Bodrog', 'Latorica', 'Zala', 'Hernád', 'Rábca', 'Lajta',
         'Kis-Duna', 'Fekete-Körös', 'Kis-Sajó', 'Torna', 'Kraszna', 'Mura', 'Séd', 'Kapos', 'Galga',
         'Cserna', 'Ivacs-patak', 'Bükkös-patak', 'Pilinka', 'Bodva', 'Hármas-Körös', 'Sajgó']

nap = ['hétfő', 'kedd', 'szerda', 'csütörtök', 'péntek', 'szombat', 'vasárnap']

honap = ['január', 'február', 'március', 'április', 'május', 'június', 'július',
         'augusztus', 'szeptember', 'október', 'november', 'december']

gyumolcs= ['alma', 'ananász',  'banán', 'barack', 'birs', 'cseresznye', 'datolya', 'dinnye', 'eper', 'füge',
            'gránátalma', 'kajszibarack', 'kivi', 'málna', 'meggy', 'narancs', 'őszibarack', 'ribizli',
            'sárgabarack', 'szeder', 'szilva', 'egres', 'vörösszőlő', 'szeder', 'körte', 'meggy', 'áfonya',
           'sárgadinnye', 'erdei szamóca', 'mangó']

zoldseg = ['articsóka', 'bab', 'borsó', 'brokkoli', 'burgonya', 'cékla', 'csicsóka', 'csiperkegomba', 'fokhagyma',
           'hagyma', 'karalábé', 'karfiol', 'káposzta', 'kelbimbó', 'kukorica', 'fejes sajáta', 'lilahagyma',
           'lilakáposzta', 'padlizsán', 'paprika', 'paszternák', 'retek', 'sárgarépa', 'spárga', 'spenót',
           'sütőtök', 'tök', 'uborka', 'zeller', 'sárgarépa', 'feketeretek','zeller', 'kínai kel', 'retek',
           'jégcsapretek', 'fokhagyma', 'újhagyma', 'szárzeller']

haszonallat = [ 'tehén', 'juh', 'kecske', 'disznó', 'tyúk', 'kacsa', 'liba', 'pulyka', 'strucc', 'ló', 'szamár', 'bivaly',
                 'jak', 'csirke', 'nyúl', 'szarvasmarha', 'szürkemarha', 'sertés', 'malac', 'gyöngytyúk', 'birka']

vad = ['medve', 'farkas', 'róka', 'borz', 'őz', 'szarvas','nyest', 'vaddisznó','muflon','vidra',
            'gímszarvas', 'molnárgörény','vadmacska']

hal = ['keszeg', 'ponty', 'csuka', 'harcsa', 'süllő', 'kárász', 'angolna', 'márna', 'fogasponty', 'sügér', 'amur',
         'menyhal', 'domolykó', 'keszeg', 'garda', 'paduc', 'compó', 'bodorka', 'nyúldomolykó']

madar = ['feketerigó', 'fülemüle', 'csalogány', 'kékvércse', 'széncinege', 'szajkó', 'szürkebegy', 'búbosbanka',
         'zöldike', 'sármány', 'fácán', 'kakukk', 'bölömbika', 'örvényi sas', 'szirti sas', 'parlagi sas',
         'réti keselyű', 'héja', 'pávaszemes fecske', 'gyurgyalag', 'gólya', 'kócsag', 'hattyú', 'vadkacsa', 'vadlúd',
         'szárcsa', 'rigó', 'szajkó']

bolygo =['Merkúr', 'Vénusz', 'Föld', 'Mars', 'Jupiter','Szaturnusz', 'Uránusz', 'Neptunusz']


leves = ["Gulyásleves", "Halászlé", "Hideg meggyleves", "Zöldborsóleves", "Jókai bableves", "Csontleves",
           "Marhahúsleves", "Zellerkrémleves", "Sárgaborsóleves", "Babgulyásleves", "Karalábéleves", "Zöldségleves",
           "Kukoricaleves", "Karfiolleves", "Hideg gyümölcsleves", "Korhelyleves", "Tyúkhúsleves",
           "Pirított tarhonyaleves", "Gombaleves", "Lencseleves", "Gulyáskrémleves", "Csülökleves", "Paradicsomleves",
           "Borleves", "Tárkonyos raguleves", "Zöldbableves", "Kapros-joghurtos leves", "Paradicsomleves betűtésztával",
           "Sajtos-tejfölös leves", "Burgonyaleves", "Csirkeleves", "Krumplileves",  "Tavaszi zöldségleves",
           "Karfiol krémleves", "Tojásleves", "Tárkonyos csirkeraguleves", "Káposztaleves", "Húsos zöldborsóleves",
           "Sárgadinnyeleves", "Tavaszi zöldségleves tarhonyával", "Hagymaleves",  "Húsleves gazdagon",
           "Gesztenyekrémleves", "Jérceleves", "Kolbászos bableves", "Uborkaleves", "Tejszínes karfiolleves",
           "Tarkabableves", "Hideg szilvaleves", "Fokhagymaleves", "Májgombócleves", "Brokkolileves",
           "Savanyú káposztaleves", "Erőleves", "Tejfölös gombaleves",  "Húsos káposztaleves", "Zöldspárga krémleves",
           "Sóska krémleves", "Burgonyapüréleves", "Laskaleves",  "Paradicsomleves húsgombóccal", "Csirkemájleves",
           "Ribizlileves", "Cukkinikrémleves", "Fokhagymás zöldbableves", "Zöldségleves tojással"]

foetel= ['Vadörkölt', 'Sült csirke',
         'Sertésszelet', 'Rántott hús', 'Paprikás csirke', 'Sült kolbász', 'Rántott sajt', 'Rántott karfiol',
         'Kacsacomb rántva', 'Kakaspörkölt',  'Sült hal',  'Gombapaprikás',
         'Marhapörkölt', 'Pacalpörkölt', 'Roston sült csirke',
         'Rántott gomba', 'Rántott karaj', 'Rántott csirkemell', 'Halpaprikás', 'Libamáj',
         'Sült sertés', 'Halpaprikás', 'Csülök Pékné módra', 'Borjúpörkölt ',
         'Párizsi csirkemell', 'Rántott karaj', 'Kacsapörkölt', 'Csirkepaprikás',  'Rántott csirkeszárny', 'Pacalpörkölt',
         'Rántott jércemell', 'Sertéspörkölt','Mátrai borzaska',
         'Grillezett csirkecomb', 'Lecsós csirke', 'Rántott gomba ', 'Rántott ponty', 'Lazacsteak', 'Roston sült hal',
         'Rántott camembert', 'Sült kacsacomb', 'Sült libacomb', 'Sült pulykamell', 'Sült tarja', 'Báránytokány',
         'Szűzérmék',  'Cordon bleu', 'Sült Kacsamáj',
         'Lecsós tarja', 'Stefánia vagdalt']

koret = ['Párolt rizs', 'Hagymás tört burgonya', 'Burgonyapüré', 'Párolt zöldségek', 'Hasábburgonya',
           'Grillezett zöldségek', 'Köleskása', 'Galuska', 'Zöldségköret', 'Kukoricás rizs', 'Sárgarépa püré',
            'Tarhonya',  'Burgonyakrokett', 'Kuszkusz', 'Brokkolipüré', 'Párolt sárgarépa',
           'Tarhonya',  'Zöldborsós rizs', 'Gombás rizs', 'Gersli',  'Sült édesburgonya hasáb',
           'Édesburgonya püré',  'Hercegnő burgonya', 'Csónak burgonya', 'Tepsis sült burgonya']

egytal = ['Rakott krumpli', 'Töltött káposzta', 'Lecsó','Töltött paprika','Lencsefőzelék sültkolbásszal','Hortobágyi húsos palacsinta',
          'Sztrapacska szalonna pörccel','Burgonyás tészta','Csirkés rizottó','Rakott kelkáposzta csőben sütve',
           'Rakott zöldbab', 'Disznótoros káposzta friss kenyérrel', 'Bácskai rizseshús', 'Brassói aprópecsenye','Tarhonyás hús',
          'Székelykáposzta kenyérrel','Paradicsomos töltött káposzta','Rakott cukkini', 'Pásztortarhonya','Húsos-szaftos tészta',
          'Lecsó Mezőcsáti módra', 'Sonkás-paradicsomos tészta', 'Sajtos-sonkás rakott tészta', 'Kolozsvári rakott káposzta',
          'Sonkás tészta csőben sütve','Túrós csusza','Kapros-túrós csusza', 'Székelykáposzta','Paprikás krumpli', 'Rakott padlizsán' ]

desszert = [
    'Almás pite', 'Aranygaluska','Bejgli','Bodri torta','Boszorkányszigeti torta','Budapest roló', 'Császármorzsa',
    'Csokoládé torta','Dobostorta','Diótorta', 'Esterházy torta','Fekete-erdő torta','Flódni','Gesztenyepüré torta',
    'János vitéz tortája', 'Joghurt torta', 'Kakaós-meggyes pite', 'Képviselőfánk', 'Két színű torta',
    'Kókuszos szelet', 'Krémes', 'Linzer', 'Mákos guba', 'Mákos kalács', 'Napóleon torta', 'Orosz krémtorta',
    'Francia krémes', 'Puncsgolyó','Rakott palacsinta','Rákóczi túrós','Rigó Jancsi', 'Somlói galuska',
    'Tiramisu','Répatorta']

bor = ['Tokaji Furmint', 'Villányi Franc', 'Eger Bikavér', 'Szekszárdi Bikavér', 'Balatonboglári Kékfrankos',
       'Badacsonyi Olaszrizling', 'Villányi Portugieser', 'Villányi Cabernet Franc', 'Egri Kékfrankos',
       'Villányi Merlot', 'Etyeki Chardonnay', 'Somlói Juhfark', 'Tokaji Aszú', 'Mátrai Irsai Olivér',
       'Villányi Cabernet Sauvignon', 'Balatonfüredi Szürkebarát', 'Soproni Kékfrankos', 'Szekszárdi Kadarka',
       'Szekszárdi Merlot', 'Balatonlellei Olaszrizling', 'Badacsonyi Kéknyelű', 'Villányi Syrah',
       'Somlói Furmint', 'Tokaji Szamorodni', 'Villányi Cuvée', 'Villányi Pinot Noir', 'Badacsonyi Kékfrankos',
       'Mátrai Pinot Noir', 'Tokaji Hárslevelű', 'Villányi Kékfrankos', 'Somlói Traminer',
       'Badacsonyi Muscat Ottonel', 'Villányi Kadarka', 'Mátrai Cabernet Sauvignon', 'Soproni Pinot Noir',
       'Balatonfüredi Olaszrizling', 'Badacsonyi Szürkebarát', 'Tokaji Szamorodni Édes', 'Egri Leányka',
       'Szekszárdi Cuvée', 'Villányi Kéknyelű', 'Egri Merlot', 'Somlói Olaszrizling',
       'Badacsonyi Rizlingszilváni', 'Villányi Portugieser Rosé', 'Balatonboglári Zenit',
       'Balatonlellei Riesling', 'Tokaji Szamorodni Száraz', 'Soproni Rosé']

udito = ['Narancslé', 'Almalé', 'Tonik', 'Ásványvíz', 'Gyümölcslé', 'Szőlőlé',
        'Bodza szörp', 'Cseresznyeszörp', 'Málnaszörp', 'Eper szörp',  'Zöld teás üdítő',
        'Narancs ízű ásványvíz','Coca Cola', 'Fanta', 'Sprite', 'Jeges tea', 'Gyömbér',
        'Bambi', 'Róna', 'Márka','Traubisoda','Olympos','Málna-gyöngye','Meggy-gyöngye',
        'Sió gyümölcs nektár','Limonádé']



kiraly = {'Árpád': (895, 907), 'Zoltán': (907, 947), 'Fajsz': (947, 955), 'Taksony': (955, 972), 'Géza': (972, 997),
    'I.István': (997, 1038),'I. Péter': (1038, 1041), 'Sámuel': (1041, 1044), 'Péter-2': (1044, 1045), 'I.András': (1041, 1060),
    'I. Béla': (1060, 1063), 'Salamon': (1063, 1074), 'I. Géza': (1074, 1077), 'I. László': (1077, 1095),
    'Kálmán': (1095, 1116),'II. István': (1116, 1131), 'II. Béla': (1131, 1141), 'II. Géza': (1141,1162),
    'III. István': (1162, 1172), 'III. Béla': (1172, 1196), 'Imre':(1196, 1204), 'III. László': (1204, 1205),
    'II. András': (1205, 1235),'IV. Béla': (1235, 1270), 'V. István': (1270, 1272), 'IV. László': (1272, 1290),
    'III. András': (1290, 1301), 'Vencel': (1301, 1305), 'Ottó': (1305, 1307), 'I. Károly': (1308, 1342),
    'I.Lajos': (1342, 1382), 'Mária': (1382, 1385), 'II. Károly': (1385, 1386), 'Mária-2':(1386, 1395),
    'Zsigmond' : (1387, 1437), 'Albert': (1437, 1439), 'V. László': (1440, 1457), 'I. Ulászló': (1440, 1444),
    'I. Mátyás': (1458, 1490), 'II. Ulászló': (1490, 1516), 'II. Lajos': (1516, 1526), 'I.János': (1526, 1540),
    'II. János' : (1540, 1571), 'I. Ferdinánd': (1526, 1564), 'Miksa': (1564, 1576), 'Rudolf': (1576, 1608),
    'II. Mátyás': (1608, 1619), 'II. Ferdinánd': (1618, 1637), 'III. Ferdinánd': (1637,1657), 'IV. Ferdinánd': (1647,1654),
    'I. Lipót' : (1657, 1705),  'I. József': (1705,1711), 'III. Károly': (1711,1740), 'Mária Terézia': (1740, 1780),
    'II. József':(1780, 1790), 'II. Lipót': (1790, 1792), 'I. Ferenc': (1790, 1835), 'V. Ferdinánd' : (1835,1848),
    'I. Ferenc József' : (1848,1916), 'IV. Károly':(1916,1918) }

megye_szekhely= {'Bács-Kiskun': 'Kecskemét','Baranya': 'Pécs', 'Békés': 'Békéscsaba','Borsod-Abaúj-Zemplén': 'Miskolc',
    'Csongrád-Csanád': 'Szeged','Fejér': 'Székesfehérvár', 'Győr-Moson-Sopron': 'Győr','Hajdú-Bihar': 'Debrecen',
    'Heves': 'Eger','Jász-Nagykun-Szolnok': 'Szolnok', 'Komárom-Esztergom': 'Tatabánya', 'Nógrád': 'Salgótarján',
    'Pest': 'Budapest', 'Somogy': 'Kaposvár', 'Szabolcs-Szatmár-Bereg': 'Nyíregyháza', 'Tolna': 'Szekszárd',
    'Vas': 'Szombathely', 'Veszprém': 'Veszprém', 'Zala': 'Zalaegerszeg' }

jaras= {
    'Bácsalmási járás': ['Bácsalmás', 'Bács-Kiskun'],'Bajai járás': ['Baja', 'Bács-Kiskun'],
    'Jánoshalmi járás': ['Jánoshalma', 'Bács-Kiskun'],'Kalocsai járás': ['Kalocsa', 'Bács -Kiskun'],
    'Kecskeméti járás': ['Kecskemét', 'Bács-Kiskun'], 'Kiskőrösi járás': ['Kiskőrös', 'Bács-Kiskun'],
    'Kiskunfélegyházi járás': ['Kiskunfélegyháza', 'Bács-Kiskun'], 'Kiskunhalasi járás': ['Kiskunhalas', 'Bács-Kiskun'],
    'Kunszentmiklósi járás': ['Kunszentmiklós', 'Bács-Kiskun'], 'Tiszakécskei járás': ['Tiszakécske', 'Bács-Kiskun'],
    'Kiskunmajsai járás' :['Kiskunmajsa', 'Bács-Kiskun'],
    'Bólyi járás': ['Bóly', 'Baranya'], 'Hegyháti járás': ['Sásd', 'Baranya'],
    'Komlói járás': ['Komló', 'Baranya'],'Mohácsi járás': ['Mohács', 'Baranya'],
    'Pécsi járás': ['Pécs', 'Baranya'], 'Pécsváradi járás': ['Pécsvárad', 'Baranya'],
    'Sellyei járás': ['Sellye', 'Baranya'], 'Szentlőrinci járás': ['Szentlőrinc', 'Baranya'],
    'Siklósi járás': ['Siklós', 'Baranya'], 'Szigetvári járás': ['Szigetvár', 'Baranya'],
    'Békési járás':['Békés', 'Békés'],'Gyulai járás': ['Gyula', 'Békés'],
    'Mezőkovácsházi járás': ['Mezőkovácsháza', 'Békés'],'Orosházi járás': ['Orosháza', 'Békés'],
    'Sarkadi járás': ['Sarkad', 'Békés'], 'Szeghalmi járás': ['Szeghalom', 'Békés'],
    'Békéscsabai járás':['Békéscsaba', 'Békés'], 'Gyomaendrődi járás':['Gyomaendrőd', 'Békés'],
    'Szarvasi járás':['Szarvas', 'Békés'],
    'Cigándi járás': ['Cigánd', 'Borsod-Abaúj-Zemplén'], 'Edelényi járás': ['Edelény', 'Borsod-Abaúj-Zemplén'],
    'Encsi járás': ['Encs', 'Borsod-Abaúj-Zemplén'], 'Gönci járás': ['Gönc', 'Borsod-Abaúj-Zemplén'],
    'Kazincbarcikai járás': ['Kazincbarcika', 'Borsod-Abaúj-Zemplén'], 'Mezőcsáti járás': ['Mezőcsát', 'Borsod-Abaúj-Zemplén'],
    'Mezőkövesdi járás': ['Mezőkövesd', 'Borsod-Abaúj-Zemplén'],  'Miskolci járás': ['Miskolc', 'Borsod-Abaúj-Zemplén'],
    'Ózdi járás': ['Ózd', 'Borsod-Abaúj-Zemplén'],  'Putnoki járás': ['Putnok', 'Borsod-Abaúj-Zemplén'],
    'Sárospataki járás': ['Sárospatak', 'Borsod-Abaúj-Zemplén'], 'Sátoraljaújhelyi járás': ['Sátoraljaújhely', 'Borsod-Abaúj-Zemplén'],
    'Szerencsi járás': ['Szerencs', 'Borsod-Abaúj-Zemplén'],  'Szikszói járás': ['Szikszó', 'Borsod-Abaúj-Zemplén'],
    'Tiszaújvárosi járás': ['Tiszaújváros', 'Borsod-Abaúj-Zemplén'],  'Tokaji járás': ['Tokaj', 'Borsod-Abaúj-Zemplén'],
    'Csongrádi járás': ['Csongrád', 'Csongrád-Csanád'],'Hódmezővásárhelyi járás': ['Hódmezővásárhely', 'Csongrád-Csanád'],
    'Kisteleki járás': ['Kistelek', 'Csongrád-Csanád'], 'Makói járás': ['Makó', 'Csongrád-Csanád'],
    'Mórahalmi járás': ['Mórahalom', 'Csongrád-Csanád'],'Szegedi járás': ['Szeged', 'Csongrád-Csanád'],
    'Szentesi járás': ['Szentes', 'Csongrád-Csanád'],
    'Bicskei járás': ['Bicske', 'Fejér'], 'Dunaújvárosi járás': ['Dunaújváros', 'Fejér'],
    'Enyingi járás': ['Enying', 'Fejér'],'Gárdonyi járás': ['Gárdony', 'Fejér'],
    'Martonvásári járás': ['Martonvásár', 'Fejér'],'Móri járás': ['Mór', 'Fejér'],
    'Sárbogárdi járás': ['Sárbogárd', 'Fejér'], 'Székesfehérvári járás': ['Székesfehérvár', 'Fejér'],
    'Csornai járás': ['Csorna', 'Győr-Moson-Sopron'], 'Győri járás': ['Győr', 'Győr-Moson-Sopron'],
    'Kapuvári járás': ['Kapuvár', 'Győr-Moson-Sopron'], 'Mosonmagyaróvári járás': ['Mosonmagyaróvár', 'Győr-Moson-Sopron'],
    'Pannonhalmi járás': ['Pannonhalma', 'Győr-Moson-Sopron'], 'Soproni járás': ['Sopron', 'Győr-Moson-Sopron'],
    'Téti járás': ['Tét', 'Győr-Moson-Sopron'],
    'Balmazújvárosi járás': ['Balmazújváros', 'Hajdú-Bihar'],'Berettyóújfalui járás': ['Berettyóújfalu', 'Hajdú-Bihar'],
    'Debreceni járás': ['Debrecen', 'Hajdú-Bihar'],'Derecskei járás': ['Derecske', 'Hajdú-Bihar'],
    'Hajdúböszörményi járás': ['Hajdúböszörmény', 'Hajdú-Bihar'],'Hajdúhadházi járás': ['Hajdúhadház', 'Hajdú-Bihar'],
    'Hajdúnánási járás': ['Hajdúnánás', 'Hajdú-Bihar'],'Hajdúszoboszlói járás': ['Hajdúszoboszló', 'Hajdú-Bihar'],
    'Nyíradonyi járás': ['Nyíradony', 'Hajdú-Bihar'],'Püspökladányi járás': ['Püspökladány', 'Hajdú-Bihar'],
    'Bélapátfalvai járás': ['Bélapátfalva', 'Heves'], 'Egri járás': ['Eger', 'Heves'],
    'Füzesabonyi járás': ['Füzesabony', 'Heves'], 'Gyöngyösi járás': ['Gyöngyös', 'Heves'],
    'Hatvani járás': ['Hatvan', 'Heves'],'Hevesi járás': ['Heves', 'Heves'],
    'Pétervásárai járás': ['Pétervására', 'Heves'],
    'Jászapáti járás': ['Jászapáti', 'Jász-Nagykun-Szolnok'],'Jászberényi járás': ['Jászberény', 'Jász-Nagykun-Szolnok'],
    'Karcagi járás': ['Karcag', 'Jász-Nagykun-Szolnok'],'Kunhegyesi járás': ['Kunhegyes', 'Jász-Nagykun-Szolnok'],
    'Kunszentmártoni járás': ['Kunszentmárton', 'Jász-Nagykun-Szolnok'],
    'Mezőtúri járás': ['Mezőtúr', 'Jász-Nagykun-Szolnok'],
    'Szolnoki járás': ['Szolnok', 'Jász-Nagykun-Szolnok'],
    'Tiszafüredi járás': ['Tiszafüred', 'Jász-Nagykun-Szolnok'],
    'Törökszentmiklósi járás': ['Törökszentmiklós', 'Jász-Nagykun-Szolnok'],
    'Esztergomi járás': ['Esztergom', 'Komárom-Esztergom'],'Kisbéri járás': ['Kisbér', 'Komárom-Esztergom'],
    'Komáromi járás': ['Komárom', 'Komárom-Esztergom'], 'Oroszlányi járás': ['Oroszlány', 'Komárom-Esztergom'],
    'Tatabányai járás': ['Tatabánya', 'Komárom-Esztergom'],'Tatai járás': ['Tata', 'Komárom-Esztergom'],
    'Balassagyarmati járás': ['Balassagyarmat', 'Nógrád'], 'Bátonyterenyei járás': ['Bátonyterenye', 'Nógrád'],
    'Pásztói járás': ['Pásztó', 'Nógrád'], 'Rétsági járás': ['Rétság', 'Nógrád'],
    'Salgótarjáni járás': ['Salgótarján', 'Nógrád'], 'Szécsényi járás': ['Szécsény', 'Nógrád'],
    'Aszódi járás': ['Aszód', 'Pest'],'Budakeszi járás': ['Budakeszi', 'Pest'],
    'Ceglédi járás': ['Cegléd', 'Pest'],'Dabasi járás': ['Dabas', 'Pest'],
    'Dunakeszi járás': ['Dunakeszi', 'Pest'],'Érdi járás': ['Érd', 'Pest'],
    'Gödöllői járás': ['Gödöllő', 'Pest'], 'Gyáli járás': ['Gyál', 'Pest'],
    'Monori járás': ['Monor', 'Pest'],'Nagykátai járás': ['Nagykáta', 'Pest'],
    'Nagykőrösi járás': ['Nagykőrös', 'Pest'],'Pilisvörösvári járás': ['Pilisvörösvár', 'Pest'],
    'Ráckevei járás': ['Ráckeve', 'Pest'], 'Szentendrei járás': ['Szentendre', 'Pest'],
    'Szigetszentmiklósi járás': ['Szigetszentmiklós', 'Pest'],'Szobi járás': ['Szob', 'Pest'],
    'Váci járás': ['Vác', 'Pest'],'Vecsési járás': ['Vecsés', 'Pest'],
    'Barcsi járás': ['Barcs', 'Somogy'],  'Csurgói járás': ['Csurgó', 'Somogy'],
    'Fonyódi járás': ['Fonyód', 'Somogy'], 'Kaposvári járás': ['Kaposvár', 'Somogy'],
    'Marcali járás': ['Marcali', 'Somogy'], 'Nagyatádi járás': ['Nagyatád', 'Somogy'],
    'Siófoki járás': ['Siófok', 'Somogy'], 'Tabi járás': ['Tab', 'Somogy'],
    'Baktalórántházai járás': ['Baktalórántháza', 'Szabolcs-Szatmár-Bereg'],'Csengeri járás': ['Csenger', 'Szabolcs-Szatmár-Bereg'],
    'Fehérgyarmati járás': ['Fehérgyarmat', 'Szabolcs-Szatmár-Bereg'], 'Ibrányi járás': ['Ibrány', 'Szabolcs-Szatmár-Bereg'],
    'Kemecsei járás': ['Kemecse', 'Szabolcs-Szatmár-Bereg'],'Kisvárdai járás': ['Kisvárda', 'Szabolcs-Szatmár-Bereg'],
    'Mátészalkai járás': ['Mátészalka', 'Szabolcs-Szatmár-Bereg'], 'Nagykállói járás': ['Nagykálló', 'Szabolcs-Szatmár-Bereg'],
    'Nyírbátori járás': ['Nyírbátor', 'Szabolcs-Szatmár-Bereg'], 'Nyíregyházi járás': ['Nyíregyháza', 'Szabolcs-Szatmár-Bereg'],
    'Tiszavasvári járás': ['Tiszavasvári', 'Szabolcs-Szatmár-Bereg'],'Vásárosnaményi járás': ['Vásárosnamény', 'Szabolcs-Szatmár-Bereg'],
    'Záhonyi járás': ['Záhony', 'Szabolcs-Szatmár-Bereg'],
    'Bonyhádi járás': ['Bonyhád', 'Tolna'], 'Dombóvári járás': ['Dombóvár', 'Tolna'],
    'Paksi járás': ['Paks', 'Tolna'], 'Szekszárdi járás': ['Szekszárd', 'Tolna'],
    'Tamási járás': ['Tamási', 'Tolna'], 'Tolnai járás': ['Tolna', 'Tolna'],
    'Celldömölki járás': ['Celldömölk', 'Vas'],'Körmendi járás': ['Körmend', 'Vas'], 'Kőszegi járás': ['Kőszeg', 'Vas'],
    'Sárvári járás': ['Sárvár', 'Vas'],'Szentgotthárdi járás': ['Szentgotthárd', 'Vas'],
    'Szombathelyi járás': ['Szombathely', 'Vas'],   'Vasvári járás': ['Vasvár', 'Vas'],
    'Ajkai járás': ['Ajka', 'Veszprém'], 'Balatonalmádi járás': ['Balatonalmádi', 'Veszprém'],
    'Balatonfüredi járás': ['Balatonfüred', 'Veszprém'], 'Devecseri járás': ['Devecser', 'Veszprém'],
    'Pápai járás': ['Pápa', 'Veszprém'], 'Sümegi járás': ['Sümeg', 'Veszprém'],'Tapolcai járás': ['Tapolca', 'Veszprém'],
    'Várpalotai járás': ['Várpalota', 'Veszprém'], 'Veszprémi járás': ['Veszprém', 'Veszprém'], 'Zirci járás': ['Zirc', 'Veszprém'],
    'Keszthelyi járás': ['Keszthely', 'Zala'],'Lenti járás': ['Lenti', 'Zala'],'Letenyei járás': ['Letenye', 'Zala'],
    'Nagykanizsai járás': ['Nagykanizsa', 'Zala'],'Zalaegerszegi járás': ['Zalaegerszeg', 'Zala'],
    'Zalaszentgróti járás': ['Zalaszentgrót', 'Zala'] }

villamos = {
            "BKK1": {"viszonylat":1, "indulas": "Kelenföld vasútállomás", "erkezes": "Bécsi út/Vörösvári út","menetido": 50,"varos": "Budapest" },
            "BKK2":{"viszonylat": 2, "indulas": "Jászai Mari tér", "erkezes" : "Közvágóhíd", "menetido" : 22 ,"varos": "Budapest" },
            "BKK3":{"viszonylat": 3, "indulas": "Mexikói út metróállomás", "erkezes" : "Gubacsi út/ Határ út", "menetido" : 47,"varos": "Budapest" },
            "BKK4":{ "viszonylat": 4,"indulas": "Széll Kálmán tér metróállomás", "erkezes" : "Újbuda központ metróállomás", "menetido": 30,"varos": "Budapest" },
            "BKK6":{ "viszonylat": 6,"indulas": "Széll Kálmán tér metróállomás", "erkezes" : "Móricz Zsigmond körtér metróállomás", "menetido" : 30 ,"varos": "Budapest"},
            "BKK12":{"viszonylat": 12, "indulas": "Angyalföld kocsiszín", "erkezes" : "Rákospalota Kossuth utca", "menetido" : 14,"varos": "Budapest"},
            "BKK14":{"viszonylat": 14,"indulas": "Lehel tér metróállomás", "erkezes" : "Káposztásmegye, Megyeri út", "menetido" : 33 ,"varos": "Budapest"},
            "BKK17":{"viszonylat": 17,"indulas": "Savoya park", "erkezes" : "Bécsi út/ Vörösvári út", "menetido" : 52,"varos": "Budapest" },
            "BKK19":{"viszonylat": 19, "indulas": "Kelenföld vasútállomás", "erkezes" : "Bécsi út / Vörösvári út", "menetido" : 40,"varos": "Budapest"},
            "BKK23":{"viszonylat": 23, "indulas": "Jászai Mari tér", "erkezes" : "Keleti pályaudvar metróállomás", "menetido": 35,"varos": "Budapest"},
            "BKK24":{"viszonylat": 24,"indulas": "Keleti pályudvar metróállomás", "erkezes" : "Közvágóhíd HÉV állomás", "menetido": 18,"varos": "Budapest"},
            "BKK28":{"viszonylat": 28, "indulas": "Blaha Lujza tér metróállomás", "erkezes" : "Izraelita temető", "menetido": 38,"varos": "Budapest"},
            "BKK37":{"viszonylat": 37,"indulas": "Blaha Lujza tér metróállomás", "erkezes" : "Új köztemető (Kozma utca)", "menetido": 31,"varos": "Budapest"},
            "BKK41":{"viszonylat": 41, "indulas": "Kamaraerdei ifjúsági park", "erkezes" : "Bécsi út / Vörösvári út", "menetido": 62,"varos": "Budapest"},
            "BKK42":{"viszonylat": 42, "indulas": "Határ út metróállomás", "erkezes" : "Kispest Tulipán utca", "menetido": 8,"varos": "Budapest"},
            "BKK47":{"viszonylat": 47, "indulas": "Deák Ferenc tér metróállomás", "erkezes" : "Városház tér", "menetido": 31,"varos": "Budapest"},
            "BKK48":{"viszonylat": 48, "indulas": "Savoya park", "erkezes" : "Deák Ferenc tér metróállomás", "menetido": 28,"varos": "Budapest"},
            "BKK49":{"viszonylat": 49, "indulas": "Kelenföld vasútállomás", "erkezes" : "Deák Ferenc tér metróállomás", "menetido": 20,"varos": "Budapest"},
            "BKK50":{ "viszonylat": 50,"indulas": "Határ út", "erkezes" : "Pestszentlőrinc ,Béke tér", "menetido": 25,"varos": "Budapest"},
            "BKK51":{ "viszonylat": 51,"indulas": "Nagysándor József utca", "erkezes" : "Ferenc körút/Mester utca", "menetido": 28,"varos": "Budapest"},
            "BKK52":{ "viszonylat": 52,"indulas": "Határ út metróállomás", "erkezes" : "Pesterzsébet, Pacsirtatelep", "menetido": 25,"varos": "Budapest"},
            "BKK56":{"viszonylat": 56, "indulas": "Hűvösvölgy", "erkezes" : "Városház tér", "menetido": 56,"varos": "Budapest"},
            "BKK59":{"viszonylat": 59,"indulas": "Márton Áron tér", "erkezes" : "Szent János kórház", "menetido": 19,"varos": "Budapest"},
            "BKK60":{"viszonylat": 60,"indulas": "Városmajor", "erkezes" : "Széchenyi-hegy, Gyermekvasút", "menetido": 14,"varos": "Budapest"},
            "BKK61": {"viszonylat": 61, "indulas": "Móricz Zsigmond körtér", "erkezes" : "Hűvösvölgy", "menetido": 35,"varos": "Budapest"},
            "BKK62":{"viszonylat": 62, "indulas": "Blaha Lujza tér metróállomás", "erkezes" : "Rákospalota, MÁV-telep", "menetido": 47,"varos": "Budapest"},
            "BKK69":{"viszonylat": 69, "indulas": "Újpalota, Erdőkerülő utca", "erkezes" : "Mexikói út metróállomás", "menetido": 56,"varos": "Budapest"},
            "DKV1": {"viszonylat": 1, "indulas": "Nagyállomás", "erkezes": "Nagyállomás", "menetido": 38, "varos": "Debrecen"},
            "DKV2": {"viszonylat": 2, "indulas": "Nagyállomás", "erkezes": "Nagyállomás", "menetido": 44, "varos": "Debrecen"},
            "MVK1": {"viszonylat": 1, "indulas": "Tiszai pályaudvar", "erkezes": "Felső-Majláth", "menetido": 33,"varos": "Miskolc"},
            "MVK2": {"viszonylat": 2, "indulas": "Tiszai pályaudvar", "erkezes": "Újgyőri főtér", "menetido": 26,"varos": "Miskolc"},
            "SZKT1": {"viszonylat": 1, "indulas": "Szeged plaza", "erkezes": "Szeged vasútállomás", "menetido": 33, "varos": "Szeged"},
            "SZKT2": {"viszonylat": 2, "indulas": "Európa liget", "erkezes": "Szeged vasútállomás", "menetido": 33, "varos": "Szeged"},
}

orszag= {
    "Albánia": "Tirana","Andorra": "Andorra város", "Ausztria": "Bécs", "Belgium": "Brüsszel",
    "Bosznia és Hercegovina": "Szarajevó",  "Bulgária": "Szófia",  "Ciprus": "Nicosia",
    "Csehország": "Prága",  "Dánia": "Koppenhága", "Észtország": "Tallinn", "Finnország": "Helsinki",
    "Franciaország": "Párizs", "Görögország": "Athén", "Horvátország": "Zágráb", "Izland": "Reykjavík",
    "Írország": "Dublin", "Koszovó": "Pristina", "Lengyelország": "Varsó", "Lettország": "Riga",
    "Liechtenstein": "Vaduz",  "Litvánia": "Vilnius",  "Luxemburg": "Luxemburg",
    "Magyarország": "Budapest",  "Málta": "Valletta",  "Moldova": "Kisinyov",  "Monaco": "Monaco",
    "Montenegró": "Podgorica", "Németország": "Berlin", "Norvégia": "Oslo", "Olaszország": "Róma",
    "Portugália": "Lisszabon", "Románia": "Bukarest", "San Marino": "San Marino",
    "Spanyolország": "Madrid", "Svájc": "Bern",  "Svédország": "Stockholm",  "Szlovákia": "Pozsony",
    "Szlovénia": "Ljubljana", "Törökország": "Ankara", "Ukrajna": "Kijev", "Vatikán": "Vatikánváros"
}

def szotarbol_veletlen_kulcs(szotar, n):
    """
        szotar (dict): A szótár, amelyből véletlenszerűen választunk kulcsokat.
        n (int): A választandó kulcsok száma.
    """
    kulcsok = list(szotar.keys())
    veletlen_kulcsok = []
    for i in range(n):
        kulcs_index = hash(str(i)) % len(kulcsok)
        veletlen_kulcs = kulcsok[kulcs_index]
        veletlen_kulcsok.append(veletlen_kulcs)
    return veletlen_kulcsok

def tordel(lst, n=None):  # lst = kiírandó lista, n = hany kerüljön  egy sorba
    if n is None:
        n = 10
    for i in range(0, len(lst), n):
        row = lst[i:i+n]
        print(", ".join(map(str, row)), end=", ")
        print()

def ftordel(lst, n=None, indent=None):
    if n is None:
        n = 10
    if indent is None:
        indent = ''
    tordelt_sorok = []
    for i in range(0, len(lst), n):
        row = lst[i:i+n]
        tordelt_sorok.append(f"{indent}{', '.join(map(str, row))}")
    return "\n".join(tordelt_sorok)

ABECEDARAK = 'aábcdeéfghiíjklmnoóöőpqrstuúüűvwxyz'
def abc(lista):
    return sorted(lista, key=lambda s: [ABECEDARAK.find(c) for c in s.lower()])

def fel_kerekit(szam):
    if szam % 1 == 0:
        return int(szam)
    else:
        return int(szam) + 1

def le_kerekit(szam):
    return int(szam // 1)
